<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'kihi: pakeke, pakeke, kiri āhua māmā, kiri āhua māmā-waenga',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'kihi: pakeke, pakeke, kiri āhua māmā, kiri āhua waenga',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'kihi: pakeke, pakeke, kiri āhua māmā, kiri āhua waenga-parauri',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'kihi: pakeke, pakeke, kiri āhua māmā, kiri āhua parauri',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'kihi: pakeke, pakeke, kiri āhua māmā-waenga, kiri āhua māmā',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'kihi: pakeke, pakeke, kiri āhua māmā-waenga, kiri āhua waenga',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'kihi: pakeke, pakeke, kiri āhua māmā-waenga, kiri āhua waenga-parauri',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'kihi: pakeke, pakeke, kiri āhua māmā-waenga, kiri āhua parauri',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'kihi: pakeke, pakeke, kiri āhua waenga, kiri āhua māmā',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'kihi: pakeke, pakeke, kiri āhua waenga, kiri āhua māmā-waenga',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'kihi: pakeke, pakeke, kiri āhua waenga, kiri āhua waenga-parauri',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'kihi: pakeke, pakeke, kiri āhua waenga, kiri āhua parauri',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'kihi: pakeke, pakeke, kiri āhua waenga-parauri, kiri āhua māmā',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'kihi: pakeke, pakeke, kiri āhua waenga-parauri, kiri āhua māmā-waenga',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'kihi: pakeke, pakeke, kiri āhua waenga-parauri, kiri āhua waenga',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'kihi: pakeke, pakeke, kiri āhua waenga-parauri, kiri āhua parauri',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'kihi: pakeke, pakeke, kiri āhua parauri, kiri āhua māmā',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'kihi: pakeke, pakeke, kiri āhua parauri, kiri āhua māmā-waenga',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'kihi: pakeke, pakeke, kiri āhua parauri, kiri āhua waenga',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'kihi: pakeke, pakeke, kiri āhua parauri, kiri āhua waenga-parauri',
    '👨🏻‍❤‍💋‍👨🏻' => 'kihi: tāne, tāne, kiri āhua māmā',
    '👨🏻‍❤‍💋‍👨🏼' => 'kihi: tāne, tāne, kiri āhua māmā, kiri āhua māmā-waenga',
    '👨🏻‍❤‍💋‍👨🏽' => 'kihi: tāne, tāne, kiri āhua māmā, kiri āhua waenga',
    '👨🏻‍❤‍💋‍👨🏾' => 'kihi: tāne, tāne, kiri āhua māmā, kiri āhua waenga-parauri',
    '👨🏻‍❤‍💋‍👨🏿' => 'kihi: tāne, tāne, kiri āhua māmā, kiri āhua parauri',
    '👨🏼‍❤‍💋‍👨🏻' => 'kihi: tāne, tāne, kiri āhua māmā-waenga, kiri āhua māmā',
    '👨🏼‍❤‍💋‍👨🏼' => 'kihi: tāne, tāne, kiri āhua māmā-waenga',
    '👨🏼‍❤‍💋‍👨🏽' => 'kihi: tāne, tāne, kiri āhua māmā-waenga, kiri āhua waenga',
    '👨🏼‍❤‍💋‍👨🏾' => 'kihi: tāne, tāne, kiri āhua māmā-waenga, kiri āhua waenga-parauri',
    '👨🏼‍❤‍💋‍👨🏿' => 'kihi: tāne, tāne, kiri āhua māmā-waenga, kiri āhua parauri',
    '👨🏽‍❤‍💋‍👨🏻' => 'kihi: tāne, tāne, kiri āhua waenga, kiri āhua māmā',
    '👨🏽‍❤‍💋‍👨🏼' => 'kihi: tāne, tāne, kiri āhua waenga, kiri āhua māmā-waenga',
    '👨🏽‍❤‍💋‍👨🏽' => 'kihi: tāne, tāne, kiri āhua waenga',
    '👨🏽‍❤‍💋‍👨🏾' => 'kihi: tāne, tāne, kiri āhua waenga, kiri āhua waenga-parauri',
    '👨🏽‍❤‍💋‍👨🏿' => 'kihi: tāne, tāne, kiri āhua waenga, kiri āhua parauri',
    '👨🏾‍❤‍💋‍👨🏻' => 'kihi: tāne, tāne, kiri āhua waenga-parauri, kiri āhua māmā',
    '👨🏾‍❤‍💋‍👨🏼' => 'kihi: tāne, tāne, kiri āhua waenga-parauri, kiri āhua māmā-waenga',
    '👨🏾‍❤‍💋‍👨🏽' => 'kihi: tāne, tāne, kiri āhua waenga-parauri, kiri āhua waenga',
    '👨🏾‍❤‍💋‍👨🏾' => 'kihi: tāne, tāne, kiri āhua waenga-parauri',
    '👨🏾‍❤‍💋‍👨🏿' => 'kihi: tāne, tāne, kiri āhua waenga-parauri, kiri āhua parauri',
    '👨🏿‍❤‍💋‍👨🏻' => 'kihi: tāne, tāne, kiri āhua parauri, kiri āhua māmā',
    '👨🏿‍❤‍💋‍👨🏼' => 'kihi: tāne, tāne, kiri āhua parauri, kiri āhua māmā-waenga',
    '👨🏿‍❤‍💋‍👨🏽' => 'kihi: tāne, tāne, kiri āhua parauri, kiri āhua waenga',
    '👨🏿‍❤‍💋‍👨🏾' => 'kihi: tāne, tāne, kiri āhua parauri, kiri āhua waenga-parauri',
    '👨🏿‍❤‍💋‍👨🏿' => 'kihi: tāne, tāne, kiri āhua parauri',
    '👩🏻‍❤‍💋‍👨🏻' => 'kihi: wahine, tāne, kiri āhua māmā',
    '👩🏻‍❤‍💋‍👨🏼' => 'kihi: wahine, tāne, kiri āhua māmā, kiri āhua māmā-waenga',
    '👩🏻‍❤‍💋‍👨🏽' => 'kihi: wahine, tāne, kiri āhua māmā, kiri āhua waenga',
    '👩🏻‍❤‍💋‍👨🏾' => 'kihi: wahine, tāne, kiri āhua māmā, kiri āhua waenga-parauri',
    '👩🏻‍❤‍💋‍👨🏿' => 'kihi: wahine, tāne, kiri āhua māmā, kiri āhua parauri',
    '👩🏼‍❤‍💋‍👨🏻' => 'kihi: wahine, tāne, kiri āhua māmā-waenga, kiri āhua māmā',
    '👩🏼‍❤‍💋‍👨🏼' => 'kihi: wahine, tāne, kiri āhua māmā-waenga',
    '👩🏼‍❤‍💋‍👨🏽' => 'kihi: wahine, tāne, kiri āhua māmā-waenga, kiri āhua waenga',
    '👩🏼‍❤‍💋‍👨🏾' => 'kihi: wahine, tāne, kiri āhua māmā-waenga, kiri āhua waenga-parauri',
    '👩🏼‍❤‍💋‍👨🏿' => 'kihi: wahine, tāne, kiri āhua māmā-waenga, kiri āhua parauri',
    '👩🏽‍❤‍💋‍👨🏻' => 'kihi: wahine, tāne, kiri āhua waenga, kiri āhua māmā',
    '👩🏽‍❤‍💋‍👨🏼' => 'kihi: wahine, tāne, kiri āhua waenga, kiri āhua māmā-waenga',
    '👩🏽‍❤‍💋‍👨🏽' => 'kihi: wahine, tāne, kiri āhua waenga',
    '👩🏽‍❤‍💋‍👨🏾' => 'kihi: wahine, tāne, kiri āhua waenga, kiri āhua waenga-parauri',
    '👩🏽‍❤‍💋‍👨🏿' => 'kihi: wahine, tāne, kiri āhua waenga, kiri āhua parauri',
    '👩🏾‍❤‍💋‍👨🏻' => 'kihi: wahine, tāne, kiri āhua waenga-parauri, kiri āhua māmā',
    '👩🏾‍❤‍💋‍👨🏼' => 'kihi: wahine, tāne, kiri āhua waenga-parauri, kiri āhua māmā-waenga',
    '👩🏾‍❤‍💋‍👨🏽' => 'kihi: wahine, tāne, kiri āhua waenga-parauri, kiri āhua waenga',
    '👩🏾‍❤‍💋‍👨🏾' => 'kihi: wahine, tāne, kiri āhua waenga-parauri',
    '👩🏾‍❤‍💋‍👨🏿' => 'kihi: wahine, tāne, kiri āhua waenga-parauri, kiri āhua parauri',
    '👩🏿‍❤‍💋‍👨🏻' => 'kihi: wahine, tāne, kiri āhua parauri, kiri āhua māmā',
    '👩🏿‍❤‍💋‍👨🏼' => 'kihi: wahine, tāne, kiri āhua parauri, kiri āhua māmā-waenga',
    '👩🏿‍❤‍💋‍👨🏽' => 'kihi: wahine, tāne, kiri āhua parauri, kiri āhua waenga',
    '👩🏿‍❤‍💋‍👨🏾' => 'kihi: wahine, tāne, kiri āhua parauri, kiri āhua waenga-parauri',
    '👩🏿‍❤‍💋‍👨🏿' => 'kihi: wahine, tāne, kiri āhua parauri',
    '👩🏻‍❤‍💋‍👩🏻' => 'kihi: wahine, wahine, kiri āhua māmā',
    '👩🏻‍❤‍💋‍👩🏼' => 'kihi: wahine, wahine, kiri āhua māmā, kiri āhua māmā-waenga',
    '👩🏻‍❤‍💋‍👩🏽' => 'kihi: wahine, wahine, kiri āhua māmā, kiri āhua waenga',
    '👩🏻‍❤‍💋‍👩🏾' => 'kihi: wahine, wahine, kiri āhua māmā, kiri āhua waenga-parauri',
    '👩🏻‍❤‍💋‍👩🏿' => 'kihi: wahine, wahine, kiri āhua māmā, kiri āhua parauri',
    '👩🏼‍❤‍💋‍👩🏻' => 'kihi: wahine, wahine, kiri āhua māmā-waenga, kiri āhua māmā',
    '👩🏼‍❤‍💋‍👩🏼' => 'kihi: wahine, wahine, kiri āhua māmā-waenga',
    '👩🏼‍❤‍💋‍👩🏽' => 'kihi: wahine, wahine, kiri āhua māmā-waenga, kiri āhua waenga',
    '👩🏼‍❤‍💋‍👩🏾' => 'kihi: wahine, wahine, kiri āhua māmā-waenga, kiri āhua waenga-parauri',
    '👩🏼‍❤‍💋‍👩🏿' => 'kihi: wahine, wahine, kiri āhua māmā-waenga, kiri āhua parauri',
    '👩🏽‍❤‍💋‍👩🏻' => 'kihi: wahine, wahine, kiri āhua waenga, kiri āhua māmā',
    '👩🏽‍❤‍💋‍👩🏼' => 'kihi: wahine, wahine, kiri āhua waenga, kiri āhua māmā-waenga',
    '👩🏽‍❤‍💋‍👩🏽' => 'kihi: wahine, wahine, kiri āhua waenga',
    '👩🏽‍❤‍💋‍👩🏾' => 'kihi: wahine, wahine, kiri āhua waenga, kiri āhua waenga-parauri',
    '👩🏽‍❤‍💋‍👩🏿' => 'kihi: wahine, wahine, kiri āhua waenga, kiri āhua parauri',
    '👩🏾‍❤‍💋‍👩🏻' => 'kihi: wahine, wahine, kiri āhua waenga-parauri, kiri āhua māmā',
    '👩🏾‍❤‍💋‍👩🏼' => 'kihi: wahine, wahine, kiri āhua waenga-parauri, kiri āhua māmā-waenga',
    '👩🏾‍❤‍💋‍👩🏽' => 'kihi: wahine, wahine, kiri āhua waenga-parauri, kiri āhua waenga',
    '👩🏾‍❤‍💋‍👩🏾' => 'kihi: wahine, wahine, kiri āhua waenga-parauri',
    '👩🏾‍❤‍💋‍👩🏿' => 'kihi: wahine, wahine, kiri āhua waenga-parauri, kiri āhua parauri',
    '👩🏿‍❤‍💋‍👩🏻' => 'kihi: wahine, wahine, kiri āhua parauri, kiri āhua māmā',
    '👩🏿‍❤‍💋‍👩🏼' => 'kihi: wahine, wahine, kiri āhua parauri, kiri āhua māmā-waenga',
    '👩🏿‍❤‍💋‍👩🏽' => 'kihi: wahine, wahine, kiri āhua parauri, kiri āhua waenga',
    '👩🏿‍❤‍💋‍👩🏾' => 'kihi: wahine, wahine, kiri āhua parauri, kiri āhua waenga-parauri',
    '👩🏿‍❤‍💋‍👩🏿' => 'kihi: wahine, wahine, kiri āhua parauri',
    '🧑🏻‍🫯‍🧑🏼' => 'tāngata mamau: kiri āhua māmā, kiri āhua māmā-waenga',
    '🧑🏻‍🫯‍🧑🏽' => 'tāngata mamau: kiri āhua māmā, kiri āhua waenga',
    '🧑🏻‍🫯‍🧑🏾' => 'tāngata mamau: kiri āhua māmā, kiri āhua waenga-parauri',
    '🧑🏻‍🫯‍🧑🏿' => 'tāngata mamau: kiri āhua māmā, kiri āhua parauri',
    '🧑🏼‍🫯‍🧑🏻' => 'tāngata mamau: kiri āhua māmā-waenga, kiri āhua māmā',
    '🧑🏼‍🫯‍🧑🏽' => 'tāngata mamau: kiri āhua māmā-waenga, kiri āhua waenga',
    '🧑🏼‍🫯‍🧑🏾' => 'tāngata mamau: kiri āhua māmā-waenga, kiri āhua waenga-parauri',
    '🧑🏼‍🫯‍🧑🏿' => 'tāngata mamau: kiri āhua māmā-waenga, kiri āhua parauri',
    '🧑🏽‍🫯‍🧑🏻' => 'tāngata mamau: kiri āhua waenga, kiri āhua māmā',
    '🧑🏽‍🫯‍🧑🏼' => 'tāngata mamau: kiri āhua waenga, kiri āhua māmā-waenga',
    '🧑🏽‍🫯‍🧑🏾' => 'tāngata mamau: kiri āhua waenga, kiri āhua waenga-parauri',
    '🧑🏽‍🫯‍🧑🏿' => 'tāngata mamau: kiri āhua waenga, kiri āhua parauri',
    '🧑🏾‍🫯‍🧑🏻' => 'tāngata mamau: kiri āhua waenga-parauri, kiri āhua māmā',
    '🧑🏾‍🫯‍🧑🏼' => 'tāngata mamau: kiri āhua waenga-parauri, kiri āhua māmā-waenga',
    '🧑🏾‍🫯‍🧑🏽' => 'tāngata mamau: kiri āhua waenga-parauri, kiri āhua waenga',
    '🧑🏾‍🫯‍🧑🏿' => 'tāngata mamau: kiri āhua waenga-parauri, kiri āhua parauri',
    '🧑🏿‍🫯‍🧑🏻' => 'tāngata mamau: kiri āhua parauri, kiri āhua māmā',
    '🧑🏿‍🫯‍🧑🏼' => 'tāngata mamau: kiri āhua parauri, kiri āhua māmā-waenga',
    '🧑🏿‍🫯‍🧑🏽' => 'tāngata mamau: kiri āhua parauri, kiri āhua waenga',
    '🧑🏿‍🫯‍🧑🏾' => 'tāngata mamau: kiri āhua parauri, kiri āhua waenga-parauri',
    '🧑🏻‍❤‍🧑🏼' => 'tokorua me te manawa: pakeke, pakeke, kiri āhua māmā, kiri āhua māmā-waenga',
    '🧑🏻‍❤‍🧑🏽' => 'tokorua me te manawa: pakeke, pakeke, kiri āhua māmā, kiri āhua waenga',
    '🧑🏻‍❤‍🧑🏾' => 'tokorua me te manawa: pakeke, pakeke, kiri āhua māmā, kiri āhua waenga-parauri',
    '🧑🏻‍❤‍🧑🏿' => 'tokorua me te manawa: pakeke, pakeke, kiri āhua māmā, kiri āhua parauri',
    '🧑🏼‍❤‍🧑🏻' => 'tokorua me te manawa: pakeke, pakeke, kiri āhua māmā-waenga, kiri āhua māmā',
    '🧑🏼‍❤‍🧑🏽' => 'tokorua me te manawa: pakeke, pakeke, kiri āhua māmā-waenga, kiri āhua waenga',
    '🧑🏼‍❤‍🧑🏾' => 'tokorua me te manawa: pakeke, pakeke, kiri āhua māmā-waenga, kiri āhua waenga-parauri',
    '🧑🏼‍❤‍🧑🏿' => 'tokorua me te manawa: pakeke, pakeke, kiri āhua māmā-waenga, kiri āhua parauri',
    '🧑🏽‍❤‍🧑🏻' => 'tokorua me te manawa: pakeke, pakeke, kiri āhua waenga, kiri āhua māmā',
    '🧑🏽‍❤‍🧑🏼' => 'tokorua me te manawa: pakeke, pakeke, kiri āhua waenga, kiri āhua māmā-waenga',
    '🧑🏽‍❤‍🧑🏾' => 'tokorua me te manawa: pakeke, pakeke, kiri āhua waenga, kiri āhua waenga-parauri',
    '🧑🏽‍❤‍🧑🏿' => 'tokorua me te manawa: pakeke, pakeke, kiri āhua waenga, kiri āhua parauri',
    '🧑🏾‍❤‍🧑🏻' => 'tokorua me te manawa: pakeke, pakeke, kiri āhua waenga-parauri, kiri āhua māmā',
    '🧑🏾‍❤‍🧑🏼' => 'tokorua me te manawa: pakeke, pakeke, kiri āhua waenga-parauri, kiri āhua māmā-waenga',
    '🧑🏾‍❤‍🧑🏽' => 'tokorua me te manawa: pakeke, pakeke, kiri āhua waenga-parauri, kiri āhua waenga',
    '🧑🏾‍❤‍🧑🏿' => 'tokorua me te manawa: pakeke, pakeke, kiri āhua waenga-parauri, kiri āhua parauri',
    '🧑🏿‍❤‍🧑🏻' => 'tokorua me te manawa: pakeke, pakeke, kiri āhua parauri, kiri āhua māmā',
    '🧑🏿‍❤‍🧑🏼' => 'tokorua me te manawa: pakeke, pakeke, kiri āhua parauri, kiri āhua māmā-waenga',
    '🧑🏿‍❤‍🧑🏽' => 'tokorua me te manawa: pakeke, pakeke, kiri āhua parauri, kiri āhua waenga',
    '🧑🏿‍❤‍🧑🏾' => 'tokorua me te manawa: pakeke, pakeke, kiri āhua parauri, kiri āhua waenga-parauri',
    '🧑🏻‍🐰‍🧑🏼' => 'tāngata taringa rāpeti whakangahau: kiri āhua māmā, kiri āhua māmā-waenga',
    '🧑🏻‍🐰‍🧑🏽' => 'tāngata taringa rāpeti whakangahau: kiri āhua māmā, kiri āhua waenga',
    '🧑🏻‍🐰‍🧑🏾' => 'tāngata taringa rāpeti whakangahau: kiri āhua māmā, kiri āhua waenga-parauri',
    '🧑🏻‍🐰‍🧑🏿' => 'tāngata taringa rāpeti whakangahau: kiri āhua māmā, kiri āhua parauri',
    '🧑🏼‍🐰‍🧑🏻' => 'tāngata taringa rāpeti whakangahau: kiri āhua māmā-waenga, kiri āhua māmā',
    '🧑🏼‍🐰‍🧑🏽' => 'tāngata taringa rāpeti whakangahau: kiri āhua māmā-waenga, kiri āhua waenga',
    '🧑🏼‍🐰‍🧑🏾' => 'tāngata taringa rāpeti whakangahau: kiri āhua māmā-waenga, kiri āhua waenga-parauri',
    '🧑🏼‍🐰‍🧑🏿' => 'tāngata taringa rāpeti whakangahau: kiri āhua māmā-waenga, kiri āhua parauri',
    '🧑🏽‍🐰‍🧑🏻' => 'tāngata taringa rāpeti whakangahau: kiri āhua waenga, kiri āhua māmā',
    '🧑🏽‍🐰‍🧑🏼' => 'tāngata taringa rāpeti whakangahau: kiri āhua waenga, kiri āhua māmā-waenga',
    '🧑🏽‍🐰‍🧑🏾' => 'tāngata taringa rāpeti whakangahau: kiri āhua waenga, kiri āhua waenga-parauri',
    '🧑🏽‍🐰‍🧑🏿' => 'tāngata taringa rāpeti whakangahau: kiri āhua waenga, kiri āhua parauri',
    '🧑🏾‍🐰‍🧑🏻' => 'tāngata taringa rāpeti whakangahau: kiri āhua waenga-parauri, kiri āhua māmā',
    '🧑🏾‍🐰‍🧑🏼' => 'tāngata taringa rāpeti whakangahau: kiri āhua waenga-parauri, kiri āhua māmā-waenga',
    '🧑🏾‍🐰‍🧑🏽' => 'tāngata taringa rāpeti whakangahau: kiri āhua waenga-parauri, kiri āhua waenga',
    '🧑🏾‍🐰‍🧑🏿' => 'tāngata taringa rāpeti whakangahau: kiri āhua waenga-parauri, kiri āhua parauri',
    '🧑🏿‍🐰‍🧑🏻' => 'tāngata taringa rāpeti whakangahau: kiri āhua parauri, kiri āhua māmā',
    '🧑🏿‍🐰‍🧑🏼' => 'tāngata taringa rāpeti whakangahau: kiri āhua parauri, kiri āhua māmā-waenga',
    '🧑🏿‍🐰‍🧑🏽' => 'tāngata taringa rāpeti whakangahau: kiri āhua parauri, kiri āhua waenga',
    '🧑🏿‍🐰‍🧑🏾' => 'tāngata taringa rāpeti whakangahau: kiri āhua parauri, kiri āhua waenga-parauri',
    '👨🏻‍🫯‍👨🏼' => 'tāne mamau: kiri āhua māmā, kiri āhua māmā-waenga',
    '👨🏻‍🫯‍👨🏽' => 'tāne mamau: kiri āhua māmā, kiri āhua waenga',
    '👨🏻‍🫯‍👨🏾' => 'tāne mamau: kiri āhua māmā, kiri āhua waenga-parauri',
    '👨🏻‍🫯‍👨🏿' => 'tāne mamau: kiri āhua māmā, kiri āhua parauri',
    '👨🏼‍🫯‍👨🏻' => 'tāne mamau: kiri āhua māmā-waenga, kiri āhua māmā',
    '👨🏼‍🫯‍👨🏽' => 'tāne mamau: kiri āhua māmā-waenga, kiri āhua waenga',
    '👨🏼‍🫯‍👨🏾' => 'tāne mamau: kiri āhua māmā-waenga, kiri āhua waenga-parauri',
    '👨🏼‍🫯‍👨🏿' => 'tāne mamau: kiri āhua māmā-waenga, kiri āhua parauri',
    '👨🏽‍🫯‍👨🏻' => 'tāne mamau: kiri āhua waenga, kiri āhua māmā',
    '👨🏽‍🫯‍👨🏼' => 'tāne mamau: kiri āhua waenga, kiri āhua māmā-waenga',
    '👨🏽‍🫯‍👨🏾' => 'tāne mamau: kiri āhua waenga, kiri āhua waenga-parauri',
    '👨🏽‍🫯‍👨🏿' => 'tāne mamau: kiri āhua waenga, kiri āhua parauri',
    '👨🏾‍🫯‍👨🏻' => 'tāne mamau: kiri āhua waenga-parauri, kiri āhua māmā',
    '👨🏾‍🫯‍👨🏼' => 'tāne mamau: kiri āhua waenga-parauri, kiri āhua māmā-waenga',
    '👨🏾‍🫯‍👨🏽' => 'tāne mamau: kiri āhua waenga-parauri, kiri āhua waenga',
    '👨🏾‍🫯‍👨🏿' => 'tāne mamau: kiri āhua waenga-parauri, kiri āhua parauri',
    '👨🏿‍🫯‍👨🏻' => 'tāne mamau: kiri āhua parauri, kiri āhua māmā',
    '👨🏿‍🫯‍👨🏼' => 'tāne mamau: kiri āhua parauri, kiri āhua māmā-waenga',
    '👨🏿‍🫯‍👨🏽' => 'tāne mamau: kiri āhua parauri, kiri āhua waenga',
    '👨🏿‍🫯‍👨🏾' => 'tāne mamau: kiri āhua parauri, kiri āhua waenga-parauri',
    '👨🏻‍❤‍👨🏻' => 'tokorua me te manawa: tāne, tāne, kiri āhua māmā',
    '👨🏻‍❤‍👨🏼' => 'tokorua me te manawa: tāne, tāne, kiri āhua māmā, kiri āhua māmā-waenga',
    '👨🏻‍❤‍👨🏽' => 'tokorua me te manawa: tāne, tāne, kiri āhua māmā, kiri āhua waenga',
    '👨🏻‍❤‍👨🏾' => 'tokorua me te manawa: tāne, tāne, kiri āhua māmā, kiri āhua waenga-parauri',
    '👨🏻‍❤‍👨🏿' => 'tokorua me te manawa: tāne, tāne, kiri āhua māmā, kiri āhua parauri',
    '👨🏼‍❤‍👨🏻' => 'tokorua me te manawa: tāne, tāne, kiri āhua māmā-waenga, kiri āhua māmā',
    '👨🏼‍❤‍👨🏼' => 'tokorua me te manawa: tāne, tāne, kiri āhua māmā-waenga',
    '👨🏼‍❤‍👨🏽' => 'tokorua me te manawa: tāne, tāne, kiri āhua māmā-waenga, kiri āhua waenga',
    '👨🏼‍❤‍👨🏾' => 'tokorua me te manawa: tāne, tāne, kiri āhua māmā-waenga, kiri āhua waenga-parauri',
    '👨🏼‍❤‍👨🏿' => 'tokorua me te manawa: tāne, tāne, kiri āhua māmā-waenga, kiri āhua parauri',
    '👨🏽‍❤‍👨🏻' => 'tokorua me te manawa: tāne, tāne, kiri āhua waenga, kiri āhua māmā',
    '👨🏽‍❤‍👨🏼' => 'tokorua me te manawa: tāne, tāne, kiri āhua waenga, kiri āhua māmā-waenga',
    '👨🏽‍❤‍👨🏽' => 'tokorua me te manawa: tāne, tāne, kiri āhua waenga',
    '👨🏽‍❤‍👨🏾' => 'tokorua me te manawa: tāne, tāne, kiri āhua waenga, kiri āhua waenga-parauri',
    '👨🏽‍❤‍👨🏿' => 'tokorua me te manawa: tāne, tāne, kiri āhua waenga, kiri āhua parauri',
    '👨🏾‍❤‍👨🏻' => 'tokorua me te manawa: tāne, tāne, kiri āhua waenga-parauri, kiri āhua māmā',
    '👨🏾‍❤‍👨🏼' => 'tokorua me te manawa: tāne, tāne, kiri āhua waenga-parauri, kiri āhua māmā-waenga',
    '👨🏾‍❤‍👨🏽' => 'tokorua me te manawa: tāne, tāne, kiri āhua waenga-parauri, kiri āhua waenga',
    '👨🏾‍❤‍👨🏾' => 'tokorua me te manawa: tāne, tāne, kiri āhua waenga-parauri',
    '👨🏾‍❤‍👨🏿' => 'tokorua me te manawa: tāne, tāne, kiri āhua waenga-parauri, kiri āhua parauri',
    '👨🏿‍❤‍👨🏻' => 'tokorua me te manawa: tāne, tāne, kiri āhua parauri, kiri āhua māmā',
    '👨🏿‍❤‍👨🏼' => 'tokorua me te manawa: tāne, tāne, kiri āhua parauri, kiri āhua māmā-waenga',
    '👨🏿‍❤‍👨🏽' => 'tokorua me te manawa: tāne, tāne, kiri āhua parauri, kiri āhua waenga',
    '👨🏿‍❤‍👨🏾' => 'tokorua me te manawa: tāne, tāne, kiri āhua parauri, kiri āhua waenga-parauri',
    '👨🏿‍❤‍👨🏿' => 'tokorua me te manawa: tāne, tāne, kiri āhua parauri',
    '👨🏻‍🐰‍👨🏼' => 'tāne taringa rāpeti whakangahau: kiri āhua māmā, kiri āhua māmā-waenga',
    '👨🏻‍🐰‍👨🏽' => 'tāne taringa rāpeti whakangahau: kiri āhua māmā, kiri āhua waenga',
    '👨🏻‍🐰‍👨🏾' => 'tāne taringa rāpeti whakangahau: kiri āhua māmā, kiri āhua waenga-parauri',
    '👨🏻‍🐰‍👨🏿' => 'tāne taringa rāpeti whakangahau: kiri āhua māmā, kiri āhua parauri',
    '👨🏼‍🐰‍👨🏻' => 'tāne taringa rāpeti whakangahau: kiri āhua māmā-waenga, kiri āhua māmā',
    '👨🏼‍🐰‍👨🏽' => 'tāne taringa rāpeti whakangahau: kiri āhua māmā-waenga, kiri āhua waenga',
    '👨🏼‍🐰‍👨🏾' => 'tāne taringa rāpeti whakangahau: kiri āhua māmā-waenga, kiri āhua waenga-parauri',
    '👨🏼‍🐰‍👨🏿' => 'tāne taringa rāpeti whakangahau: kiri āhua māmā-waenga, kiri āhua parauri',
    '👨🏽‍🐰‍👨🏻' => 'tāne taringa rāpeti whakangahau: kiri āhua waenga, kiri āhua māmā',
    '👨🏽‍🐰‍👨🏼' => 'tāne taringa rāpeti whakangahau: kiri āhua waenga, kiri āhua māmā-waenga',
    '👨🏽‍🐰‍👨🏾' => 'tāne taringa rāpeti whakangahau: kiri āhua waenga, kiri āhua waenga-parauri',
    '👨🏽‍🐰‍👨🏿' => 'tāne taringa rāpeti whakangahau: kiri āhua waenga, kiri āhua parauri',
    '👨🏾‍🐰‍👨🏻' => 'tāne taringa rāpeti whakangahau: kiri āhua waenga-parauri, kiri āhua māmā',
    '👨🏾‍🐰‍👨🏼' => 'tāne taringa rāpeti whakangahau: kiri āhua waenga-parauri, kiri āhua māmā-waenga',
    '👨🏾‍🐰‍👨🏽' => 'tāne taringa rāpeti whakangahau: kiri āhua waenga-parauri, kiri āhua waenga',
    '👨🏾‍🐰‍👨🏿' => 'tāne taringa rāpeti whakangahau: kiri āhua waenga-parauri, kiri āhua parauri',
    '👨🏿‍🐰‍👨🏻' => 'tāne taringa rāpeti whakangahau: kiri āhua parauri, kiri āhua māmā',
    '👨🏿‍🐰‍👨🏼' => 'tāne taringa rāpeti whakangahau: kiri āhua parauri, kiri āhua māmā-waenga',
    '👨🏿‍🐰‍👨🏽' => 'tāne taringa rāpeti whakangahau: kiri āhua parauri, kiri āhua waenga',
    '👨🏿‍🐰‍👨🏾' => 'tāne taringa rāpeti whakangahau: kiri āhua parauri, kiri āhua waenga-parauri',
    '👩🏻‍🫯‍👩🏼' => 'wāhine mamau: kiri āhua māmā, kiri āhua māmā-waenga',
    '👩🏻‍🫯‍👩🏽' => 'wāhine mamau: kiri āhua māmā, kiri āhua waenga',
    '👩🏻‍🫯‍👩🏾' => 'wāhine mamau: kiri āhua māmā, kiri āhua waenga-parauri',
    '👩🏻‍🫯‍👩🏿' => 'wāhine mamau: kiri āhua māmā, kiri āhua parauri',
    '👩🏼‍🫯‍👩🏻' => 'wāhine mamau: kiri āhua māmā-waenga, kiri āhua māmā',
    '👩🏼‍🫯‍👩🏽' => 'wāhine mamau: kiri āhua māmā-waenga, kiri āhua waenga',
    '👩🏼‍🫯‍👩🏾' => 'wāhine mamau: kiri āhua māmā-waenga, kiri āhua waenga-parauri',
    '👩🏼‍🫯‍👩🏿' => 'wāhine mamau: kiri āhua māmā-waenga, kiri āhua parauri',
    '👩🏽‍🫯‍👩🏻' => 'wāhine mamau: kiri āhua waenga, kiri āhua māmā',
    '👩🏽‍🫯‍👩🏼' => 'wāhine mamau: kiri āhua waenga, kiri āhua māmā-waenga',
    '👩🏽‍🫯‍👩🏾' => 'wāhine mamau: kiri āhua waenga, kiri āhua waenga-parauri',
    '👩🏽‍🫯‍👩🏿' => 'wāhine mamau: kiri āhua waenga, kiri āhua parauri',
    '👩🏾‍🫯‍👩🏻' => 'wāhine mamau: kiri āhua waenga-parauri, kiri āhua māmā',
    '👩🏾‍🫯‍👩🏼' => 'wāhine mamau: kiri āhua waenga-parauri, kiri āhua māmā-waenga',
    '👩🏾‍🫯‍👩🏽' => 'wāhine mamau: kiri āhua waenga-parauri, kiri āhua waenga',
    '👩🏾‍🫯‍👩🏿' => 'wāhine mamau: kiri āhua waenga-parauri, kiri āhua parauri',
    '👩🏿‍🫯‍👩🏻' => 'wāhine mamau: kiri āhua parauri, kiri āhua māmā',
    '👩🏿‍🫯‍👩🏼' => 'wāhine mamau: kiri āhua parauri, kiri āhua māmā-waenga',
    '👩🏿‍🫯‍👩🏽' => 'wāhine mamau: kiri āhua parauri, kiri āhua waenga',
    '👩🏿‍🫯‍👩🏾' => 'wāhine mamau: kiri āhua parauri, kiri āhua waenga-parauri',
    '👩🏻‍❤‍👨🏻' => 'tokorua me te manawa: wahine, tāne, kiri āhua māmā',
    '👩🏻‍❤‍👨🏼' => 'tokorua me te manawa: wahine, tāne, kiri āhua māmā, kiri āhua māmā-waenga',
    '👩🏻‍❤‍👨🏽' => 'tokorua me te manawa: wahine, tāne, kiri āhua māmā, kiri āhua waenga',
    '👩🏻‍❤‍👨🏾' => 'tokorua me te manawa: wahine, tāne, kiri āhua māmā, kiri āhua waenga-parauri',
    '👩🏻‍❤‍👨🏿' => 'tokorua me te manawa: wahine, tāne, kiri āhua māmā, kiri āhua parauri',
    '👩🏼‍❤‍👨🏻' => 'tokorua me te manawa: wahine, tāne, kiri āhua māmā-waenga, kiri āhua māmā',
    '👩🏼‍❤‍👨🏼' => 'tokorua me te manawa: wahine, tāne, kiri āhua māmā-waenga',
    '👩🏼‍❤‍👨🏽' => 'tokorua me te manawa: wahine, tāne, kiri āhua māmā-waenga, kiri āhua waenga',
    '👩🏼‍❤‍👨🏾' => 'tokorua me te manawa: wahine, tāne, kiri āhua māmā-waenga, kiri āhua waenga-parauri',
    '👩🏼‍❤‍👨🏿' => 'tokorua me te manawa: wahine, tāne, kiri āhua māmā-waenga, kiri āhua parauri',
    '👩🏽‍❤‍👨🏻' => 'tokorua me te manawa: wahine, tāne, kiri āhua waenga, kiri āhua māmā',
    '👩🏽‍❤‍👨🏼' => 'tokorua me te manawa: wahine, tāne, kiri āhua waenga, kiri āhua māmā-waenga',
    '👩🏽‍❤‍👨🏽' => 'tokorua me te manawa: wahine, tāne, kiri āhua waenga',
    '👩🏽‍❤‍👨🏾' => 'tokorua me te manawa: wahine, tāne, kiri āhua waenga, kiri āhua waenga-parauri',
    '👩🏽‍❤‍👨🏿' => 'tokorua me te manawa: wahine, tāne, kiri āhua waenga, kiri āhua parauri',
    '👩🏾‍❤‍👨🏻' => 'tokorua me te manawa: wahine, tāne, kiri āhua waenga-parauri, kiri āhua māmā',
    '👩🏾‍❤‍👨🏼' => 'tokorua me te manawa: wahine, tāne, kiri āhua waenga-parauri, kiri āhua māmā-waenga',
    '👩🏾‍❤‍👨🏽' => 'tokorua me te manawa: wahine, tāne, kiri āhua waenga-parauri, kiri āhua waenga',
    '👩🏾‍❤‍👨🏾' => 'tokorua me te manawa: wahine, tāne, kiri āhua waenga-parauri',
    '👩🏾‍❤‍👨🏿' => 'tokorua me te manawa: wahine, tāne, kiri āhua waenga-parauri, kiri āhua parauri',
    '👩🏿‍❤‍👨🏻' => 'tokorua me te manawa: wahine, tāne, kiri āhua parauri, kiri āhua māmā',
    '👩🏿‍❤‍👨🏼' => 'tokorua me te manawa: wahine, tāne, kiri āhua parauri, kiri āhua māmā-waenga',
    '👩🏿‍❤‍👨🏽' => 'tokorua me te manawa: wahine, tāne, kiri āhua parauri, kiri āhua waenga',
    '👩🏿‍❤‍👨🏾' => 'tokorua me te manawa: wahine, tāne, kiri āhua parauri, kiri āhua waenga-parauri',
    '👩🏿‍❤‍👨🏿' => 'tokorua me te manawa: wahine, tāne, kiri āhua parauri',
    '👩🏻‍❤‍👩🏻' => 'tokorua me te manawa: wahine, wahine, kiri āhua māmā',
    '👩🏻‍❤‍👩🏼' => 'tokorua me te manawa: wahine, wahine, kiri āhua māmā, kiri āhua māmā-waenga',
    '👩🏻‍❤‍👩🏽' => 'tokorua me te manawa: wahine, wahine, kiri āhua māmā, kiri āhua waenga',
    '👩🏻‍❤‍👩🏾' => 'tokorua me te manawa: wahine, wahine, kiri āhua māmā, kiri āhua waenga-parauri',
    '👩🏻‍❤‍👩🏿' => 'tokorua me te manawa: wahine, wahine, kiri āhua māmā, kiri āhua parauri',
    '👩🏼‍❤‍👩🏻' => 'tokorua me te manawa: wahine, wahine, kiri āhua māmā-waenga, kiri āhua māmā',
    '👩🏼‍❤‍👩🏼' => 'tokorua me te manawa: wahine, wahine, kiri āhua māmā-waenga',
    '👩🏼‍❤‍👩🏽' => 'tokorua me te manawa: wahine, wahine, kiri āhua māmā-waenga, kiri āhua waenga',
    '👩🏼‍❤‍👩🏾' => 'tokorua me te manawa: wahine, wahine, kiri āhua māmā-waenga, kiri āhua waenga-parauri',
    '👩🏼‍❤‍👩🏿' => 'tokorua me te manawa: wahine, wahine, kiri āhua māmā-waenga, kiri āhua parauri',
    '👩🏽‍❤‍👩🏻' => 'tokorua me te manawa: wahine, wahine, kiri āhua waenga, kiri āhua māmā',
    '👩🏽‍❤‍👩🏼' => 'tokorua me te manawa: wahine, wahine, kiri āhua waenga, kiri āhua māmā-waenga',
    '👩🏽‍❤‍👩🏽' => 'tokorua me te manawa: wahine, wahine, kiri āhua waenga',
    '👩🏽‍❤‍👩🏾' => 'tokorua me te manawa: wahine, wahine, kiri āhua waenga, kiri āhua waenga-parauri',
    '👩🏽‍❤‍👩🏿' => 'tokorua me te manawa: wahine, wahine, kiri āhua waenga, kiri āhua parauri',
    '👩🏾‍❤‍👩🏻' => 'tokorua me te manawa: wahine, wahine, kiri āhua waenga-parauri, kiri āhua māmā',
    '👩🏾‍❤‍👩🏼' => 'tokorua me te manawa: wahine, wahine, kiri āhua waenga-parauri, kiri āhua māmā-waenga',
    '👩🏾‍❤‍👩🏽' => 'tokorua me te manawa: wahine, wahine, kiri āhua waenga-parauri, kiri āhua waenga',
    '👩🏾‍❤‍👩🏾' => 'tokorua me te manawa: wahine, wahine, kiri āhua waenga-parauri',
    '👩🏾‍❤‍👩🏿' => 'tokorua me te manawa: wahine, wahine, kiri āhua waenga-parauri, kiri āhua parauri',
    '👩🏿‍❤‍👩🏻' => 'tokorua me te manawa: wahine, wahine, kiri āhua parauri, kiri āhua māmā',
    '👩🏿‍❤‍👩🏼' => 'tokorua me te manawa: wahine, wahine, kiri āhua parauri, kiri āhua māmā-waenga',
    '👩🏿‍❤‍👩🏽' => 'tokorua me te manawa: wahine, wahine, kiri āhua parauri, kiri āhua waenga',
    '👩🏿‍❤‍👩🏾' => 'tokorua me te manawa: wahine, wahine, kiri āhua parauri, kiri āhua waenga-parauri',
    '👩🏿‍❤‍👩🏿' => 'tokorua me te manawa: wahine, wahine, kiri āhua parauri',
    '👩🏻‍🐰‍👩🏼' => 'wāhine taringa rāpeti whakangahau: kiri āhua māmā, kiri āhua māmā-waenga',
    '👩🏻‍🐰‍👩🏽' => 'wāhine taringa rāpeti whakangahau: kiri āhua māmā, kiri āhua waenga',
    '👩🏻‍🐰‍👩🏾' => 'wāhine taringa rāpeti whakangahau: kiri āhua māmā, kiri āhua waenga-parauri',
    '👩🏻‍🐰‍👩🏿' => 'wāhine taringa rāpeti whakangahau: kiri āhua māmā, kiri āhua parauri',
    '👩🏼‍🐰‍👩🏻' => 'wāhine taringa rāpeti whakangahau: kiri āhua māmā-waenga, kiri āhua māmā',
    '👩🏼‍🐰‍👩🏽' => 'wāhine taringa rāpeti whakangahau: kiri āhua māmā-waenga, kiri āhua waenga',
    '👩🏼‍🐰‍👩🏾' => 'wāhine taringa rāpeti whakangahau: kiri āhua māmā-waenga, kiri āhua waenga-parauri',
    '👩🏼‍🐰‍👩🏿' => 'wāhine taringa rāpeti whakangahau: kiri āhua māmā-waenga, kiri āhua parauri',
    '👩🏽‍🐰‍👩🏻' => 'wāhine taringa rāpeti whakangahau: kiri āhua waenga, kiri āhua māmā',
    '👩🏽‍🐰‍👩🏼' => 'wāhine taringa rāpeti whakangahau: kiri āhua waenga, kiri āhua māmā-waenga',
    '👩🏽‍🐰‍👩🏾' => 'wāhine taringa rāpeti whakangahau: kiri āhua waenga, kiri āhua waenga-parauri',
    '👩🏽‍🐰‍👩🏿' => 'wāhine taringa rāpeti whakangahau: kiri āhua waenga, kiri āhua parauri',
    '👩🏾‍🐰‍👩🏻' => 'wāhine taringa rāpeti whakangahau: kiri āhua waenga-parauri, kiri āhua māmā',
    '👩🏾‍🐰‍👩🏼' => 'wāhine taringa rāpeti whakangahau: kiri āhua waenga-parauri, kiri āhua māmā-waenga',
    '👩🏾‍🐰‍👩🏽' => 'wāhine taringa rāpeti whakangahau: kiri āhua waenga-parauri, kiri āhua waenga',
    '👩🏾‍🐰‍👩🏿' => 'wāhine taringa rāpeti whakangahau: kiri āhua waenga-parauri, kiri āhua parauri',
    '👩🏿‍🐰‍👩🏻' => 'wāhine taringa rāpeti whakangahau: kiri āhua parauri, kiri āhua māmā',
    '👩🏿‍🐰‍👩🏼' => 'wāhine taringa rāpeti whakangahau: kiri āhua parauri, kiri āhua māmā-waenga',
    '👩🏿‍🐰‍👩🏽' => 'wāhine taringa rāpeti whakangahau: kiri āhua parauri, kiri āhua waenga',
    '👩🏿‍🐰‍👩🏾' => 'wāhine taringa rāpeti whakangahau: kiri āhua parauri, kiri āhua waenga-parauri',
    '👩🏻‍🤝‍👩🏼' => 'tokorua wāhine mau ringa: kiri āhua māmā, kiri āhua māmā-waenga',
    '👩🏻‍🤝‍👩🏽' => 'tokorua wāhine mau ringa: kiri āhua māmā, kiri āhua waenga',
    '👩🏻‍🤝‍👩🏾' => 'tokorua wāhine mau ringa: kiri āhua māmā, kiri āhua waenga-parauri',
    '👩🏻‍🤝‍👩🏿' => 'tokorua wāhine mau ringa: kiri āhua māmā, kiri āhua parauri',
    '👩🏼‍🤝‍👩🏻' => 'tokorua wāhine mau ringa: kiri āhua māmā-waenga, kiri āhua māmā',
    '👩🏼‍🤝‍👩🏽' => 'tokorua wāhine mau ringa: kiri āhua māmā-waenga, kiri āhua waenga',
    '👩🏼‍🤝‍👩🏾' => 'tokorua wāhine mau ringa: kiri āhua māmā-waenga, kiri āhua waenga-parauri',
    '👩🏼‍🤝‍👩🏿' => 'tokorua wāhine mau ringa: kiri āhua māmā-waenga, kiri āhua parauri',
    '👩🏽‍🤝‍👩🏻' => 'tokorua wāhine mau ringa: kiri āhua waenga, kiri āhua māmā',
    '👩🏽‍🤝‍👩🏼' => 'tokorua wāhine mau ringa: kiri āhua waenga, kiri āhua māmā-waenga',
    '👩🏽‍🤝‍👩🏾' => 'tokorua wāhine mau ringa: kiri āhua waenga, kiri āhua waenga-parauri',
    '👩🏽‍🤝‍👩🏿' => 'tokorua wāhine mau ringa: kiri āhua waenga, kiri āhua parauri',
    '👩🏾‍🤝‍👩🏻' => 'tokorua wāhine mau ringa: kiri āhua waenga-parauri, kiri āhua māmā',
    '👩🏾‍🤝‍👩🏼' => 'tokorua wāhine mau ringa: kiri āhua waenga-parauri, kiri āhua māmā-waenga',
    '👩🏾‍🤝‍👩🏽' => 'tokorua wāhine mau ringa: kiri āhua waenga-parauri, kiri āhua waenga',
    '👩🏾‍🤝‍👩🏿' => 'tokorua wāhine mau ringa: kiri āhua waenga-parauri, kiri āhua parauri',
    '👩🏿‍🤝‍👩🏻' => 'tokorua wāhine mau ringa: kiri āhua parauri, kiri āhua māmā',
    '👩🏿‍🤝‍👩🏼' => 'tokorua wāhine mau ringa: kiri āhua parauri, kiri āhua māmā-waenga',
    '👩🏿‍🤝‍👩🏽' => 'tokorua wāhine mau ringa: kiri āhua parauri, kiri āhua waenga',
    '👩🏿‍🤝‍👩🏾' => 'tokorua wāhine mau ringa: kiri āhua parauri, kiri āhua waenga-parauri',
    '👩🏻‍🤝‍👨🏼' => 'tāne me te wahine mau ringa: kiri āhua māmā, kiri āhua māmā-waenga',
    '👩🏻‍🤝‍👨🏽' => 'tāne me te wahine mau ringa: kiri āhua māmā, kiri āhua waenga',
    '👩🏻‍🤝‍👨🏾' => 'tāne me te wahine mau ringa: kiri āhua māmā, kiri āhua waenga-parauri',
    '👩🏻‍🤝‍👨🏿' => 'tāne me te wahine mau ringa: kiri āhua māmā, kiri āhua parauri',
    '👩🏼‍🤝‍👨🏻' => 'tāne me te wahine mau ringa: kiri āhua māmā-waenga, kiri āhua māmā',
    '👩🏼‍🤝‍👨🏽' => 'tāne me te wahine mau ringa: kiri āhua māmā-waenga, kiri āhua waenga',
    '👩🏼‍🤝‍👨🏾' => 'tāne me te wahine mau ringa: kiri āhua māmā-waenga, kiri āhua waenga-parauri',
    '👩🏼‍🤝‍👨🏿' => 'tāne me te wahine mau ringa: kiri āhua māmā-waenga, kiri āhua parauri',
    '👩🏽‍🤝‍👨🏻' => 'tāne me te wahine mau ringa: kiri āhua waenga, kiri āhua māmā',
    '👩🏽‍🤝‍👨🏼' => 'tāne me te wahine mau ringa: kiri āhua waenga, kiri āhua māmā-waenga',
    '👩🏽‍🤝‍👨🏾' => 'tāne me te wahine mau ringa: kiri āhua waenga, kiri āhua waenga-parauri',
    '👩🏽‍🤝‍👨🏿' => 'tāne me te wahine mau ringa: kiri āhua waenga, kiri āhua parauri',
    '👩🏾‍🤝‍👨🏻' => 'tāne me te wahine mau ringa: kiri āhua waenga-parauri, kiri āhua māmā',
    '👩🏾‍🤝‍👨🏼' => 'tāne me te wahine mau ringa: kiri āhua waenga-parauri, kiri āhua māmā-waenga',
    '👩🏾‍🤝‍👨🏽' => 'tāne me te wahine mau ringa: kiri āhua waenga-parauri, kiri āhua waenga',
    '👩🏾‍🤝‍👨🏿' => 'tāne me te wahine mau ringa: kiri āhua waenga-parauri, kiri āhua parauri',
    '👩🏿‍🤝‍👨🏻' => 'tāne me te wahine mau ringa: kiri āhua parauri, kiri āhua māmā',
    '👩🏿‍🤝‍👨🏼' => 'tāne me te wahine mau ringa: kiri āhua parauri, kiri āhua māmā-waenga',
    '👩🏿‍🤝‍👨🏽' => 'tāne me te wahine mau ringa: kiri āhua parauri, kiri āhua waenga',
    '👩🏿‍🤝‍👨🏾' => 'tāne me te wahine mau ringa: kiri āhua parauri, kiri āhua waenga-parauri',
    '👨🏻‍🤝‍👨🏼' => 'tokorua tāne mau ringa: kiri āhua māmā, kiri āhua māmā-waenga',
    '👨🏻‍🤝‍👨🏽' => 'tokorua tāne mau ringa: kiri āhua māmā, kiri āhua waenga',
    '👨🏻‍🤝‍👨🏾' => 'tokorua tāne mau ringa: kiri āhua māmā, kiri āhua waenga-parauri',
    '👨🏻‍🤝‍👨🏿' => 'tokorua tāne mau ringa: kiri āhua māmā, kiri āhua parauri',
    '👨🏼‍🤝‍👨🏻' => 'tokorua tāne mau ringa: kiri āhua māmā-waenga, kiri āhua māmā',
    '👨🏼‍🤝‍👨🏽' => 'tokorua tāne mau ringa: kiri āhua māmā-waenga, kiri āhua waenga',
    '👨🏼‍🤝‍👨🏾' => 'tokorua tāne mau ringa: kiri āhua māmā-waenga, kiri āhua waenga-parauri',
    '👨🏼‍🤝‍👨🏿' => 'tokorua tāne mau ringa: kiri āhua māmā-waenga, kiri āhua parauri',
    '👨🏽‍🤝‍👨🏻' => 'tokorua tāne mau ringa: kiri āhua waenga, kiri āhua māmā',
    '👨🏽‍🤝‍👨🏼' => 'tokorua tāne mau ringa: kiri āhua waenga, kiri āhua māmā-waenga',
    '👨🏽‍🤝‍👨🏾' => 'tokorua tāne mau ringa: kiri āhua waenga, kiri āhua waenga-parauri',
    '👨🏽‍🤝‍👨🏿' => 'tokorua tāne mau ringa: kiri āhua waenga, kiri āhua parauri',
    '👨🏾‍🤝‍👨🏻' => 'tokorua tāne mau ringa: kiri āhua waenga-parauri, kiri āhua māmā',
    '👨🏾‍🤝‍👨🏼' => 'tokorua tāne mau ringa: kiri āhua waenga-parauri, kiri āhua māmā-waenga',
    '👨🏾‍🤝‍👨🏽' => 'tokorua tāne mau ringa: kiri āhua waenga-parauri, kiri āhua waenga',
    '👨🏾‍🤝‍👨🏿' => 'tokorua tāne mau ringa: kiri āhua waenga-parauri, kiri āhua parauri',
    '👨🏿‍🤝‍👨🏻' => 'tokorua tāne mau ringa: kiri āhua parauri, kiri āhua māmā',
    '👨🏿‍🤝‍👨🏼' => 'tokorua tāne mau ringa: kiri āhua parauri, kiri āhua māmā-waenga',
    '👨🏿‍🤝‍👨🏽' => 'tokorua tāne mau ringa: kiri āhua parauri, kiri āhua waenga',
    '👨🏿‍🤝‍👨🏾' => 'tokorua tāne mau ringa: kiri āhua parauri, kiri āhua waenga-parauri',
    '👩‍❤‍💋‍👨' => 'kihi: wahine, tāne',
    '👨‍❤‍💋‍👨' => 'kihi: tāne, tāne',
    '👩‍❤‍💋‍👩' => 'kihi: wahine, wahine',
    '👨‍👩‍👧‍👦' => 'whānau: tāne, wahine, kōtiro, tamatāne',
    '👨‍👩‍👦‍👦' => 'whānau: tāne, wahine, tamatāne, tamatāne',
    '👨‍👩‍👧‍👧' => 'whānau: tāne, wahine, kōtiro, kōtiro',
    '👨‍👨‍👧‍👦' => 'whānau: tāne, tāne, kōtiro, tamatāne',
    '👨‍👨‍👦‍👦' => 'whānau: tāne, tāne, tamatāne, tamatāne',
    '👨‍👨‍👧‍👧' => 'whānau: tāne, tāne, kōtiro, kōtiro',
    '👩‍👩‍👧‍👦' => 'whānau: wahine, wahine, kōtiro, tamatāne',
    '👩‍👩‍👦‍👦' => 'whānau: wahine, wahine, tamatāne, tamatāne',
    '👩‍👩‍👧‍👧' => 'whānau: wahine, wahine, kōtiro, kōtiro',
    '🫱🏻‍🫲🏼' => 'rūrū: kiri āhua māmā, kiri āhua māmā-waenga',
    '🫱🏻‍🫲🏽' => 'rūrū: kiri āhua māmā, kiri āhua waenga',
    '🫱🏻‍🫲🏾' => 'rūrū: kiri āhua māmā, kiri āhua waenga-parauri',
    '🫱🏻‍🫲🏿' => 'rūrū: kiri āhua māmā, kiri āhua parauri',
    '🫱🏼‍🫲🏻' => 'rūrū: kiri āhua māmā-waenga, kiri āhua māmā',
    '🫱🏼‍🫲🏽' => 'rūrū: kiri āhua māmā-waenga, kiri āhua waenga',
    '🫱🏼‍🫲🏾' => 'rūrū: kiri āhua māmā-waenga, kiri āhua waenga-parauri',
    '🫱🏼‍🫲🏿' => 'rūrū: kiri āhua māmā-waenga, kiri āhua parauri',
    '🫱🏽‍🫲🏻' => 'rūrū: kiri āhua waenga, kiri āhua māmā',
    '🫱🏽‍🫲🏼' => 'rūrū: kiri āhua waenga, kiri āhua māmā-waenga',
    '🫱🏽‍🫲🏾' => 'rūrū: kiri āhua waenga, kiri āhua waenga-parauri',
    '🫱🏽‍🫲🏿' => 'rūrū: kiri āhua waenga, kiri āhua parauri',
    '🫱🏾‍🫲🏻' => 'rūrū: kiri āhua waenga-parauri, kiri āhua māmā',
    '🫱🏾‍🫲🏼' => 'rūrū: kiri āhua waenga-parauri, kiri āhua māmā-waenga',
    '🫱🏾‍🫲🏽' => 'rūrū: kiri āhua waenga-parauri, kiri āhua waenga',
    '🫱🏾‍🫲🏿' => 'rūrū: kiri āhua waenga-parauri, kiri āhua parauri',
    '🫱🏿‍🫲🏻' => 'rūrū: kiri āhua parauri, kiri āhua māmā',
    '🫱🏿‍🫲🏼' => 'rūrū: kiri āhua parauri, kiri āhua māmā-waenga',
    '🫱🏿‍🫲🏽' => 'rūrū: kiri āhua parauri, kiri āhua waenga',
    '🫱🏿‍🫲🏾' => 'rūrū: kiri āhua parauri, kiri āhua waenga-parauri',
    '👩‍❤‍👨' => 'tokorua me te manawa: wahine, tāne',
    '👨‍❤‍👨' => 'tokorua me te manawa: tāne, tāne',
    '👩‍❤‍👩' => 'tokorua me te manawa: wahine, wahine',
    '👨‍👩‍👦' => 'whānau: tāne, wahine, tamatāne',
    '👨‍👩‍👧' => 'whānau: tāne, wahine, kōtiro',
    '👨‍👨‍👦' => 'whānau: tāne, tāne, tamatāne',
    '👨‍👨‍👧' => 'whānau: tāne, tāne, kōtiro',
    '👩‍👩‍👦' => 'whānau: wahine, wahine, tamatāne',
    '👩‍👩‍👧' => 'whānau: wahine, wahine, kōtiro',
    '👨‍👦‍👦' => 'whānau: tāne, tamatāne, tamatāne',
    '👨‍👧‍👦' => 'whānau: tāne, kōtiro, tamatāne',
    '👨‍👧‍👧' => 'whānau: tāne, kōtiro, kōtiro',
    '👩‍👦‍👦' => 'whānau: wahine, tamatāne, tamatāne',
    '👩‍👧‍👦' => 'whānau: wahine, kōtiro, tamatāne',
    '👩‍👧‍👧' => 'whānau: wahine, kōtiro, kōtiro',
    '👱🏻‍♂' => 'tāne mākekehu: kiri āhua māmā',
    '👱🏼‍♂' => 'tāne mākekehu: kiri āhua māmā-waenga',
    '👱🏽‍♂' => 'tāne mākekehu: kiri āhua waenga',
    '👱🏾‍♂' => 'tāne mākekehu: kiri āhua waenga-parauri',
    '👱🏿‍♂' => 'tāne mākekehu: kiri āhua parauri',
    '👱🏻‍♀' => 'wahine mākekehu: kiri āhua māmā',
    '👱🏼‍♀' => 'wahine mākekehu: kiri āhua māmā-waenga',
    '👱🏽‍♀' => 'wahine mākekehu: kiri āhua waenga',
    '👱🏾‍♀' => 'wahine mākekehu: kiri āhua waenga-parauri',
    '👱🏿‍♀' => 'wahine mākekehu: kiri āhua parauri',
    '🙍🏻‍♂' => 'tāne poururu: kiri āhua māmā',
    '🙍🏼‍♂' => 'tāne poururu: kiri āhua māmā-waenga',
    '🙍🏽‍♂' => 'tāne poururu: kiri āhua waenga',
    '🙍🏾‍♂' => 'tāne poururu: kiri āhua waenga-parauri',
    '🙍🏿‍♂' => 'tāne poururu: kiri āhua parauri',
    '🙍🏻‍♀' => 'wahine poururu: kiri āhua māmā',
    '🙍🏼‍♀' => 'wahine poururu: kiri āhua māmā-waenga',
    '🙍🏽‍♀' => 'wahine poururu: kiri āhua waenga',
    '🙍🏾‍♀' => 'wahine poururu: kiri āhua waenga-parauri',
    '🙍🏿‍♀' => 'wahine poururu: kiri āhua parauri',
    '🙎🏻‍♂' => 'tāne tupere: kiri āhua māmā',
    '🙎🏼‍♂' => 'tāne tupere: kiri āhua māmā-waenga',
    '🙎🏽‍♂' => 'tāne tupere: kiri āhua waenga',
    '🙎🏾‍♂' => 'tāne tupere: kiri āhua waenga-parauri',
    '🙎🏿‍♂' => 'tāne tupere: kiri āhua parauri',
    '🙎🏻‍♀' => 'wahine tupere: kiri āhua māmā',
    '🙎🏼‍♀' => 'wahine tupere: kiri āhua māmā-waenga',
    '🙎🏽‍♀' => 'wahine tupere: kiri āhua waenga',
    '🙎🏾‍♀' => 'wahine tupere: kiri āhua waenga-parauri',
    '🙎🏿‍♀' => 'wahine tupere: kiri āhua parauri',
    '🙅🏻‍♂' => 'tāne tohu ana KĀO: kiri āhua māmā',
    '🙅🏼‍♂' => 'tāne tohu ana KĀO: kiri āhua māmā-waenga',
    '🙅🏽‍♂' => 'tāne tohu ana KĀO: kiri āhua waenga',
    '🙅🏾‍♂' => 'tāne tohu ana KĀO: kiri āhua waenga-parauri',
    '🙅🏿‍♂' => 'tāne tohu ana KĀO: kiri āhua parauri',
    '🙅🏻‍♀' => 'wahine tohu ana KĀO: kiri āhua māmā',
    '🙅🏼‍♀' => 'wahine tohu ana KĀO: kiri āhua māmā-waenga',
    '🙅🏽‍♀' => 'wahine tohu ana KĀO: kiri āhua waenga',
    '🙅🏾‍♀' => 'wahine tohu ana KĀO: kiri āhua waenga-parauri',
    '🙅🏿‍♀' => 'wahine tohu ana KĀO: kiri āhua parauri',
    '🙆🏻‍♂' => 'tāne tohu ana ĀE: kiri āhua māmā',
    '🙆🏼‍♂' => 'tāne tohu ana ĀE: kiri āhua māmā-waenga',
    '🙆🏽‍♂' => 'tāne tohu ana ĀE: kiri āhua waenga',
    '🙆🏾‍♂' => 'tāne tohu ana ĀE: kiri āhua waenga-parauri',
    '🙆🏿‍♂' => 'tāne tohu ana ĀE: kiri āhua parauri',
    '🙆🏻‍♀' => 'wahine tohu ana ĀE: kiri āhua māmā',
    '🙆🏼‍♀' => 'wahine tohu ana ĀE: kiri āhua māmā-waenga',
    '🙆🏽‍♀' => 'wahine tohu ana ĀE: kiri āhua waenga',
    '🙆🏾‍♀' => 'wahine tohu ana ĀE: kiri āhua waenga-parauri',
    '🙆🏿‍♀' => 'wahine tohu ana ĀE: kiri āhua parauri',
    '💁🏻‍♂' => 'tāne ringa tāringi: kiri āhua māmā',
    '💁🏼‍♂' => 'tāne ringa tāringi: kiri āhua māmā-waenga',
    '💁🏽‍♂' => 'tāne ringa tāringi: kiri āhua waenga',
    '💁🏾‍♂' => 'tāne ringa tāringi: kiri āhua waenga-parauri',
    '💁🏿‍♂' => 'tāne ringa tāringi: kiri āhua parauri',
    '💁🏻‍♀' => 'wahine ringa tāringi: kiri āhua māmā',
    '💁🏼‍♀' => 'wahine ringa tāringi: kiri āhua māmā-waenga',
    '💁🏽‍♀' => 'wahine ringa tāringi: kiri āhua waenga',
    '💁🏾‍♀' => 'wahine ringa tāringi: kiri āhua waenga-parauri',
    '💁🏿‍♀' => 'wahine ringa tāringi: kiri āhua parauri',
    '🙋🏻‍♂' => 'tāne ringa tū: kiri āhua māmā',
    '🙋🏼‍♂' => 'tāne ringa tū: kiri āhua māmā-waenga',
    '🙋🏽‍♂' => 'tāne ringa tū: kiri āhua waenga',
    '🙋🏾‍♂' => 'tāne ringa tū: kiri āhua waenga-parauri',
    '🙋🏿‍♂' => 'tāne ringa tū: kiri āhua parauri',
    '🙋🏻‍♀' => 'wahine ringa tū: kiri āhua māmā',
    '🙋🏼‍♀' => 'wahine ringa tū: kiri āhua māmā-waenga',
    '🙋🏽‍♀' => 'wahine ringa tū: kiri āhua waenga',
    '🙋🏾‍♀' => 'wahine ringa tū: kiri āhua waenga-parauri',
    '🙋🏿‍♀' => 'wahine ringa tū: kiri āhua parauri',
    '🙇🏻‍♂' => 'tāne tuohu: kiri āhua māmā',
    '🙇🏼‍♂' => 'tāne tuohu: kiri āhua māmā-waenga',
    '🙇🏽‍♂' => 'tāne tuohu: kiri āhua waenga',
    '🙇🏾‍♂' => 'tāne tuohu: kiri āhua waenga-parauri',
    '🙇🏿‍♂' => 'tāne tuohu: kiri āhua parauri',
    '🙇🏻‍♀' => 'wahine tuohu: kiri āhua māmā',
    '🙇🏼‍♀' => 'wahine tuohu: kiri āhua māmā-waenga',
    '🙇🏽‍♀' => 'wahine tuohu: kiri āhua waenga',
    '🙇🏾‍♀' => 'wahine tuohu: kiri āhua waenga-parauri',
    '🙇🏿‍♀' => 'wahine tuohu: kiri āhua parauri',
    '🤦🏻‍♂' => 'tāne ringakanohi: kiri āhua māmā',
    '🤦🏼‍♂' => 'tāne ringakanohi: kiri āhua māmā-waenga',
    '🤦🏽‍♂' => 'tāne ringakanohi: kiri āhua waenga',
    '🤦🏾‍♂' => 'tāne ringakanohi: kiri āhua waenga-parauri',
    '🤦🏿‍♂' => 'tāne ringakanohi: kiri āhua parauri',
    '🤦🏻‍♀' => 'wahine ringakanohi: kiri āhua māmā',
    '🤦🏼‍♀' => 'wahine ringakanohi: kiri āhua māmā-waenga',
    '🤦🏽‍♀' => 'wahine ringakanohi: kiri āhua waenga',
    '🤦🏾‍♀' => 'wahine ringakanohi: kiri āhua waenga-parauri',
    '🤦🏿‍♀' => 'wahine ringakanohi: kiri āhua parauri',
    '🤷🏻‍♂' => 'tāne hiki-pakihiwi: kiri āhua māmā',
    '🤷🏼‍♂' => 'tāne hiki-pakihiwi: kiri āhua māmā-waenga',
    '🤷🏽‍♂' => 'tāne hiki-pakihiwi: kiri āhua waenga',
    '🤷🏾‍♂' => 'tāne hiki-pakihiwi: kiri āhua waenga-parauri',
    '🤷🏿‍♂' => 'tāne hiki-pakihiwi: kiri āhua parauri',
    '🤷🏻‍♀' => 'wahine hiki-pakihiwi: kiri āhua māmā',
    '🤷🏼‍♀' => 'wahine hiki-pakihiwi: kiri āhua māmā-waenga',
    '🤷🏽‍♀' => 'wahine hiki-pakihiwi: kiri āhua waenga',
    '🤷🏾‍♀' => 'wahine hiki-pakihiwi: kiri āhua waenga-parauri',
    '🤷🏿‍♀' => 'wahine hiki-pakihiwi: kiri āhua parauri',
    '👨🏻‍⚕' => 'kaimahi hauora tāne: kiri āhua māmā',
    '👨🏼‍⚕' => 'kaimahi hauora tāne: kiri āhua māmā-waenga',
    '👨🏽‍⚕' => 'kaimahi hauora tāne: kiri āhua waenga',
    '👨🏾‍⚕' => 'kaimahi hauora tāne: kiri āhua waenga-parauri',
    '👨🏿‍⚕' => 'kaimahi hauora tāne: kiri āhua parauri',
    '👩🏻‍⚕' => 'wahine atawhai hauora: kiri āhua māmā',
    '👩🏼‍⚕' => 'wahine atawhai hauora: kiri āhua māmā-waenga',
    '👩🏽‍⚕' => 'wahine atawhai hauora: kiri āhua waenga',
    '👩🏾‍⚕' => 'wahine atawhai hauora: kiri āhua waenga-parauri',
    '👩🏿‍⚕' => 'wahine atawhai hauora: kiri āhua parauri',
    '👨🏻‍🎓' => 'ākonga tāne: kiri āhua māmā',
    '👨🏼‍🎓' => 'ākonga tāne: kiri āhua māmā-waenga',
    '👨🏽‍🎓' => 'ākonga tāne: kiri āhua waenga',
    '👨🏾‍🎓' => 'ākonga tāne: kiri āhua waenga-parauri',
    '👨🏿‍🎓' => 'ākonga tāne: kiri āhua parauri',
    '👩🏻‍🎓' => 'ākonga wahine: kiri āhua māmā',
    '👩🏼‍🎓' => 'ākonga wahine: kiri āhua māmā-waenga',
    '👩🏽‍🎓' => 'ākonga wahine: kiri āhua waenga',
    '👩🏾‍🎓' => 'ākonga wahine: kiri āhua waenga-parauri',
    '👩🏿‍🎓' => 'ākonga wahine: kiri āhua parauri',
    '👨🏻‍🏫' => 'tāne kaiako: kiri āhua māmā',
    '👨🏼‍🏫' => 'tāne kaiako: kiri āhua māmā-waenga',
    '👨🏽‍🏫' => 'tāne kaiako: kiri āhua waenga',
    '👨🏾‍🏫' => 'tāne kaiako: kiri āhua waenga-parauri',
    '👨🏿‍🏫' => 'tāne kaiako: kiri āhua parauri',
    '👩🏻‍🏫' => 'kaiako wahine: kiri āhua māmā',
    '👩🏼‍🏫' => 'kaiako wahine: kiri āhua māmā-waenga',
    '👩🏽‍🏫' => 'kaiako wahine: kiri āhua waenga',
    '👩🏾‍🏫' => 'kaiako wahine: kiri āhua waenga-parauri',
    '👩🏿‍🏫' => 'kaiako wahine: kiri āhua parauri',
    '👨🏻‍⚖' => 'kaiwhakawā tāne: kiri āhua māmā',
    '👨🏼‍⚖' => 'kaiwhakawā tāne: kiri āhua māmā-waenga',
    '👨🏽‍⚖' => 'kaiwhakawā tāne: kiri āhua waenga',
    '👨🏾‍⚖' => 'kaiwhakawā tāne: kiri āhua waenga-parauri',
    '👨🏿‍⚖' => 'kaiwhakawā tāne: kiri āhua parauri',
    '👩🏻‍⚖' => 'kaiwhakawā wahine: kiri āhua māmā',
    '👩🏼‍⚖' => 'kaiwhakawā wahine: kiri āhua māmā-waenga',
    '👩🏽‍⚖' => 'kaiwhakawā wahine: kiri āhua waenga',
    '👩🏾‍⚖' => 'kaiwhakawā wahine: kiri āhua waenga-parauri',
    '👩🏿‍⚖' => 'kaiwhakawā wahine: kiri āhua parauri',
    '👨🏻‍🌾' => 'kaipāmu tāne: kiri āhua māmā',
    '👨🏼‍🌾' => 'kaipāmu tāne: kiri āhua māmā-waenga',
    '👨🏽‍🌾' => 'kaipāmu tāne: kiri āhua waenga',
    '👨🏾‍🌾' => 'kaipāmu tāne: kiri āhua waenga-parauri',
    '👨🏿‍🌾' => 'kaipāmu tāne: kiri āhua parauri',
    '👩🏻‍🌾' => 'wahine kaipāmu: kiri āhua māmā',
    '👩🏼‍🌾' => 'wahine kaipāmu: kiri āhua māmā-waenga',
    '👩🏽‍🌾' => 'wahine kaipāmu: kiri āhua waenga',
    '👩🏾‍🌾' => 'wahine kaipāmu: kiri āhua waenga-parauri',
    '👩🏿‍🌾' => 'wahine kaipāmu: kiri āhua parauri',
    '👨🏻‍🍳' => 'kaitao tāne: kiri āhua māmā',
    '👨🏼‍🍳' => 'kaitao tāne: kiri āhua māmā-waenga',
    '👨🏽‍🍳' => 'kaitao tāne: kiri āhua waenga',
    '👨🏾‍🍳' => 'kaitao tāne: kiri āhua waenga-parauri',
    '👨🏿‍🍳' => 'kaitao tāne: kiri āhua parauri',
    '👩🏻‍🍳' => 'kaitao wahine: kiri āhua māmā',
    '👩🏼‍🍳' => 'kaitao wahine: kiri āhua māmā-waenga',
    '👩🏽‍🍳' => 'kaitao wahine: kiri āhua waenga',
    '👩🏾‍🍳' => 'kaitao wahine: kiri āhua waenga-parauri',
    '👩🏿‍🍳' => 'kaitao wahine: kiri āhua parauri',
    '👨🏻‍🔧' => 'kaiaka mīhini tāne: kiri āhua māmā',
    '👨🏼‍🔧' => 'kaiaka mīhini tāne: kiri āhua māmā-waenga',
    '👨🏽‍🔧' => 'kaiaka mīhini tāne: kiri āhua waenga',
    '👨🏾‍🔧' => 'kaiaka mīhini tāne: kiri āhua waenga-parauri',
    '👨🏿‍🔧' => 'kaiaka mīhini tāne: kiri āhua parauri',
    '👩🏻‍🔧' => 'kaiaka mīhini wahine: kiri āhua māmā',
    '👩🏼‍🔧' => 'kaiaka mīhini wahine: kiri āhua māmā-waenga',
    '👩🏽‍🔧' => 'kaiaka mīhini wahine: kiri āhua waenga',
    '👩🏾‍🔧' => 'kaiaka mīhini wahine: kiri āhua waenga-parauri',
    '👩🏿‍🔧' => 'kaiaka mīhini wahine: kiri āhua parauri',
    '👨🏻‍🏭' => 'tāne mahi wheketere: kiri āhua māmā',
    '👨🏼‍🏭' => 'tāne mahi wheketere: kiri āhua māmā-waenga',
    '👨🏽‍🏭' => 'tāne mahi wheketere: kiri āhua waenga',
    '👨🏾‍🏭' => 'tāne mahi wheketere: kiri āhua waenga-parauri',
    '👨🏿‍🏭' => 'tāne mahi wheketere: kiri āhua parauri',
    '👩🏻‍🏭' => 'wahine mahi wheketere: kiri āhua māmā',
    '👩🏼‍🏭' => 'wahine mahi wheketere: kiri āhua māmā-waenga',
    '👩🏽‍🏭' => 'wahine mahi wheketere: kiri āhua waenga',
    '👩🏾‍🏭' => 'wahine mahi wheketere: kiri āhua waenga-parauri',
    '👩🏿‍🏭' => 'wahine mahi wheketere: kiri āhua parauri',
    '👨🏻‍💼' => 'kaimahi tari tāne: kiri āhua māmā',
    '👨🏼‍💼' => 'kaimahi tari tāne: kiri āhua māmā-waenga',
    '👨🏽‍💼' => 'kaimahi tari tāne: kiri āhua waenga',
    '👨🏾‍💼' => 'kaimahi tari tāne: kiri āhua waenga-parauri',
    '👨🏿‍💼' => 'kaimahi tari tāne: kiri āhua parauri',
    '👩🏻‍💼' => 'kaimahi tari wahine: kiri āhua māmā',
    '👩🏼‍💼' => 'kaimahi tari wahine: kiri āhua māmā-waenga',
    '👩🏽‍💼' => 'kaimahi tari wahine: kiri āhua waenga',
    '👩🏾‍💼' => 'kaimahi tari wahine: kiri āhua waenga-parauri',
    '👩🏿‍💼' => 'kaimahi tari wahine: kiri āhua parauri',
    '👨🏻‍🔬' => 'kaimātai pūtaiao tāne: kiri āhua māmā',
    '👨🏼‍🔬' => 'kaimātai pūtaiao tāne: kiri āhua māmā-waenga',
    '👨🏽‍🔬' => 'kaimātai pūtaiao tāne: kiri āhua waenga',
    '👨🏾‍🔬' => 'kaimātai pūtaiao tāne: kiri āhua waenga-parauri',
    '👨🏿‍🔬' => 'kaimātai pūtaiao tāne: kiri āhua parauri',
    '👩🏻‍🔬' => 'kaimātai pūtaiao wahine: kiri āhua māmā',
    '👩🏼‍🔬' => 'kaimātai pūtaiao wahine: kiri āhua māmā-waenga',
    '👩🏽‍🔬' => 'kaimātai pūtaiao wahine: kiri āhua waenga',
    '👩🏾‍🔬' => 'kaimātai pūtaiao wahine: kiri āhua waenga-parauri',
    '👩🏿‍🔬' => 'kaimātai pūtaiao wahine: kiri āhua parauri',
    '👨🏻‍💻' => 'kaihangarau tāne: kiri āhua māmā',
    '👨🏼‍💻' => 'kaihangarau tāne: kiri āhua māmā-waenga',
    '👨🏽‍💻' => 'kaihangarau tāne: kiri āhua waenga',
    '👨🏾‍💻' => 'kaihangarau tāne: kiri āhua waenga-parauri',
    '👨🏿‍💻' => 'kaihangarau tāne: kiri āhua parauri',
    '👩🏻‍💻' => 'kaihangarau wahine: kiri āhua māmā',
    '👩🏼‍💻' => 'kaihangarau wahine: kiri āhua māmā-waenga',
    '👩🏽‍💻' => 'kaihangarau wahine: kiri āhua waenga',
    '👩🏾‍💻' => 'kaihangarau wahine: kiri āhua waenga-parauri',
    '👩🏿‍💻' => 'kaihangarau wahine: kiri āhua parauri',
    '👨🏻‍🎤' => 'kaiwaiata tāne: kiri āhua māmā',
    '👨🏼‍🎤' => 'kaiwaiata tāne: kiri āhua māmā-waenga',
    '👨🏽‍🎤' => 'kaiwaiata tāne: kiri āhua waenga',
    '👨🏾‍🎤' => 'kaiwaiata tāne: kiri āhua waenga-parauri',
    '👨🏿‍🎤' => 'kaiwaiata tāne: kiri āhua parauri',
    '👩🏻‍🎤' => 'kaiwaiata wahine: kiri āhua māmā',
    '👩🏼‍🎤' => 'kaiwaiata wahine: kiri āhua māmā-waenga',
    '👩🏽‍🎤' => 'kaiwaiata wahine: kiri āhua waenga',
    '👩🏾‍🎤' => 'kaiwaiata wahine: kiri āhua waenga-parauri',
    '👩🏿‍🎤' => 'kaiwaiata wahine: kiri āhua parauri',
    '👨🏻‍🎨' => 'tāne toi: kiri āhua māmā',
    '👨🏼‍🎨' => 'tāne toi: kiri āhua māmā-waenga',
    '👨🏽‍🎨' => 'tāne toi: kiri āhua waenga',
    '👨🏾‍🎨' => 'tāne toi: kiri āhua waenga-parauri',
    '👨🏿‍🎨' => 'tāne toi: kiri āhua parauri',
    '👩🏻‍🎨' => 'wahine toi: kiri āhua māmā',
    '👩🏼‍🎨' => 'wahine toi: kiri āhua māmā-waenga',
    '👩🏽‍🎨' => 'wahine toi: kiri āhua waenga',
    '👩🏾‍🎨' => 'wahine toi: kiri āhua waenga-parauri',
    '👩🏿‍🎨' => 'wahine toi: kiri āhua parauri',
    '👨🏻‍✈' => 'paerata tāne: kiri āhua māmā',
    '👨🏼‍✈' => 'paerata tāne: kiri āhua māmā-waenga',
    '👨🏽‍✈' => 'paerata tāne: kiri āhua waenga',
    '👨🏾‍✈' => 'paerata tāne: kiri āhua waenga-parauri',
    '👨🏿‍✈' => 'paerata tāne: kiri āhua parauri',
    '👩🏻‍✈' => 'paerata wahine: kiri āhua māmā',
    '👩🏼‍✈' => 'paerata wahine: kiri āhua māmā-waenga',
    '👩🏽‍✈' => 'paerata wahine: kiri āhua waenga',
    '👩🏾‍✈' => 'paerata wahine: kiri āhua waenga-parauri',
    '👩🏿‍✈' => 'paerata wahine: kiri āhua parauri',
    '👨🏻‍🚀' => 'kaiātea tāne: kiri āhua māmā',
    '👨🏼‍🚀' => 'kaiātea tāne: kiri āhua māmā-waenga',
    '👨🏽‍🚀' => 'kaiātea tāne: kiri āhua waenga',
    '👨🏾‍🚀' => 'kaiātea tāne: kiri āhua waenga-parauri',
    '👨🏿‍🚀' => 'kaiātea tāne: kiri āhua parauri',
    '👩🏻‍🚀' => 'kaiātea wahine: kiri āhua māmā',
    '👩🏼‍🚀' => 'kaiātea wahine: kiri āhua māmā-waenga',
    '👩🏽‍🚀' => 'kaiātea wahine: kiri āhua waenga',
    '👩🏾‍🚀' => 'kaiātea wahine: kiri āhua waenga-parauri',
    '👩🏿‍🚀' => 'kaiātea wahine: kiri āhua parauri',
    '👨🏻‍🚒' => 'kaitinei-ahi tāne: kiri āhua māmā',
    '👨🏼‍🚒' => 'kaitinei-ahi tāne: kiri āhua māmā-waenga',
    '👨🏽‍🚒' => 'kaitinei-ahi tāne: kiri āhua waenga',
    '👨🏾‍🚒' => 'kaitinei-ahi tāne: kiri āhua waenga-parauri',
    '👨🏿‍🚒' => 'kaitinei-ahi tāne: kiri āhua parauri',
    '👩🏻‍🚒' => 'kaitinei-ahi wahine: kiri āhua māmā',
    '👩🏼‍🚒' => 'kaitinei-ahi wahine: kiri āhua māmā-waenga',
    '👩🏽‍🚒' => 'kaitinei-ahi wahine: kiri āhua waenga',
    '👩🏾‍🚒' => 'kaitinei-ahi wahine: kiri āhua waenga-parauri',
    '👩🏿‍🚒' => 'kaitinei-ahi wahine: kiri āhua parauri',
    '👮🏻‍♂' => 'āpiha pirihimana tāne: kiri āhua māmā',
    '👮🏼‍♂' => 'āpiha pirihimana tāne: kiri āhua māmā-waenga',
    '👮🏽‍♂' => 'āpiha pirihimana tāne: kiri āhua waenga',
    '👮🏾‍♂' => 'āpiha pirihimana tāne: kiri āhua waenga-parauri',
    '👮🏿‍♂' => 'āpiha pirihimana tāne: kiri āhua parauri',
    '👮🏻‍♀' => 'āpiha pirihimana wahine: kiri āhua māmā',
    '👮🏼‍♀' => 'āpiha pirihimana wahine: kiri āhua māmā-waenga',
    '👮🏽‍♀' => 'āpiha pirihimana wahine: kiri āhua waenga',
    '👮🏾‍♀' => 'āpiha pirihimana wahine: kiri āhua waenga-parauri',
    '👮🏿‍♀' => 'āpiha pirihimana wahine: kiri āhua parauri',
    '🕵🏻‍♂' => 'kaikimihara tāne: kiri āhua māmā',
    '🕵🏼‍♂' => 'kaikimihara tāne: kiri āhua māmā-waenga',
    '🕵🏽‍♂' => 'kaikimihara tāne: kiri āhua waenga',
    '🕵🏾‍♂' => 'kaikimihara tāne: kiri āhua waenga-parauri',
    '🕵🏿‍♂' => 'kaikimihara tāne: kiri āhua parauri',
    '🕵🏻‍♀' => 'kaikimihara wahine: kiri āhua māmā',
    '🕵🏼‍♀' => 'kaikimihara wahine: kiri āhua māmā-waenga',
    '🕵🏽‍♀' => 'kaikimihara wahine: kiri āhua waenga',
    '🕵🏾‍♀' => 'kaikimihara wahine: kiri āhua waenga-parauri',
    '🕵🏿‍♀' => 'kaikimihara wahine: kiri āhua parauri',
    '💂🏻‍♂' => 'tautieki tāne: kiri āhua māmā',
    '💂🏼‍♂' => 'tautieki tāne: kiri āhua māmā-waenga',
    '💂🏽‍♂' => 'tautieki tāne: kiri āhua waenga',
    '💂🏾‍♂' => 'tautieki tāne: kiri āhua waenga-parauri',
    '💂🏿‍♂' => 'tautieki tāne: kiri āhua parauri',
    '💂🏻‍♀' => 'tautieki wahine: kiri āhua māmā',
    '💂🏼‍♀' => 'tautieki wahine: kiri āhua māmā-waenga',
    '💂🏽‍♀' => 'tautieki wahine: kiri āhua waenga',
    '💂🏾‍♀' => 'tautieki wahine: kiri āhua waenga-parauri',
    '💂🏿‍♀' => 'tautieki wahine: kiri āhua parauri',
    '👷🏻‍♂' => 'kaimahi hangatanga tāne: kiri āhua māmā',
    '👷🏼‍♂' => 'kaimahi hangatanga tāne: kiri āhua māmā-waenga',
    '👷🏽‍♂' => 'kaimahi hangatanga tāne: kiri āhua waenga',
    '👷🏾‍♂' => 'kaimahi hangatanga tāne: kiri āhua waenga-parauri',
    '👷🏿‍♂' => 'kaimahi hangatanga tāne: kiri āhua parauri',
    '👷🏻‍♀' => 'kaimahi hangatanga wahine: kiri āhua māmā',
    '👷🏼‍♀' => 'kaimahi hangatanga wahine: kiri āhua māmā-waenga',
    '👷🏽‍♀' => 'kaimahi hangatanga wahine: kiri āhua waenga',
    '👷🏾‍♀' => 'kaimahi hangatanga wahine: kiri āhua waenga-parauri',
    '👷🏿‍♀' => 'kaimahi hangatanga wahine: kiri āhua parauri',
    '👳🏻‍♂' => 'tāne mau pōtae kameta: kiri āhua māmā',
    '👳🏼‍♂' => 'tāne mau pōtae kameta: kiri āhua māmā-waenga',
    '👳🏽‍♂' => 'tāne mau pōtae kameta: kiri āhua waenga',
    '👳🏾‍♂' => 'tāne mau pōtae kameta: kiri āhua waenga-parauri',
    '👳🏿‍♂' => 'tāne mau pōtae kameta: kiri āhua parauri',
    '👳🏻‍♀' => 'wahine mau pōtae kameta: kiri āhua māmā',
    '👳🏼‍♀' => 'wahine mau pōtae kameta: kiri āhua māmā-waenga',
    '👳🏽‍♀' => 'wahine mau pōtae kameta: kiri āhua waenga',
    '👳🏾‍♀' => 'wahine mau pōtae kameta: kiri āhua waenga-parauri',
    '👳🏿‍♀' => 'wahine mau pōtae kameta: kiri āhua parauri',
    '🧙🏻‍♂' => 'tohunga matakite: kiri āhua māmā',
    '🧙🏼‍♂' => 'tohunga matakite: kiri āhua māmā-waenga',
    '🧙🏽‍♂' => 'tohunga matakite: kiri āhua waenga',
    '🧙🏾‍♂' => 'tohunga matakite: kiri āhua waenga-parauri',
    '🧙🏿‍♂' => 'tohunga matakite: kiri āhua parauri',
    '🧙🏻‍♀' => 'wahine matakite: kiri āhua māmā',
    '🧙🏼‍♀' => 'wahine matakite: kiri āhua māmā-waenga',
    '🧙🏽‍♀' => 'wahine matakite: kiri āhua waenga',
    '🧙🏾‍♀' => 'wahine matakite: kiri āhua waenga-parauri',
    '🧙🏿‍♀' => 'wahine matakite: kiri āhua parauri',
    '🧚🏻‍♂' => 'patupaiarehe tāne: kiri āhua māmā',
    '🧚🏼‍♂' => 'patupaiarehe tāne: kiri āhua māmā-waenga',
    '🧚🏽‍♂' => 'patupaiarehe tāne: kiri āhua waenga',
    '🧚🏾‍♂' => 'patupaiarehe tāne: kiri āhua waenga-parauri',
    '🧚🏿‍♂' => 'patupaiarehe tāne: kiri āhua parauri',
    '🧚🏻‍♀' => 'patupaiarehe wahine: kiri āhua māmā',
    '🧚🏼‍♀' => 'patupaiarehe wahine: kiri āhua māmā-waenga',
    '🧚🏽‍♀' => 'patupaiarehe wahine: kiri āhua waenga',
    '🧚🏾‍♀' => 'patupaiarehe wahine: kiri āhua waenga-parauri',
    '🧚🏿‍♀' => 'patupaiarehe wahine: kiri āhua parauri',
    '🧛🏻‍♂' => 'tāne kaitoto: kiri āhua māmā',
    '🧛🏼‍♂' => 'tāne kaitoto: kiri āhua māmā-waenga',
    '🧛🏽‍♂' => 'tāne kaitoto: kiri āhua waenga',
    '🧛🏾‍♂' => 'tāne kaitoto: kiri āhua waenga-parauri',
    '🧛🏿‍♂' => 'tāne kaitoto: kiri āhua parauri',
    '🧛🏻‍♀' => 'wahine kaitoto: kiri āhua māmā',
    '🧛🏼‍♀' => 'wahine kaitoto: kiri āhua māmā-waenga',
    '🧛🏽‍♀' => 'wahine kaitoto: kiri āhua waenga',
    '🧛🏾‍♀' => 'wahine kaitoto: kiri āhua waenga-parauri',
    '🧛🏿‍♀' => 'wahine kaitoto: kiri āhua parauri',
    '🧜🏻‍♂' => 'tāne-ika: kiri āhua māmā',
    '🧜🏼‍♂' => 'tāne-ika: kiri āhua māmā-waenga',
    '🧜🏽‍♂' => 'tāne-ika: kiri āhua waenga',
    '🧜🏾‍♂' => 'tāne-ika: kiri āhua waenga-parauri',
    '🧜🏿‍♂' => 'tāne-ika: kiri āhua parauri',
    '🧜🏻‍♀' => 'hine-ika: kiri āhua māmā',
    '🧜🏼‍♀' => 'hine-ika: kiri āhua māmā-waenga',
    '🧜🏽‍♀' => 'hine-ika: kiri āhua waenga',
    '🧜🏾‍♀' => 'hine-ika: kiri āhua waenga-parauri',
    '🧜🏿‍♀' => 'hine-ika: kiri āhua parauri',
    '🧝🏻‍♂' => 'erepe tāne: kiri āhua māmā',
    '🧝🏼‍♂' => 'erepe tāne: kiri āhua māmā-waenga',
    '🧝🏽‍♂' => 'erepe tāne: kiri āhua waenga',
    '🧝🏾‍♂' => 'erepe tāne: kiri āhua waenga-parauri',
    '🧝🏿‍♂' => 'erepe tāne: kiri āhua parauri',
    '🧝🏻‍♀' => 'erepe wahine: kiri āhua māmā',
    '🧝🏼‍♀' => 'erepe wahine: kiri āhua māmā-waenga',
    '🧝🏽‍♀' => 'erepe wahine: kiri āhua waenga',
    '🧝🏾‍♀' => 'erepe wahine: kiri āhua waenga-parauri',
    '🧝🏿‍♀' => 'erepe wahine: kiri āhua parauri',
    '💆🏻‍♂' => 'tāne whiwhi mirimiri: kiri āhua māmā',
    '💆🏼‍♂' => 'tāne whiwhi mirimiri: kiri āhua māmā-waenga',
    '💆🏽‍♂' => 'tāne whiwhi mirimiri: kiri āhua waenga',
    '💆🏾‍♂' => 'tāne whiwhi mirimiri: kiri āhua waenga-parauri',
    '💆🏿‍♂' => 'tāne whiwhi mirimiri: kiri āhua parauri',
    '💆🏻‍♀' => 'wahine whiwhi mirimiri: kiri āhua māmā',
    '💆🏼‍♀' => 'wahine whiwhi mirimiri: kiri āhua māmā-waenga',
    '💆🏽‍♀' => 'wahine whiwhi mirimiri: kiri āhua waenga',
    '💆🏾‍♀' => 'wahine whiwhi mirimiri: kiri āhua waenga-parauri',
    '💆🏿‍♀' => 'wahine whiwhi mirimiri: kiri āhua parauri',
    '💇🏻‍♂' => 'tāne whiwhi kutinga makawe: kiri āhua māmā',
    '💇🏼‍♂' => 'tāne whiwhi kutinga makawe: kiri āhua māmā-waenga',
    '💇🏽‍♂' => 'tāne whiwhi kutinga makawe: kiri āhua waenga',
    '💇🏾‍♂' => 'tāne whiwhi kutinga makawe: kiri āhua waenga-parauri',
    '💇🏿‍♂' => 'tāne whiwhi kutinga makawe: kiri āhua parauri',
    '💇🏻‍♀' => 'wahine whiwhi kutinga makawe: kiri āhua māmā',
    '💇🏼‍♀' => 'wahine whiwhi kutinga makawe: kiri āhua māmā-waenga',
    '💇🏽‍♀' => 'wahine whiwhi kutinga makawe: kiri āhua waenga',
    '💇🏾‍♀' => 'wahine whiwhi kutinga makawe: kiri āhua waenga-parauri',
    '💇🏿‍♀' => 'wahine whiwhi kutinga makawe: kiri āhua parauri',
    '🚶🏻‍♂' => 'tāne hīkoi: kiri āhua māmā',
    '🚶🏼‍♂' => 'tāne hīkoi: kiri āhua māmā-waenga',
    '🚶🏽‍♂' => 'tāne hīkoi: kiri āhua waenga',
    '🚶🏾‍♂' => 'tāne hīkoi: kiri āhua waenga-parauri',
    '🚶🏿‍♂' => 'tāne hīkoi: kiri āhua parauri',
    '🚶🏻‍♀' => 'wahine hīkoi: kiri āhua māmā',
    '🚶🏼‍♀' => 'wahine hīkoi: kiri āhua māmā-waenga',
    '🚶🏽‍♀' => 'wahine hīkoi: kiri āhua waenga',
    '🚶🏾‍♀' => 'wahine hīkoi: kiri āhua waenga-parauri',
    '🚶🏿‍♀' => 'wahine hīkoi: kiri āhua parauri',
    '🏃🏻‍♂' => 'tāne oma: kiri āhua māmā',
    '🏃🏼‍♂' => 'tāne oma: kiri āhua māmā-waenga',
    '🏃🏽‍♂' => 'tāne oma: kiri āhua waenga',
    '🏃🏾‍♂' => 'tāne oma: kiri āhua waenga-parauri',
    '🏃🏿‍♂' => 'tāne oma: kiri āhua parauri',
    '🏃🏻‍♀' => 'wahine oma: kiri āhua māmā',
    '🏃🏼‍♀' => 'wahine oma: kiri āhua māmā-waenga',
    '🏃🏽‍♀' => 'wahine oma: kiri āhua waenga',
    '🏃🏾‍♀' => 'wahine oma: kiri āhua waenga-parauri',
    '🏃🏿‍♀' => 'wahine oma: kiri āhua parauri',
    '👯🏻‍♀' => 'wāhine taringa rāpeti whakangahau: kiri āhua māmā',
    '👯🏼‍♀' => 'wāhine taringa rāpeti whakangahau: kiri āhua māmā-waenga',
    '👯🏽‍♀' => 'wāhine taringa rāpeti whakangahau: kiri āhua waenga',
    '👯🏾‍♀' => 'wāhine taringa rāpeti whakangahau: kiri āhua waenga-parauri',
    '👯🏿‍♀' => 'wāhine taringa rāpeti whakangahau: kiri āhua parauri',
    '👯🏻‍♂' => 'tāne taringa rāpeti whakangahau: kiri āhua māmā',
    '👯🏼‍♂' => 'tāne taringa rāpeti whakangahau: kiri āhua māmā-waenga',
    '👯🏽‍♂' => 'tāne taringa rāpeti whakangahau: kiri āhua waenga',
    '👯🏾‍♂' => 'tāne taringa rāpeti whakangahau: kiri āhua waenga-parauri',
    '👯🏿‍♂' => 'tāne taringa rāpeti whakangahau: kiri āhua parauri',
    '🧖🏻‍♂' => 'tāne rō taiwhanga mamaoa: kiri āhua māmā',
    '🧖🏼‍♂' => 'tāne rō taiwhanga mamaoa: kiri āhua māmā-waenga',
    '🧖🏽‍♂' => 'tāne rō taiwhanga mamaoa: kiri āhua waenga',
    '🧖🏾‍♂' => 'tāne rō taiwhanga mamaoa: kiri āhua waenga-parauri',
    '🧖🏿‍♂' => 'tāne rō taiwhanga mamaoa: kiri āhua parauri',
    '🧖🏻‍♀' => 'wahine rō taiwhanga mamaoa: kiri āhua māmā',
    '🧖🏼‍♀' => 'wahine rō taiwhanga mamaoa: kiri āhua māmā-waenga',
    '🧖🏽‍♀' => 'wahine rō taiwhanga mamaoa: kiri āhua waenga',
    '🧖🏾‍♀' => 'wahine rō taiwhanga mamaoa: kiri āhua waenga-parauri',
    '🧖🏿‍♀' => 'wahine rō taiwhanga mamaoa: kiri āhua parauri',
    '🧗🏻‍♂' => 'tāne piki: kiri āhua māmā',
    '🧗🏼‍♂' => 'tāne piki: kiri āhua māmā-waenga',
    '🧗🏽‍♂' => 'tāne piki: kiri āhua waenga',
    '🧗🏾‍♂' => 'tāne piki: kiri āhua waenga-parauri',
    '🧗🏿‍♂' => 'tāne piki: kiri āhua parauri',
    '🧗🏻‍♀' => 'wahine piki: kiri āhua māmā',
    '🧗🏼‍♀' => 'wahine piki: kiri āhua māmā-waenga',
    '🧗🏽‍♀' => 'wahine piki: kiri āhua waenga',
    '🧗🏾‍♀' => 'wahine piki: kiri āhua waenga-parauri',
    '🧗🏿‍♀' => 'wahine piki: kiri āhua parauri',
    '🏌🏻‍♂' => 'tāne haupōro: kiri āhua māmā',
    '🏌🏼‍♂' => 'tāne haupōro: kiri āhua māmā-waenga',
    '🏌🏽‍♂' => 'tāne haupōro: kiri āhua waenga',
    '🏌🏾‍♂' => 'tāne haupōro: kiri āhua waenga-parauri',
    '🏌🏿‍♂' => 'tāne haupōro: kiri āhua parauri',
    '🏌🏻‍♀' => 'wahine haupōro: kiri āhua māmā',
    '🏌🏼‍♀' => 'wahine haupōro: kiri āhua māmā-waenga',
    '🏌🏽‍♀' => 'wahine haupōro: kiri āhua waenga',
    '🏌🏾‍♀' => 'wahine haupōro: kiri āhua waenga-parauri',
    '🏌🏿‍♀' => 'wahine haupōro: kiri āhua parauri',
    '🏄🏻‍♂' => 'tāne whakaheke ngaru: kiri āhua māmā',
    '🏄🏼‍♂' => 'tāne whakaheke ngaru: kiri āhua māmā-waenga',
    '🏄🏽‍♂' => 'tāne whakaheke ngaru: kiri āhua waenga',
    '🏄🏾‍♂' => 'tāne whakaheke ngaru: kiri āhua waenga-parauri',
    '🏄🏿‍♂' => 'tāne whakaheke ngaru: kiri āhua parauri',
    '🏄🏻‍♀' => 'wahine whakaheke ngaru: kiri āhua māmā',
    '🏄🏼‍♀' => 'wahine whakaheke ngaru: kiri āhua māmā-waenga',
    '🏄🏽‍♀' => 'wahine whakaheke ngaru: kiri āhua waenga',
    '🏄🏾‍♀' => 'wahine whakaheke ngaru: kiri āhua waenga-parauri',
    '🏄🏿‍♀' => 'wahine whakaheke ngaru: kiri āhua parauri',
    '🚣🏻‍♂' => 'tāne hoe waka: kiri āhua māmā',
    '🚣🏼‍♂' => 'tāne hoe waka: kiri āhua māmā-waenga',
    '🚣🏽‍♂' => 'tāne hoe waka: kiri āhua waenga',
    '🚣🏾‍♂' => 'tāne hoe waka: kiri āhua waenga-parauri',
    '🚣🏿‍♂' => 'tāne hoe waka: kiri āhua parauri',
    '🚣🏻‍♀' => 'wahine hoe waka: kiri āhua māmā',
    '🚣🏼‍♀' => 'wahine hoe waka: kiri āhua māmā-waenga',
    '🚣🏽‍♀' => 'wahine hoe waka: kiri āhua waenga',
    '🚣🏾‍♀' => 'wahine hoe waka: kiri āhua waenga-parauri',
    '🚣🏿‍♀' => 'wahine hoe waka: kiri āhua parauri',
    '🏊🏻‍♂' => 'tāne kauhoe: kiri āhua māmā',
    '🏊🏼‍♂' => 'tāne kauhoe: kiri āhua māmā-waenga',
    '🏊🏽‍♂' => 'tāne kauhoe: kiri āhua waenga',
    '🏊🏾‍♂' => 'tāne kauhoe: kiri āhua waenga-parauri',
    '🏊🏿‍♂' => 'tāne kauhoe: kiri āhua parauri',
    '🏊🏻‍♀' => 'wahine kauhoe: kiri āhua māmā',
    '🏊🏼‍♀' => 'wahine kauhoe: kiri āhua māmā-waenga',
    '🏊🏽‍♀' => 'wahine kauhoe: kiri āhua waenga',
    '🏊🏾‍♀' => 'wahine kauhoe: kiri āhua waenga-parauri',
    '🏊🏿‍♀' => 'wahine kauhoe: kiri āhua parauri',
    '⛹🏻‍♂' => 'tāne tāwhana pōro: kiri āhua māmā',
    '⛹🏼‍♂' => 'tāne tāwhana pōro: kiri āhua māmā-waenga',
    '⛹🏽‍♂' => 'tāne tāwhana pōro: kiri āhua waenga',
    '⛹🏾‍♂' => 'tāne tāwhana pōro: kiri āhua waenga-parauri',
    '⛹🏿‍♂' => 'tāne tāwhana pōro: kiri āhua parauri',
    '⛹🏻‍♀' => 'wahine tāwhana pōro: kiri āhua māmā',
    '⛹🏼‍♀' => 'wahine tāwhana pōro: kiri āhua māmā-waenga',
    '⛹🏽‍♀' => 'wahine tāwhana pōro: kiri āhua waenga',
    '⛹🏾‍♀' => 'wahine tāwhana pōro: kiri āhua waenga-parauri',
    '⛹🏿‍♀' => 'wahine tāwhana pōro: kiri āhua parauri',
    '🏋🏻‍♂' => 'tāne hiki taumaha: kiri āhua māmā',
    '🏋🏼‍♂' => 'tāne hiki taumaha: kiri āhua māmā-waenga',
    '🏋🏽‍♂' => 'tāne hiki taumaha: kiri āhua waenga',
    '🏋🏾‍♂' => 'tāne hiki taumaha: kiri āhua waenga-parauri',
    '🏋🏿‍♂' => 'tāne hiki taumaha: kiri āhua parauri',
    '🏋🏻‍♀' => 'wahine hiki taumaha: kiri āhua māmā',
    '🏋🏼‍♀' => 'wahine hiki taumaha: kiri āhua māmā-waenga',
    '🏋🏽‍♀' => 'wahine hiki taumaha: kiri āhua waenga',
    '🏋🏾‍♀' => 'wahine hiki taumaha: kiri āhua waenga-parauri',
    '🏋🏿‍♀' => 'wahine hiki taumaha: kiri āhua parauri',
    '🚴🏻‍♂' => 'tāne eke pahikara: kiri āhua māmā',
    '🚴🏼‍♂' => 'tāne eke pahikara: kiri āhua māmā-waenga',
    '🚴🏽‍♂' => 'tāne eke pahikara: kiri āhua waenga',
    '🚴🏾‍♂' => 'tāne eke pahikara: kiri āhua waenga-parauri',
    '🚴🏿‍♂' => 'tāne eke pahikara: kiri āhua parauri',
    '🚴🏻‍♀' => 'wahine eke pahikara: kiri āhua māmā',
    '🚴🏼‍♀' => 'wahine eke pahikara: kiri āhua māmā-waenga',
    '🚴🏽‍♀' => 'wahine eke pahikara: kiri āhua waenga',
    '🚴🏾‍♀' => 'wahine eke pahikara: kiri āhua waenga-parauri',
    '🚴🏿‍♀' => 'wahine eke pahikara: kiri āhua parauri',
    '🚵🏻‍♂' => 'tāne eke pahikara maunga: kiri āhua māmā',
    '🚵🏼‍♂' => 'tāne eke pahikara maunga: kiri āhua māmā-waenga',
    '🚵🏽‍♂' => 'tāne eke pahikara maunga: kiri āhua waenga',
    '🚵🏾‍♂' => 'tāne eke pahikara maunga: kiri āhua waenga-parauri',
    '🚵🏿‍♂' => 'tāne eke pahikara maunga: kiri āhua parauri',
    '🚵🏻‍♀' => 'wahine eke pahikara maunga: kiri āhua māmā',
    '🚵🏼‍♀' => 'wahine eke pahikara maunga: kiri āhua māmā-waenga',
    '🚵🏽‍♀' => 'wahine eke pahikara maunga: kiri āhua waenga',
    '🚵🏾‍♀' => 'wahine eke pahikara maunga: kiri āhua waenga-parauri',
    '🚵🏿‍♀' => 'wahine eke pahikara maunga: kiri āhua parauri',
    '🤸🏻‍♂' => 'tāne kātawīra: kiri āhua māmā',
    '🤸🏼‍♂' => 'tāne kātawīra: kiri āhua māmā-waenga',
    '🤸🏽‍♂' => 'tāne kātawīra: kiri āhua waenga',
    '🤸🏾‍♂' => 'tāne kātawīra: kiri āhua waenga-parauri',
    '🤸🏿‍♂' => 'tāne kātawīra: kiri āhua parauri',
    '🤸🏻‍♀' => 'wahine kātawīra: kiri āhua māmā',
    '🤸🏼‍♀' => 'wahine kātawīra: kiri āhua māmā-waenga',
    '🤸🏽‍♀' => 'wahine kātawīra: kiri āhua waenga',
    '🤸🏾‍♀' => 'wahine kātawīra: kiri āhua waenga-parauri',
    '🤸🏿‍♀' => 'wahine kātawīra: kiri āhua parauri',
    '🤼🏻‍♀' => 'wāhine mamau: kiri āhua māmā',
    '🤼🏼‍♀' => 'wāhine mamau: kiri āhua māmā-waenga',
    '🤼🏽‍♀' => 'wāhine mamau: kiri āhua waenga',
    '🤼🏾‍♀' => 'wāhine mamau: kiri āhua waenga-parauri',
    '🤼🏿‍♀' => 'wāhine mamau: kiri āhua parauri',
    '🤼🏻‍♂' => 'tāne mamau: kiri āhua māmā',
    '🤼🏼‍♂' => 'tāne mamau: kiri āhua māmā-waenga',
    '🤼🏽‍♂' => 'tāne mamau: kiri āhua waenga',
    '🤼🏾‍♂' => 'tāne mamau: kiri āhua waenga-parauri',
    '🤼🏿‍♂' => 'tāne mamau: kiri āhua parauri',
    '🤽🏻‍♂' => 'tāne tākaro poro wai: kiri āhua māmā',
    '🤽🏼‍♂' => 'tāne tākaro poro wai: kiri āhua māmā-waenga',
    '🤽🏽‍♂' => 'tāne tākaro poro wai: kiri āhua waenga',
    '🤽🏾‍♂' => 'tāne tākaro poro wai: kiri āhua waenga-parauri',
    '🤽🏿‍♂' => 'tāne tākaro poro wai: kiri āhua parauri',
    '🤽🏻‍♀' => 'wahine tākaro poro wai: kiri āhua māmā',
    '🤽🏼‍♀' => 'wahine tākaro poro wai: kiri āhua māmā-waenga',
    '🤽🏽‍♀' => 'wahine tākaro poro wai: kiri āhua waenga',
    '🤽🏾‍♀' => 'wahine tākaro poro wai: kiri āhua waenga-parauri',
    '🤽🏿‍♀' => 'wahine tākaro poro wai: kiri āhua parauri',
    '🤾🏻‍♂' => 'tāne tākaro poiringa: kiri āhua māmā',
    '🤾🏼‍♂' => 'tāne tākaro poiringa: kiri āhua māmā-waenga',
    '🤾🏽‍♂' => 'tāne tākaro poiringa: kiri āhua waenga',
    '🤾🏾‍♂' => 'tāne tākaro poiringa: kiri āhua waenga-parauri',
    '🤾🏿‍♂' => 'tāne tākaro poiringa: kiri āhua parauri',
    '🤾🏻‍♀' => 'wahine tākaro poiringa: kiri āhua māmā',
    '🤾🏼‍♀' => 'wahine tākaro poiringa: kiri āhua māmā-waenga',
    '🤾🏽‍♀' => 'wahine tākaro poiringa: kiri āhua waenga',
    '🤾🏾‍♀' => 'wahine tākaro poiringa: kiri āhua waenga-parauri',
    '🤾🏿‍♀' => 'wahine tākaro poiringa: kiri āhua parauri',
    '🤹🏻‍♂' => 'tāne whiuwhiu: kiri āhua māmā',
    '🤹🏼‍♂' => 'tāne whiuwhiu: kiri āhua māmā-waenga',
    '🤹🏽‍♂' => 'tāne whiuwhiu: kiri āhua waenga',
    '🤹🏾‍♂' => 'tāne whiuwhiu: kiri āhua waenga-parauri',
    '🤹🏿‍♂' => 'tāne whiuwhiu: kiri āhua parauri',
    '🤹🏻‍♀' => 'wahine whiuwhiu: kiri āhua māmā',
    '🤹🏼‍♀' => 'wahine whiuwhiu: kiri āhua māmā-waenga',
    '🤹🏽‍♀' => 'wahine whiuwhiu: kiri āhua waenga',
    '🤹🏾‍♀' => 'wahine whiuwhiu: kiri āhua waenga-parauri',
    '🤹🏿‍♀' => 'wahine whiuwhiu: kiri āhua parauri',
    '🧘🏻‍♂' => 'tāne tūranga rotu: kiri āhua māmā',
    '🧘🏼‍♂' => 'tāne tūranga rotu: kiri āhua māmā-waenga',
    '🧘🏽‍♂' => 'tāne tūranga rotu: kiri āhua waenga',
    '🧘🏾‍♂' => 'tāne tūranga rotu: kiri āhua waenga-parauri',
    '🧘🏿‍♂' => 'tāne tūranga rotu: kiri āhua parauri',
    '🧘🏻‍♀' => 'wahine tūranga rotu: kiri āhua māmā',
    '🧘🏼‍♀' => 'wahine tūranga rotu: kiri āhua māmā-waenga',
    '🧘🏽‍♀' => 'wahine tūranga rotu: kiri āhua waenga',
    '🧘🏾‍♀' => 'wahine tūranga rotu: kiri āhua waenga-parauri',
    '🧘🏿‍♀' => 'wahine tūranga rotu: kiri āhua parauri',
    '👨‍👦' => 'whānau: tāne, tamatāne',
    '👨‍👧' => 'whānau: tāne, kōtiro',
    '👩‍👦' => 'whānau: wahine, tamatāne',
    '👩‍👧' => 'whānau: wahine, kōtiro',
    '👁‍🗨' => 'karu rō mirumiru kōrero',
    '👱‍♂' => 'tāne mākekehu',
    '👱‍♀' => 'wahine mākekehu',
    '🙍‍♂' => 'tāne poururu',
    '🙍‍♀' => 'wahine poururu',
    '🙎‍♂' => 'tāne tupere',
    '🙎‍♀' => 'wahine tupere',
    '🙅‍♂' => 'tāne tohu ana KĀO',
    '🙅‍♀' => 'wahine tohu ana KĀO',
    '🙆‍♂' => 'tāne tohu ana ĀE',
    '🙆‍♀' => 'wahine tohu ana ĀE',
    '💁‍♂' => 'tāne ringa tāringi',
    '💁‍♀' => 'wahine ringa tāringi',
    '🙋‍♂' => 'tāne ringa tū',
    '🙋‍♀' => 'wahine ringa tū',
    '🙇‍♂' => 'tāne tuohu',
    '🙇‍♀' => 'wahine tuohu',
    '🤦‍♂' => 'tāne ringakanohi',
    '🤦‍♀' => 'wahine ringakanohi',
    '🤷‍♂' => 'tāne hiki-pakihiwi',
    '🤷‍♀' => 'wahine hiki-pakihiwi',
    '👨‍⚕' => 'kaimahi hauora tāne',
    '👩‍⚕' => 'wahine atawhai hauora',
    '👨‍🎓' => 'ākonga tāne',
    '👩‍🎓' => 'ākonga wahine',
    '👨‍🏫' => 'tāne kaiako',
    '👩‍🏫' => 'kaiako wahine',
    '👨‍⚖' => 'kaiwhakawā tāne',
    '👩‍⚖' => 'kaiwhakawā wahine',
    '👨‍🌾' => 'kaipāmu tāne',
    '👩‍🌾' => 'wahine kaipāmu',
    '👨‍🍳' => 'kaitao tāne',
    '👩‍🍳' => 'kaitao wahine',
    '👨‍🔧' => 'kaiaka mīhini tāne',
    '👩‍🔧' => 'kaiaka mīhini wahine',
    '👨‍🏭' => 'tāne mahi wheketere',
    '👩‍🏭' => 'wahine mahi wheketere',
    '👨‍💼' => 'kaimahi tari tāne',
    '👩‍💼' => 'kaimahi tari wahine',
    '👨‍🔬' => 'kaimātai pūtaiao tāne',
    '👩‍🔬' => 'kaimātai pūtaiao wahine',
    '👨‍💻' => 'kaihangarau tāne',
    '👩‍💻' => 'kaihangarau wahine',
    '👨‍🎤' => 'kaiwaiata tāne',
    '👩‍🎤' => 'kaiwaiata wahine',
    '👨‍🎨' => 'tāne toi',
    '👩‍🎨' => 'wahine toi',
    '👨‍✈' => 'paerata tāne',
    '👩‍✈' => 'paerata wahine',
    '👨‍🚀' => 'kaiātea tāne',
    '👩‍🚀' => 'kaiātea wahine',
    '👨‍🚒' => 'kaitinei-ahi tāne',
    '👩‍🚒' => 'kaitinei-ahi wahine',
    '👮‍♂' => 'āpiha pirihimana tāne',
    '👮‍♀' => 'āpiha pirihimana wahine',
    '🕵‍♂' => 'kaikimihara tāne',
    '🕵‍♀' => 'kaikimihara wahine',
    '💂‍♂' => 'tautieki tāne',
    '💂‍♀' => 'tautieki wahine',
    '👷‍♂' => 'kaimahi hangatanga tāne',
    '👷‍♀' => 'kaimahi hangatanga wahine',
    '👳‍♂' => 'tāne mau pōtae kameta',
    '👳‍♀' => 'wahine mau pōtae kameta',
    '🧙‍♂' => 'tohunga matakite',
    '🧙‍♀' => 'wahine matakite',
    '🧚‍♂' => 'patupaiarehe tāne',
    '🧚‍♀' => 'patupaiarehe wahine',
    '🧛‍♂' => 'tāne kaitoto',
    '🧛‍♀' => 'wahine kaitoto',
    '🧜‍♂' => 'tāne-ika',
    '🧜‍♀' => 'hine-ika',
    '🧝‍♂' => 'erepe tāne',
    '🧝‍♀' => 'erepe wahine',
    '🧞‍♂' => 'tāne tūrehu',
    '🧞‍♀' => 'wahine tūrehu',
    '🧟‍♂' => 'tāne tūpāpaku',
    '🧟‍♀' => 'wahine tūpāpaku',
    '💆‍♂' => 'tāne whiwhi mirimiri',
    '💆‍♀' => 'wahine whiwhi mirimiri',
    '💇‍♂' => 'tāne whiwhi kutinga makawe',
    '💇‍♀' => 'wahine whiwhi kutinga makawe',
    '🚶‍♂' => 'tāne hīkoi',
    '🚶‍♀' => 'wahine hīkoi',
    '🏃‍♂' => 'tāne oma',
    '🏃‍♀' => 'wahine oma',
    '👯‍♂' => 'tāne taringa rāpeti whakangahau',
    '👯‍♀' => 'wāhine taringa rāpeti whakangahau',
    '🧖‍♂' => 'tāne rō taiwhanga mamaoa',
    '🧖‍♀' => 'wahine rō taiwhanga mamaoa',
    '🧗‍♂' => 'tāne piki',
    '🧗‍♀' => 'wahine piki',
    '🏌‍♂' => 'tāne haupōro',
    '🏌‍♀' => 'wahine haupōro',
    '🏄‍♂' => 'tāne whakaheke ngaru',
    '🏄‍♀' => 'wahine whakaheke ngaru',
    '🚣‍♂' => 'tāne hoe waka',
    '🚣‍♀' => 'wahine hoe waka',
    '🏊‍♂' => 'tāne kauhoe',
    '🏊‍♀' => 'wahine kauhoe',
    '⛹‍♂' => 'tāne tāwhana pōro',
    '⛹‍♀' => 'wahine tāwhana pōro',
    '🏋‍♂' => 'tāne hiki taumaha',
    '🏋‍♀' => 'wahine hiki taumaha',
    '🚴‍♂' => 'tāne eke pahikara',
    '🚴‍♀' => 'wahine eke pahikara',
    '🚵‍♂' => 'tāne eke pahikara maunga',
    '🚵‍♀' => 'wahine eke pahikara maunga',
    '🤸‍♂' => 'tāne kātawīra',
    '🤸‍♀' => 'wahine kātawīra',
    '🤼‍♂' => 'tāne mamau',
    '🤼‍♀' => 'wāhine mamau',
    '🤽‍♂' => 'tāne tākaro poro wai',
    '🤽‍♀' => 'wahine tākaro poro wai',
    '🤾‍♂' => 'tāne tākaro poiringa',
    '🤾‍♀' => 'wahine tākaro poiringa',
    '🤹‍♂' => 'tāne whiuwhiu',
    '🤹‍♀' => 'wahine whiuwhiu',
    '🧘‍♂' => 'tāne tūranga rotu',
    '🧘‍♀' => 'wahine tūranga rotu',
    '🏳‍🌈' => 'kara kahukura',
    '👋🏻' => 'ringa pōhirihiri: kiri āhua māmā',
    '👋🏼' => 'ringa pōhirihiri: kiri āhua māmā-waenga',
    '👋🏽' => 'ringa pōhirihiri: kiri āhua waenga',
    '👋🏾' => 'ringa pōhirihiri: kiri āhua waenga-parauri',
    '👋🏿' => 'ringa pōhirihiri: kiri āhua parauri',
    '🤚🏻' => 'tāmuri tū: kiri āhua māmā',
    '🤚🏼' => 'tāmuri tū: kiri āhua māmā-waenga',
    '🤚🏽' => 'tāmuri tū: kiri āhua waenga',
    '🤚🏾' => 'tāmuri tū: kiri āhua waenga-parauri',
    '🤚🏿' => 'tāmuri tū: kiri āhua parauri',
    '🖐🏻' => 'ringa tū matimati paraha: kiri āhua māmā',
    '🖐🏼' => 'ringa tū matimati paraha: kiri āhua māmā-waenga',
    '🖐🏽' => 'ringa tū matimati paraha: kiri āhua waenga',
    '🖐🏾' => 'ringa tū matimati paraha: kiri āhua waenga-parauri',
    '🖐🏿' => 'ringa tū matimati paraha: kiri āhua parauri',
    '✋🏻' => 'ringa tū: kiri āhua māmā',
    '✋🏼' => 'ringa tū: kiri āhua māmā-waenga',
    '✋🏽' => 'ringa tū: kiri āhua waenga',
    '✋🏾' => 'ringa tū: kiri āhua waenga-parauri',
    '✋🏿' => 'ringa tū: kiri āhua parauri',
    '🖖🏻' => 'whakakōtua vulcan: kiri āhua māmā',
    '🖖🏼' => 'whakakōtua vulcan: kiri āhua māmā-waenga',
    '🖖🏽' => 'whakakōtua vulcan: kiri āhua waenga',
    '🖖🏾' => 'whakakōtua vulcan: kiri āhua waenga-parauri',
    '🖖🏿' => 'whakakōtua vulcan: kiri āhua parauri',
    '👌🏻' => 'ringa ĀE: kiri āhua māmā',
    '👌🏼' => 'ringa ĀE: kiri āhua māmā-waenga',
    '👌🏽' => 'ringa ĀE: kiri āhua waenga',
    '👌🏾' => 'ringa ĀE: kiri āhua waenga-parauri',
    '👌🏿' => 'ringa ĀE: kiri āhua parauri',
    '✌🏻' => 'ringa wikitōria: kiri āhua māmā',
    '✌🏼' => 'ringa wikitōria: kiri āhua māmā-waenga',
    '✌🏽' => 'ringa wikitōria: kiri āhua waenga',
    '✌🏾' => 'ringa wikitōria: kiri āhua waenga-parauri',
    '✌🏿' => 'ringa wikitōria: kiri āhua parauri',
    '🤞🏻' => 'matimati whiri: kiri āhua māmā',
    '🤞🏼' => 'matimati whiri: kiri āhua māmā-waenga',
    '🤞🏽' => 'matimati whiri: kiri āhua waenga',
    '🤞🏾' => 'matimati whiri: kiri āhua waenga-parauri',
    '🤞🏿' => 'matimati whiri: kiri āhua parauri',
    '🤟🏻' => 'tohu aroha-ki-a-koe: kiri āhua māmā',
    '🤟🏼' => 'tohu aroha-ki-a-koe: kiri āhua māmā-waenga',
    '🤟🏽' => 'tohu aroha-ki-a-koe: kiri āhua waenga',
    '🤟🏾' => 'tohu aroha-ki-a-koe: kiri āhua waenga-parauri',
    '🤟🏿' => 'tohu aroha-ki-a-koe: kiri āhua parauri',
    '🤘🏻' => 'tohu o ngā pihi: kiri āhua māmā',
    '🤘🏼' => 'tohu o ngā pihi: kiri āhua māmā-waenga',
    '🤘🏽' => 'tohu o ngā pihi: kiri āhua waenga',
    '🤘🏾' => 'tohu o ngā pihi: kiri āhua waenga-parauri',
    '🤘🏿' => 'tohu o ngā pihi: kiri āhua parauri',
    '🤙🏻' => 'ringa waea mai: kiri āhua māmā',
    '🤙🏼' => 'ringa waea mai: kiri āhua māmā-waenga',
    '🤙🏽' => 'ringa waea mai: kiri āhua waenga',
    '🤙🏾' => 'ringa waea mai: kiri āhua waenga-parauri',
    '🤙🏿' => 'ringa waea mai: kiri āhua parauri',
    '👈🏻' => 'kōroa tāmuri tohu mauī: kiri āhua māmā',
    '👈🏼' => 'kōroa tāmuri tohu mauī: kiri āhua māmā-waenga',
    '👈🏽' => 'kōroa tāmuri tohu mauī: kiri āhua waenga',
    '👈🏾' => 'kōroa tāmuri tohu mauī: kiri āhua waenga-parauri',
    '👈🏿' => 'kōroa tāmuri tohu mauī: kiri āhua parauri',
    '👉🏻' => 'kōroa tāmuri tohu matau: kiri āhua māmā',
    '👉🏼' => 'kōroa tāmuri tohu matau: kiri āhua māmā-waenga',
    '👉🏽' => 'kōroa tāmuri tohu matau: kiri āhua waenga',
    '👉🏾' => 'kōroa tāmuri tohu matau: kiri āhua waenga-parauri',
    '👉🏿' => 'kōroa tāmuri tohu matau: kiri āhua parauri',
    '👆🏻' => 'kōroa tāmuri tohu ake: kiri āhua māmā',
    '👆🏼' => 'kōroa tāmuri tohu ake: kiri āhua māmā-waenga',
    '👆🏽' => 'kōroa tāmuri tohu ake: kiri āhua waenga',
    '👆🏾' => 'kōroa tāmuri tohu ake: kiri āhua waenga-parauri',
    '👆🏿' => 'kōroa tāmuri tohu ake: kiri āhua parauri',
    '🖕🏻' => 'māpere: kiri āhua māmā',
    '🖕🏼' => 'māpere: kiri āhua māmā-waenga',
    '🖕🏽' => 'māpere: kiri āhua waenga',
    '🖕🏾' => 'māpere: kiri āhua waenga-parauri',
    '🖕🏿' => 'māpere: kiri āhua parauri',
    '👇🏻' => 'kōroa tāmuri tohu iho: kiri āhua māmā',
    '👇🏼' => 'kōroa tāmuri tohu iho: kiri āhua māmā-waenga',
    '👇🏽' => 'kōroa tāmuri tohu iho: kiri āhua waenga',
    '👇🏾' => 'kōroa tāmuri tohu iho: kiri āhua waenga-parauri',
    '👇🏿' => 'kōroa tāmuri tohu iho: kiri āhua parauri',
    '☝🏻' => 'kōroa tohu ake: kiri āhua māmā',
    '☝🏼' => 'kōroa tohu ake: kiri āhua māmā-waenga',
    '☝🏽' => 'kōroa tohu ake: kiri āhua waenga',
    '☝🏾' => 'kōroa tohu ake: kiri āhua waenga-parauri',
    '☝🏿' => 'kōroa tohu ake: kiri āhua parauri',
    '👍🏻' => 'kōnui ake: kiri āhua māmā',
    '👍🏼' => 'kōnui ake: kiri āhua māmā-waenga',
    '👍🏽' => 'kōnui ake: kiri āhua waenga',
    '👍🏾' => 'kōnui ake: kiri āhua waenga-parauri',
    '👍🏿' => 'kōnui ake: kiri āhua parauri',
    '👎🏻' => 'kōnui iho: kiri āhua māmā',
    '👎🏼' => 'kōnui iho: kiri āhua māmā-waenga',
    '👎🏽' => 'kōnui iho: kiri āhua waenga',
    '👎🏾' => 'kōnui iho: kiri āhua waenga-parauri',
    '👎🏿' => 'kōnui iho: kiri āhua parauri',
    '✊🏻' => 'meke tū: kiri āhua māmā',
    '✊🏼' => 'meke tū: kiri āhua māmā-waenga',
    '✊🏽' => 'meke tū: kiri āhua waenga',
    '✊🏾' => 'meke tū: kiri āhua waenga-parauri',
    '✊🏿' => 'meke tū: kiri āhua parauri',
    '👊🏻' => 'meke anga mai: kiri āhua māmā',
    '👊🏼' => 'meke anga mai: kiri āhua māmā-waenga',
    '👊🏽' => 'meke anga mai: kiri āhua waenga',
    '👊🏾' => 'meke anga mai: kiri āhua waenga-parauri',
    '👊🏿' => 'meke anga mai: kiri āhua parauri',
    '🤛🏻' => 'meke anga-mauī: kiri āhua māmā',
    '🤛🏼' => 'meke anga-mauī: kiri āhua māmā-waenga',
    '🤛🏽' => 'meke anga-mauī: kiri āhua waenga',
    '🤛🏾' => 'meke anga-mauī: kiri āhua waenga-parauri',
    '🤛🏿' => 'meke anga-mauī: kiri āhua parauri',
    '🤜🏻' => 'meke anga-matau: kiri āhua māmā',
    '🤜🏼' => 'meke anga-matau: kiri āhua māmā-waenga',
    '🤜🏽' => 'meke anga-matau: kiri āhua waenga',
    '🤜🏾' => 'meke anga-matau: kiri āhua waenga-parauri',
    '🤜🏿' => 'meke anga-matau: kiri āhua parauri',
    '👏🏻' => 'ringa pakipaki: kiri āhua māmā',
    '👏🏼' => 'ringa pakipaki: kiri āhua māmā-waenga',
    '👏🏽' => 'ringa pakipaki: kiri āhua waenga',
    '👏🏾' => 'ringa pakipaki: kiri āhua waenga-parauri',
    '👏🏿' => 'ringa pakipaki: kiri āhua parauri',
    '🙌🏻' => 'ngā ringa tū: kiri āhua māmā',
    '🙌🏼' => 'ngā ringa tū: kiri āhua māmā-waenga',
    '🙌🏽' => 'ngā ringa tū: kiri āhua waenga',
    '🙌🏾' => 'ngā ringa tū: kiri āhua waenga-parauri',
    '🙌🏿' => 'ngā ringa tū: kiri āhua parauri',
    '👐🏻' => 'ringa tuwhera: kiri āhua māmā',
    '👐🏼' => 'ringa tuwhera: kiri āhua māmā-waenga',
    '👐🏽' => 'ringa tuwhera: kiri āhua waenga',
    '👐🏾' => 'ringa tuwhera: kiri āhua waenga-parauri',
    '👐🏿' => 'ringa tuwhera: kiri āhua parauri',
    '🤲🏻' => 'ringa rewa tahi: kiri āhua māmā',
    '🤲🏼' => 'ringa rewa tahi: kiri āhua māmā-waenga',
    '🤲🏽' => 'ringa rewa tahi: kiri āhua waenga',
    '🤲🏾' => 'ringa rewa tahi: kiri āhua waenga-parauri',
    '🤲🏿' => 'ringa rewa tahi: kiri āhua parauri',
    '🤝🏻' => 'rūrū: kiri āhua māmā',
    '🤝🏼' => 'rūrū: kiri āhua māmā-waenga',
    '🤝🏽' => 'rūrū: kiri āhua waenga',
    '🤝🏾' => 'rūrū: kiri āhua waenga-parauri',
    '🤝🏿' => 'rūrū: kiri āhua parauri',
    '🙏🏻' => 'ringa whiri: kiri āhua māmā',
    '🙏🏼' => 'ringa whiri: kiri āhua māmā-waenga',
    '🙏🏽' => 'ringa whiri: kiri āhua waenga',
    '🙏🏾' => 'ringa whiri: kiri āhua waenga-parauri',
    '🙏🏿' => 'ringa whiri: kiri āhua parauri',
    '✍🏻' => 'ringa tuhituhi: kiri āhua māmā',
    '✍🏼' => 'ringa tuhituhi: kiri āhua māmā-waenga',
    '✍🏽' => 'ringa tuhituhi: kiri āhua waenga',
    '✍🏾' => 'ringa tuhituhi: kiri āhua waenga-parauri',
    '✍🏿' => 'ringa tuhituhi: kiri āhua parauri',
    '💅🏻' => 'pani maikūkū: kiri āhua māmā',
    '💅🏼' => 'pani maikūkū: kiri āhua māmā-waenga',
    '💅🏽' => 'pani maikūkū: kiri āhua waenga',
    '💅🏾' => 'pani maikūkū: kiri āhua waenga-parauri',
    '💅🏿' => 'pani maikūkū: kiri āhua parauri',
    '🤳🏻' => 'kiriāhua: kiri āhua māmā',
    '🤳🏼' => 'kiriāhua: kiri āhua māmā-waenga',
    '🤳🏽' => 'kiriāhua: kiri āhua waenga',
    '🤳🏾' => 'kiriāhua: kiri āhua waenga-parauri',
    '🤳🏿' => 'kiriāhua: kiri āhua parauri',
    '💪🏻' => 'uarua whakapakari: kiri āhua māmā',
    '💪🏼' => 'uarua whakapakari: kiri āhua māmā-waenga',
    '💪🏽' => 'uarua whakapakari: kiri āhua waenga',
    '💪🏾' => 'uarua whakapakari: kiri āhua waenga-parauri',
    '💪🏿' => 'uarua whakapakari: kiri āhua parauri',
    '👂🏻' => 'taringa: kiri āhua māmā',
    '👂🏼' => 'taringa: kiri āhua māmā-waenga',
    '👂🏽' => 'taringa: kiri āhua waenga',
    '👂🏾' => 'taringa: kiri āhua waenga-parauri',
    '👂🏿' => 'taringa: kiri āhua parauri',
    '👃🏻' => 'ihu: kiri āhua māmā',
    '👃🏼' => 'ihu: kiri āhua māmā-waenga',
    '👃🏽' => 'ihu: kiri āhua waenga',
    '👃🏾' => 'ihu: kiri āhua waenga-parauri',
    '👃🏿' => 'ihu: kiri āhua parauri',
    '👶🏻' => 'pēpi: kiri āhua māmā',
    '👶🏼' => 'pēpi: kiri āhua māmā-waenga',
    '👶🏽' => 'pēpi: kiri āhua waenga',
    '👶🏾' => 'pēpi: kiri āhua waenga-parauri',
    '👶🏿' => 'pēpi: kiri āhua parauri',
    '🧒🏻' => 'tamaiti: kiri āhua māmā',
    '🧒🏼' => 'tamaiti: kiri āhua māmā-waenga',
    '🧒🏽' => 'tamaiti: kiri āhua waenga',
    '🧒🏾' => 'tamaiti: kiri āhua waenga-parauri',
    '🧒🏿' => 'tamaiti: kiri āhua parauri',
    '👦🏻' => 'tamatāne: kiri āhua māmā',
    '👦🏼' => 'tamatāne: kiri āhua māmā-waenga',
    '👦🏽' => 'tamatāne: kiri āhua waenga',
    '👦🏾' => 'tamatāne: kiri āhua waenga-parauri',
    '👦🏿' => 'tamatāne: kiri āhua parauri',
    '👧🏻' => 'kōtiro: kiri āhua māmā',
    '👧🏼' => 'kōtiro: kiri āhua māmā-waenga',
    '👧🏽' => 'kōtiro: kiri āhua waenga',
    '👧🏾' => 'kōtiro: kiri āhua waenga-parauri',
    '👧🏿' => 'kōtiro: kiri āhua parauri',
    '🧑🏻' => 'pakeke: kiri āhua māmā',
    '🧑🏼' => 'pakeke: kiri āhua māmā-waenga',
    '🧑🏽' => 'pakeke: kiri āhua waenga',
    '🧑🏾' => 'pakeke: kiri āhua waenga-parauri',
    '🧑🏿' => 'pakeke: kiri āhua parauri',
    '👱🏻' => 'tangata mākekehu: kiri āhua māmā',
    '👱🏼' => 'tangata mākekehu: kiri āhua māmā-waenga',
    '👱🏽' => 'tangata mākekehu: kiri āhua waenga',
    '👱🏾' => 'tangata mākekehu: kiri āhua waenga-parauri',
    '👱🏿' => 'tangata mākekehu: kiri āhua parauri',
    '👨🏻' => 'tāne: kiri āhua māmā',
    '👨🏼' => 'tāne: kiri āhua māmā-waenga',
    '👨🏽' => 'tāne: kiri āhua waenga',
    '👨🏾' => 'tāne: kiri āhua waenga-parauri',
    '👨🏿' => 'tāne: kiri āhua parauri',
    '🧔🏻' => 'tangata pāhau: kiri āhua māmā',
    '🧔🏼' => 'tangata pāhau: kiri āhua māmā-waenga',
    '🧔🏽' => 'tangata pāhau: kiri āhua waenga',
    '🧔🏾' => 'tangata pāhau: kiri āhua waenga-parauri',
    '🧔🏿' => 'tangata pāhau: kiri āhua parauri',
    '👩🏻' => 'wahine: kiri āhua māmā',
    '👩🏼' => 'wahine: kiri āhua māmā-waenga',
    '👩🏽' => 'wahine: kiri āhua waenga',
    '👩🏾' => 'wahine: kiri āhua waenga-parauri',
    '👩🏿' => 'wahine: kiri āhua parauri',
    '🧓🏻' => 'kaumātua: kiri āhua māmā',
    '🧓🏼' => 'kaumātua: kiri āhua māmā-waenga',
    '🧓🏽' => 'kaumātua: kiri āhua waenga',
    '🧓🏾' => 'kaumātua: kiri āhua waenga-parauri',
    '🧓🏿' => 'kaumātua: kiri āhua parauri',
    '👴🏻' => 'koroua: kiri āhua māmā',
    '👴🏼' => 'koroua: kiri āhua māmā-waenga',
    '👴🏽' => 'koroua: kiri āhua waenga',
    '👴🏾' => 'koroua: kiri āhua waenga-parauri',
    '👴🏿' => 'koroua: kiri āhua parauri',
    '👵🏻' => 'kuia: kiri āhua māmā',
    '👵🏼' => 'kuia: kiri āhua māmā-waenga',
    '👵🏽' => 'kuia: kiri āhua waenga',
    '👵🏾' => 'kuia: kiri āhua waenga-parauri',
    '👵🏿' => 'kuia: kiri āhua parauri',
    '🙍🏻' => 'tangata poururu: kiri āhua māmā',
    '🙍🏼' => 'tangata poururu: kiri āhua māmā-waenga',
    '🙍🏽' => 'tangata poururu: kiri āhua waenga',
    '🙍🏾' => 'tangata poururu: kiri āhua waenga-parauri',
    '🙍🏿' => 'tangata poururu: kiri āhua parauri',
    '🙎🏻' => 'tangata tupere: kiri āhua māmā',
    '🙎🏼' => 'tangata tupere: kiri āhua māmā-waenga',
    '🙎🏽' => 'tangata tupere: kiri āhua waenga',
    '🙎🏾' => 'tangata tupere: kiri āhua waenga-parauri',
    '🙎🏿' => 'tangata tupere: kiri āhua parauri',
    '🙅🏻' => 'tangata tohu ana KĀO: kiri āhua māmā',
    '🙅🏼' => 'tangata tohu ana KĀO: kiri āhua māmā-waenga',
    '🙅🏽' => 'tangata tohu ana KĀO: kiri āhua waenga',
    '🙅🏾' => 'tangata tohu ana KĀO: kiri āhua waenga-parauri',
    '🙅🏿' => 'tangata tohu ana KĀO: kiri āhua parauri',
    '🙆🏻' => 'tangata tohu ana ĀE: kiri āhua māmā',
    '🙆🏼' => 'tangata tohu ana ĀE: kiri āhua māmā-waenga',
    '🙆🏽' => 'tangata tohu ana ĀE: kiri āhua waenga',
    '🙆🏾' => 'tangata tohu ana ĀE: kiri āhua waenga-parauri',
    '🙆🏿' => 'tangata tohu ana ĀE: kiri āhua parauri',
    '💁🏻' => 'tangata ringa tāringi: kiri āhua māmā',
    '💁🏼' => 'tangata ringa tāringi: kiri āhua māmā-waenga',
    '💁🏽' => 'tangata ringa tāringi: kiri āhua waenga',
    '💁🏾' => 'tangata ringa tāringi: kiri āhua waenga-parauri',
    '💁🏿' => 'tangata ringa tāringi: kiri āhua parauri',
    '🙋🏻' => 'tangata ringa tū: kiri āhua māmā',
    '🙋🏼' => 'tangata ringa tū: kiri āhua māmā-waenga',
    '🙋🏽' => 'tangata ringa tū: kiri āhua waenga',
    '🙋🏾' => 'tangata ringa tū: kiri āhua waenga-parauri',
    '🙋🏿' => 'tangata ringa tū: kiri āhua parauri',
    '🙇🏻' => 'tangata tuohu: kiri āhua māmā',
    '🙇🏼' => 'tangata tuohu: kiri āhua māmā-waenga',
    '🙇🏽' => 'tangata tuohu: kiri āhua waenga',
    '🙇🏾' => 'tangata tuohu: kiri āhua waenga-parauri',
    '🙇🏿' => 'tangata tuohu: kiri āhua parauri',
    '🤦🏻' => 'tangata ringakanohi: kiri āhua māmā',
    '🤦🏼' => 'tangata ringakanohi: kiri āhua māmā-waenga',
    '🤦🏽' => 'tangata ringakanohi: kiri āhua waenga',
    '🤦🏾' => 'tangata ringakanohi: kiri āhua waenga-parauri',
    '🤦🏿' => 'tangata ringakanohi: kiri āhua parauri',
    '🤷🏻' => 'tangata hiki-pakihiwi: kiri āhua māmā',
    '🤷🏼' => 'tangata hiki-pakihiwi: kiri āhua māmā-waenga',
    '🤷🏽' => 'tangata hiki-pakihiwi: kiri āhua waenga',
    '🤷🏾' => 'tangata hiki-pakihiwi: kiri āhua waenga-parauri',
    '🤷🏿' => 'tangata hiki-pakihiwi: kiri āhua parauri',
    '👮🏻' => 'āpiha pirihimana: kiri āhua māmā',
    '👮🏼' => 'āpiha pirihimana: kiri āhua māmā-waenga',
    '👮🏽' => 'āpiha pirihimana: kiri āhua waenga',
    '👮🏾' => 'āpiha pirihimana: kiri āhua waenga-parauri',
    '👮🏿' => 'āpiha pirihimana: kiri āhua parauri',
    '🕵🏻' => 'kaikimihara: kiri āhua māmā',
    '🕵🏼' => 'kaikimihara: kiri āhua māmā-waenga',
    '🕵🏽' => 'kaikimihara: kiri āhua waenga',
    '🕵🏾' => 'kaikimihara: kiri āhua waenga-parauri',
    '🕵🏿' => 'kaikimihara: kiri āhua parauri',
    '💂🏻' => 'tautieki: kiri āhua māmā',
    '💂🏼' => 'tautieki: kiri āhua māmā-waenga',
    '💂🏽' => 'tautieki: kiri āhua waenga',
    '💂🏾' => 'tautieki: kiri āhua waenga-parauri',
    '💂🏿' => 'tautieki: kiri āhua parauri',
    '👷🏻' => 'kaimahi hangatanga: kiri āhua māmā',
    '👷🏼' => 'kaimahi hangatanga: kiri āhua māmā-waenga',
    '👷🏽' => 'kaimahi hangatanga: kiri āhua waenga',
    '👷🏾' => 'kaimahi hangatanga: kiri āhua waenga-parauri',
    '👷🏿' => 'kaimahi hangatanga: kiri āhua parauri',
    '🤴🏻' => 'piriniha: kiri āhua māmā',
    '🤴🏼' => 'piriniha: kiri āhua māmā-waenga',
    '🤴🏽' => 'piriniha: kiri āhua waenga',
    '🤴🏾' => 'piriniha: kiri āhua waenga-parauri',
    '🤴🏿' => 'piriniha: kiri āhua parauri',
    '👸🏻' => 'pirinihi: kiri āhua māmā',
    '👸🏼' => 'pirinihi: kiri āhua māmā-waenga',
    '👸🏽' => 'pirinihi: kiri āhua waenga',
    '👸🏾' => 'pirinihi: kiri āhua waenga-parauri',
    '👸🏿' => 'pirinihi: kiri āhua parauri',
    '👳🏻' => 'tangata mau pōtae kameta: kiri āhua māmā',
    '👳🏼' => 'tangata mau pōtae kameta: kiri āhua māmā-waenga',
    '👳🏽' => 'tangata mau pōtae kameta: kiri āhua waenga',
    '👳🏾' => 'tangata mau pōtae kameta: kiri āhua waenga-parauri',
    '👳🏿' => 'tangata mau pōtae kameta: kiri āhua parauri',
    '👲🏻' => 'tāne mau kape hainīhi: kiri āhua māmā',
    '👲🏼' => 'tāne mau kape hainīhi: kiri āhua māmā-waenga',
    '👲🏽' => 'tāne mau kape hainīhi: kiri āhua waenga',
    '👲🏾' => 'tāne mau kape hainīhi: kiri āhua waenga-parauri',
    '👲🏿' => 'tāne mau kape hainīhi: kiri āhua parauri',
    '🧕🏻' => 'wahine mau kāmeta: kiri āhua māmā',
    '🧕🏼' => 'wahine mau kāmeta: kiri āhua māmā-waenga',
    '🧕🏽' => 'wahine mau kāmeta: kiri āhua waenga',
    '🧕🏾' => 'wahine mau kāmeta: kiri āhua waenga-parauri',
    '🧕🏿' => 'wahine mau kāmeta: kiri āhua parauri',
    '🤵🏻' => 'tāne mau hūtu ōkawa: kiri āhua māmā',
    '🤵🏼' => 'tāne mau hūtu ōkawa: kiri āhua māmā-waenga',
    '🤵🏽' => 'tāne mau hūtu ōkawa: kiri āhua waenga',
    '🤵🏾' => 'tāne mau hūtu ōkawa: kiri āhua waenga-parauri',
    '🤵🏿' => 'tāne mau hūtu ōkawa: kiri āhua parauri',
    '👰🏻' => 'wahine mārena mau ārai: kiri āhua māmā',
    '👰🏼' => 'wahine mārena mau ārai: kiri āhua māmā-waenga',
    '👰🏽' => 'wahine mārena mau ārai: kiri āhua waenga',
    '👰🏾' => 'wahine mārena mau ārai: kiri āhua waenga-parauri',
    '👰🏿' => 'wahine mārena mau ārai: kiri āhua parauri',
    '🤰🏻' => 'wahine hapū: kiri āhua māmā',
    '🤰🏼' => 'wahine hapū: kiri āhua māmā-waenga',
    '🤰🏽' => 'wahine hapū: kiri āhua waenga',
    '🤰🏾' => 'wahine hapū: kiri āhua waenga-parauri',
    '🤰🏿' => 'wahine hapū: kiri āhua parauri',
    '🤱🏻' => 'whāngote-ū: kiri āhua māmā',
    '🤱🏼' => 'whāngote-ū: kiri āhua māmā-waenga',
    '🤱🏽' => 'whāngote-ū: kiri āhua waenga',
    '🤱🏾' => 'whāngote-ū: kiri āhua waenga-parauri',
    '🤱🏿' => 'whāngote-ū: kiri āhua parauri',
    '👼🏻' => 'pīpī anahera: kiri āhua māmā',
    '👼🏼' => 'pīpī anahera: kiri āhua māmā-waenga',
    '👼🏽' => 'pīpī anahera: kiri āhua waenga',
    '👼🏾' => 'pīpī anahera: kiri āhua waenga-parauri',
    '👼🏿' => 'pīpī anahera: kiri āhua parauri',
    '🎅🏻' => 'hana koko: kiri āhua māmā',
    '🎅🏼' => 'hana koko: kiri āhua māmā-waenga',
    '🎅🏽' => 'hana koko: kiri āhua waenga',
    '🎅🏾' => 'hana koko: kiri āhua waenga-parauri',
    '🎅🏿' => 'hana koko: kiri āhua parauri',
    '🤶🏻' => 'kuia koko: kiri āhua māmā',
    '🤶🏼' => 'kuia koko: kiri āhua māmā-waenga',
    '🤶🏽' => 'kuia koko: kiri āhua waenga',
    '🤶🏾' => 'kuia koko: kiri āhua waenga-parauri',
    '🤶🏿' => 'kuia koko: kiri āhua parauri',
    '🧙🏻' => 'tāngata matakite: kiri āhua māmā',
    '🧙🏼' => 'tāngata matakite: kiri āhua māmā-waenga',
    '🧙🏽' => 'tāngata matakite: kiri āhua waenga',
    '🧙🏾' => 'tāngata matakite: kiri āhua waenga-parauri',
    '🧙🏿' => 'tāngata matakite: kiri āhua parauri',
    '🧚🏻' => 'patupaiarehe: kiri āhua māmā',
    '🧚🏼' => 'patupaiarehe: kiri āhua māmā-waenga',
    '🧚🏽' => 'patupaiarehe: kiri āhua waenga',
    '🧚🏾' => 'patupaiarehe: kiri āhua waenga-parauri',
    '🧚🏿' => 'patupaiarehe: kiri āhua parauri',
    '🧛🏻' => 'kaitoto: kiri āhua māmā',
    '🧛🏼' => 'kaitoto: kiri āhua māmā-waenga',
    '🧛🏽' => 'kaitoto: kiri āhua waenga',
    '🧛🏾' => 'kaitoto: kiri āhua waenga-parauri',
    '🧛🏿' => 'kaitoto: kiri āhua parauri',
    '🧜🏻' => 'tangata-ika: kiri āhua māmā',
    '🧜🏼' => 'tangata-ika: kiri āhua māmā-waenga',
    '🧜🏽' => 'tangata-ika: kiri āhua waenga',
    '🧜🏾' => 'tangata-ika: kiri āhua waenga-parauri',
    '🧜🏿' => 'tangata-ika: kiri āhua parauri',
    '🧝🏻' => 'erepe: kiri āhua māmā',
    '🧝🏼' => 'erepe: kiri āhua māmā-waenga',
    '🧝🏽' => 'erepe: kiri āhua waenga',
    '🧝🏾' => 'erepe: kiri āhua waenga-parauri',
    '🧝🏿' => 'erepe: kiri āhua parauri',
    '💆🏻' => 'tangata whiwhi mirimiri: kiri āhua māmā',
    '💆🏼' => 'tangata whiwhi mirimiri: kiri āhua māmā-waenga',
    '💆🏽' => 'tangata whiwhi mirimiri: kiri āhua waenga',
    '💆🏾' => 'tangata whiwhi mirimiri: kiri āhua waenga-parauri',
    '💆🏿' => 'tangata whiwhi mirimiri: kiri āhua parauri',
    '💇🏻' => 'tangata whiwhi kutinga makawe: kiri āhua māmā',
    '💇🏼' => 'tangata whiwhi kutinga makawe: kiri āhua māmā-waenga',
    '💇🏽' => 'tangata whiwhi kutinga makawe: kiri āhua waenga',
    '💇🏾' => 'tangata whiwhi kutinga makawe: kiri āhua waenga-parauri',
    '💇🏿' => 'tangata whiwhi kutinga makawe: kiri āhua parauri',
    '🚶🏻' => 'tangata hīkoi: kiri āhua māmā',
    '🚶🏼' => 'tangata hīkoi: kiri āhua māmā-waenga',
    '🚶🏽' => 'tangata hīkoi: kiri āhua waenga',
    '🚶🏾' => 'tangata hīkoi: kiri āhua waenga-parauri',
    '🚶🏿' => 'tangata hīkoi: kiri āhua parauri',
    '🏃🏻' => 'tangata oma: kiri āhua māmā',
    '🏃🏼' => 'tangata oma: kiri āhua māmā-waenga',
    '🏃🏽' => 'tangata oma: kiri āhua waenga',
    '🏃🏾' => 'tangata oma: kiri āhua waenga-parauri',
    '🏃🏿' => 'tangata oma: kiri āhua parauri',
    '💃🏻' => 'wahine kanikani: kiri āhua māmā',
    '💃🏼' => 'wahine kanikani: kiri āhua māmā-waenga',
    '💃🏽' => 'wahine kanikani: kiri āhua waenga',
    '💃🏾' => 'wahine kanikani: kiri āhua waenga-parauri',
    '💃🏿' => 'wahine kanikani: kiri āhua parauri',
    '🕺🏻' => 'tāne kanikani: kiri āhua māmā',
    '🕺🏼' => 'tāne kanikani: kiri āhua māmā-waenga',
    '🕺🏽' => 'tāne kanikani: kiri āhua waenga',
    '🕺🏾' => 'tāne kanikani: kiri āhua waenga-parauri',
    '🕺🏿' => 'tāne kanikani: kiri āhua parauri',
    '🕴🏻' => 'tāne mau hūtu e rewa ana: kiri āhua māmā',
    '🕴🏼' => 'tāne mau hūtu e rewa ana: kiri āhua māmā-waenga',
    '🕴🏽' => 'tāne mau hūtu e rewa ana: kiri āhua waenga',
    '🕴🏾' => 'tāne mau hūtu e rewa ana: kiri āhua waenga-parauri',
    '🕴🏿' => 'tāne mau hūtu e rewa ana: kiri āhua parauri',
    '👯🏻' => 'tāngata taringa rāpeti whakangahau: kiri āhua māmā',
    '👯🏼' => 'tāngata taringa rāpeti whakangahau: kiri āhua māmā-waenga',
    '👯🏽' => 'tāngata taringa rāpeti whakangahau: kiri āhua waenga',
    '👯🏾' => 'tāngata taringa rāpeti whakangahau: kiri āhua waenga-parauri',
    '👯🏿' => 'tāngata taringa rāpeti whakangahau: kiri āhua parauri',
    '🧖🏻' => 'tangata rō taiwhanga mamaoa: kiri āhua māmā',
    '🧖🏼' => 'tangata rō taiwhanga mamaoa: kiri āhua māmā-waenga',
    '🧖🏽' => 'tangata rō taiwhanga mamaoa: kiri āhua waenga',
    '🧖🏾' => 'tangata rō taiwhanga mamaoa: kiri āhua waenga-parauri',
    '🧖🏿' => 'tangata rō taiwhanga mamaoa: kiri āhua parauri',
    '🧗🏻' => 'tangata piki: kiri āhua māmā',
    '🧗🏼' => 'tangata piki: kiri āhua māmā-waenga',
    '🧗🏽' => 'tangata piki: kiri āhua waenga',
    '🧗🏾' => 'tangata piki: kiri āhua waenga-parauri',
    '🧗🏿' => 'tangata piki: kiri āhua parauri',
    '🏇🏻' => 'tauomaoma hoiho: kiri āhua māmā',
    '🏇🏼' => 'tauomaoma hoiho: kiri āhua māmā-waenga',
    '🏇🏽' => 'tauomaoma hoiho: kiri āhua waenga',
    '🏇🏾' => 'tauomaoma hoiho: kiri āhua waenga-parauri',
    '🏇🏿' => 'tauomaoma hoiho: kiri āhua parauri',
    '🏂🏻' => 'kaipaparetihuka: kiri āhua māmā',
    '🏂🏼' => 'kaipaparetihuka: kiri āhua māmā-waenga',
    '🏂🏽' => 'kaipaparetihuka: kiri āhua waenga',
    '🏂🏾' => 'kaipaparetihuka: kiri āhua waenga-parauri',
    '🏂🏿' => 'kaipaparetihuka: kiri āhua parauri',
    '🏌🏻' => 'tangata haupōro: kiri āhua māmā',
    '🏌🏼' => 'tangata haupōro: kiri āhua māmā-waenga',
    '🏌🏽' => 'tangata haupōro: kiri āhua waenga',
    '🏌🏾' => 'tangata haupōro: kiri āhua waenga-parauri',
    '🏌🏿' => 'tangata haupōro: kiri āhua parauri',
    '🏄🏻' => 'tangata whakaheke ngaru: kiri āhua māmā',
    '🏄🏼' => 'tangata whakaheke ngaru: kiri āhua māmā-waenga',
    '🏄🏽' => 'tangata whakaheke ngaru: kiri āhua waenga',
    '🏄🏾' => 'tangata whakaheke ngaru: kiri āhua waenga-parauri',
    '🏄🏿' => 'tangata whakaheke ngaru: kiri āhua parauri',
    '🚣🏻' => 'tangata hoe waka: kiri āhua māmā',
    '🚣🏼' => 'tangata hoe waka: kiri āhua māmā-waenga',
    '🚣🏽' => 'tangata hoe waka: kiri āhua waenga',
    '🚣🏾' => 'tangata hoe waka: kiri āhua waenga-parauri',
    '🚣🏿' => 'tangata hoe waka: kiri āhua parauri',
    '🏊🏻' => 'tangata kauhoe: kiri āhua māmā',
    '🏊🏼' => 'tangata kauhoe: kiri āhua māmā-waenga',
    '🏊🏽' => 'tangata kauhoe: kiri āhua waenga',
    '🏊🏾' => 'tangata kauhoe: kiri āhua waenga-parauri',
    '🏊🏿' => 'tangata kauhoe: kiri āhua parauri',
    '⛹🏻' => 'tangata tāwhana pōro: kiri āhua māmā',
    '⛹🏼' => 'tangata tāwhana pōro: kiri āhua māmā-waenga',
    '⛹🏽' => 'tangata tāwhana pōro: kiri āhua waenga',
    '⛹🏾' => 'tangata tāwhana pōro: kiri āhua waenga-parauri',
    '⛹🏿' => 'tangata tāwhana pōro: kiri āhua parauri',
    '🏋🏻' => 'tangata hiki taumaha: kiri āhua māmā',
    '🏋🏼' => 'tangata hiki taumaha: kiri āhua māmā-waenga',
    '🏋🏽' => 'tangata hiki taumaha: kiri āhua waenga',
    '🏋🏾' => 'tangata hiki taumaha: kiri āhua waenga-parauri',
    '🏋🏿' => 'tangata hiki taumaha: kiri āhua parauri',
    '🚴🏻' => 'tangata eke pahikara: kiri āhua māmā',
    '🚴🏼' => 'tangata eke pahikara: kiri āhua māmā-waenga',
    '🚴🏽' => 'tangata eke pahikara: kiri āhua waenga',
    '🚴🏾' => 'tangata eke pahikara: kiri āhua waenga-parauri',
    '🚴🏿' => 'tangata eke pahikara: kiri āhua parauri',
    '🚵🏻' => 'tangata eke pahikara maunga: kiri āhua māmā',
    '🚵🏼' => 'tangata eke pahikara maunga: kiri āhua māmā-waenga',
    '🚵🏽' => 'tangata eke pahikara maunga: kiri āhua waenga',
    '🚵🏾' => 'tangata eke pahikara maunga: kiri āhua waenga-parauri',
    '🚵🏿' => 'tangata eke pahikara maunga: kiri āhua parauri',
    '🤸🏻' => 'tangata kātawīra: kiri āhua māmā',
    '🤸🏼' => 'tangata kātawīra: kiri āhua māmā-waenga',
    '🤸🏽' => 'tangata kātawīra: kiri āhua waenga',
    '🤸🏾' => 'tangata kātawīra: kiri āhua waenga-parauri',
    '🤸🏿' => 'tangata kātawīra: kiri āhua parauri',
    '🤼🏻' => 'tāngata mamau: kiri āhua māmā',
    '🤼🏼' => 'tāngata mamau: kiri āhua māmā-waenga',
    '🤼🏽' => 'tāngata mamau: kiri āhua waenga',
    '🤼🏾' => 'tāngata mamau: kiri āhua waenga-parauri',
    '🤼🏿' => 'tāngata mamau: kiri āhua parauri',
    '🤽🏻' => 'tangata tākaro poro wai: kiri āhua māmā',
    '🤽🏼' => 'tangata tākaro poro wai: kiri āhua māmā-waenga',
    '🤽🏽' => 'tangata tākaro poro wai: kiri āhua waenga',
    '🤽🏾' => 'tangata tākaro poro wai: kiri āhua waenga-parauri',
    '🤽🏿' => 'tangata tākaro poro wai: kiri āhua parauri',
    '🤾🏻' => 'tangata tākaro poiringa: kiri āhua māmā',
    '🤾🏼' => 'tangata tākaro poiringa: kiri āhua māmā-waenga',
    '🤾🏽' => 'tangata tākaro poiringa: kiri āhua waenga',
    '🤾🏾' => 'tangata tākaro poiringa: kiri āhua waenga-parauri',
    '🤾🏿' => 'tangata tākaro poiringa: kiri āhua parauri',
    '🤹🏻' => 'tangata whiuwhiu: kiri āhua māmā',
    '🤹🏼' => 'tangata whiuwhiu: kiri āhua māmā-waenga',
    '🤹🏽' => 'tangata whiuwhiu: kiri āhua waenga',
    '🤹🏾' => 'tangata whiuwhiu: kiri āhua waenga-parauri',
    '🤹🏿' => 'tangata whiuwhiu: kiri āhua parauri',
    '🧘🏻' => 'tangata tūranga rotu: kiri āhua māmā',
    '🧘🏼' => 'tangata tūranga rotu: kiri āhua māmā-waenga',
    '🧘🏽' => 'tangata tūranga rotu: kiri āhua waenga',
    '🧘🏾' => 'tangata tūranga rotu: kiri āhua waenga-parauri',
    '🧘🏿' => 'tangata tūranga rotu: kiri āhua parauri',
    '🛀🏻' => 'tangata kaukau ana: kiri āhua māmā',
    '🛀🏼' => 'tangata kaukau ana: kiri āhua māmā-waenga',
    '🛀🏽' => 'tangata kaukau ana: kiri āhua waenga',
    '🛀🏾' => 'tangata kaukau ana: kiri āhua waenga-parauri',
    '🛀🏿' => 'tangata kaukau ana: kiri āhua parauri',
    '🛌🏻' => 'tangata rō moenga: kiri āhua māmā',
    '🛌🏼' => 'tangata rō moenga: kiri āhua māmā-waenga',
    '🛌🏽' => 'tangata rō moenga: kiri āhua waenga',
    '🛌🏾' => 'tangata rō moenga: kiri āhua waenga-parauri',
    '🛌🏿' => 'tangata rō moenga: kiri āhua parauri',
    '👭🏻' => 'tokorua wāhine mau ringa: kiri āhua māmā',
    '👭🏼' => 'tokorua wāhine mau ringa: kiri āhua māmā-waenga',
    '👭🏽' => 'tokorua wāhine mau ringa: kiri āhua waenga',
    '👭🏾' => 'tokorua wāhine mau ringa: kiri āhua waenga-parauri',
    '👭🏿' => 'tokorua wāhine mau ringa: kiri āhua parauri',
    '👫🏻' => 'tāne me te wahine mau ringa: kiri āhua māmā',
    '👫🏼' => 'tāne me te wahine mau ringa: kiri āhua māmā-waenga',
    '👫🏽' => 'tāne me te wahine mau ringa: kiri āhua waenga',
    '👫🏾' => 'tāne me te wahine mau ringa: kiri āhua waenga-parauri',
    '👫🏿' => 'tāne me te wahine mau ringa: kiri āhua parauri',
    '👬🏻' => 'tokorua tāne mau ringa: kiri āhua māmā',
    '👬🏼' => 'tokorua tāne mau ringa: kiri āhua māmā-waenga',
    '👬🏽' => 'tokorua tāne mau ringa: kiri āhua waenga',
    '👬🏾' => 'tokorua tāne mau ringa: kiri āhua waenga-parauri',
    '👬🏿' => 'tokorua tāne mau ringa: kiri āhua parauri',
    '💏🏻' => 'kihi: kiri āhua māmā',
    '💏🏼' => 'kihi: kiri āhua māmā-waenga',
    '💏🏽' => 'kihi: kiri āhua waenga',
    '💏🏾' => 'kihi: kiri āhua waenga-parauri',
    '💏🏿' => 'kihi: kiri āhua parauri',
    '💑🏻' => 'tokorua me te manawa: kiri āhua māmā',
    '💑🏼' => 'tokorua me te manawa: kiri āhua māmā-waenga',
    '💑🏽' => 'tokorua me te manawa: kiri āhua waenga',
    '💑🏾' => 'tokorua me te manawa: kiri āhua waenga-parauri',
    '💑🏿' => 'tokorua me te manawa: kiri āhua parauri',
    '🇦🇨' => 'haki: Te Moutere Aupikinga',
    '🇦🇩' => 'haki: Anatōra',
    '🇦🇪' => 'haki: Kotahitanga o ngā Whenua o Ārapi',
    '🇦🇫' => 'haki: Awhekenetāna',
    '🇦🇬' => 'haki: Motu Nehe me Pāputa',
    '🇦🇮' => 'haki: Anguira',
    '🇦🇱' => 'haki: Arapeinia',
    '🇦🇲' => 'haki: Āmenia',
    '🇦🇴' => 'haki: Anakora',
    '🇦🇶' => 'haki: Te Kōpakatanga ki te Tonga',
    '🇦🇷' => 'haki: Āketina',
    '🇦🇸' => 'haki: Hāmoa-Amerika',
    '🇦🇹' => 'haki: Ataria',
    '🇦🇺' => 'haki: Ahitereiria',
    '🇦🇼' => 'haki: Arūpa',
    '🇦🇽' => 'haki: Motu Ōrana',
    '🇦🇿' => 'haki: Atepaihānia',
    '🇧🇦' => 'haki: Pōngia & Herekōwini',
    '🇧🇧' => 'haki: Papatohe',
    '🇧🇩' => 'haki: Pākaratēhi',
    '🇧🇪' => 'haki: Peretiama',
    '🇧🇫' => 'haki: Pākina Wharo',
    '🇧🇬' => 'haki: Purukāria',
    '🇧🇭' => 'haki: Pāreina',
    '🇧🇮' => 'haki: Puruniti',
    '🇧🇯' => 'haki: Penīna',
    '🇧🇱' => 'haki: Hato Pāteremi',
    '🇧🇲' => 'haki: Pāmura',
    '🇧🇳' => 'haki: Poronai',
    '🇧🇴' => 'haki: Poriwia',
    '🇧🇶' => 'haki: Karapīana Hōrana',
    '🇧🇷' => 'haki: Parīhi',
    '🇧🇸' => 'haki: Pahama',
    '🇧🇹' => 'haki: Pūtana',
    '🇧🇻' => 'haki: Motu Pūwei',
    '🇧🇼' => 'haki: Poriwana',
    '🇧🇾' => 'haki: Pērara',
    '🇧🇿' => 'haki: Perīhi',
    '🇨🇦' => 'haki: Kānata',
    '🇨🇨' => 'haki: Ngā Moutere Kokoko (Kirini)',
    '🇨🇩' => 'haki: Kōngo - Kinihāha',
    '🇨🇫' => 'haki: Te Whenua Tūhake o Āwherika Waenga',
    '🇨🇬' => 'haki: Kōngo - Pārawhe',
    '🇨🇭' => 'haki: Huiterangi',
    '🇨🇮' => 'haki: Te Tai Rei',
    '🇨🇰' => 'haki: Kuki Airani',
    '🇨🇱' => 'haki: Hiri',
    '🇨🇲' => 'haki: Kamarūna',
    '🇨🇳' => 'haki: Haina',
    '🇨🇴' => 'haki: Koromōpia',
    '🇨🇵' => 'haki: Te Moutere Kiripetone',
    '🇨🇶' => 'haki: Hāka',
    '🇨🇷' => 'haki: Koto Rīka',
    '🇨🇺' => 'haki: Kiupa',
    '🇨🇻' => 'haki: Te Kūrae Matomato',
    '🇨🇼' => 'haki: Kurahao',
    '🇨🇽' => 'haki: Te Moutere Kirihimete',
    '🇨🇾' => 'haki: Haipara',
    '🇨🇿' => 'haki: Tiekia',
    '🇩🇪' => 'haki: Tiamana',
    '🇩🇬' => 'haki: Tieko Kāhia',
    '🇩🇯' => 'haki: Tipūti',
    '🇩🇰' => 'haki: Tenemāka',
    '🇩🇲' => 'haki: Tominika',
    '🇩🇴' => 'haki: Te Whenua Tūhake o Tominika',
    '🇩🇿' => 'haki: Aratiria',
    '🇪🇦' => 'haki: Hūta me Merera',
    '🇪🇨' => 'haki: Ekuatoa',
    '🇪🇪' => 'haki: Etōnia',
    '🇪🇬' => 'haki: Īhipa',
    '🇪🇭' => 'haki: Hahāra ki te Tonga',
    '🇪🇷' => 'haki: Eritēria',
    '🇪🇸' => 'haki: Peina',
    '🇪🇹' => 'haki: Etiopia',
    '🇪🇺' => 'haki: Te Uniana o Ūropi',
    '🇫🇮' => 'haki: Whinarana',
    '🇫🇯' => 'haki: Whītī',
    '🇫🇰' => 'haki: Motu Whākarangi',
    '🇫🇲' => 'haki: Mekanēhia',
    '🇫🇴' => 'haki: Motu Wharau',
    '🇫🇷' => 'haki: Wīwī',
    '🇬🇦' => 'haki: Kāpona',
    '🇬🇧' => 'haki: Te Hononga o Piritene',
    '🇬🇩' => 'haki: Kerenāta',
    '🇬🇪' => 'haki: Hōria',
    '🇬🇫' => 'haki: Kiāna Wīwī',
    '🇬🇬' => 'haki: Kōnihi',
    '🇬🇭' => 'haki: Kāna',
    '🇬🇮' => 'haki: Kāmaka',
    '🇬🇱' => 'haki: Whenuakāriki',
    '🇬🇲' => 'haki: Kamopia',
    '🇬🇳' => 'haki: Kini',
    '🇬🇵' => 'haki: Kuatarupa',
    '🇬🇶' => 'haki: Kini Ekuatoria',
    '🇬🇷' => 'haki: Kirihi',
    '🇬🇸' => 'haki: Hōria ki te Tonga me ngā Motu Hanawiti ki te Tonga',
    '🇬🇹' => 'haki: Kuatamāra',
    '🇬🇺' => 'haki: Kuama',
    '🇬🇼' => 'haki: Kini-Pihao',
    '🇬🇾' => 'haki: Kaiana',
    '🇭🇰' => 'haki: Hongipua Haina',
    '🇭🇲' => 'haki: Ngā Moutere Heriti me Makitānara',
    '🇭🇳' => 'haki: Honotura',
    '🇭🇷' => 'haki: Koroātia',
    '🇭🇹' => 'haki: Haiti',
    '🇭🇺' => 'haki: Hanekari',
    '🇮🇨' => 'haki: Motu Kanēre',
    '🇮🇩' => 'haki: Initonīhia',
    '🇮🇪' => 'haki: Airani',
    '🇮🇱' => 'haki: Iharaira',
    '🇮🇲' => 'haki: Te Moutere Mana',
    '🇮🇳' => 'haki: Inia',
    '🇮🇴' => 'haki: Te Rohe o te Moana Īniana Piritihi',
    '🇮🇶' => 'haki: Irāka',
    '🇮🇷' => 'haki: Irāna',
    '🇮🇸' => 'haki: Tiorangi',
    '🇮🇹' => 'haki: Itāria',
    '🇯🇪' => 'haki: Tōrehe',
    '🇯🇲' => 'haki: Hemeika',
    '🇯🇴' => 'haki: Hōrano',
    '🇯🇵' => 'haki: Hapani',
    '🇰🇪' => 'haki: Kenia',
    '🇰🇬' => 'haki: Kikitānga',
    '🇰🇭' => 'haki: Kamapōtia',
    '🇰🇮' => 'haki: Kiripati',
    '🇰🇲' => 'haki: Komoro',
    '🇰🇳' => 'haki: Hato Kiti me Newhi',
    '🇰🇵' => 'haki: Kōrea ki te Raki',
    '🇰🇷' => 'haki: Kōrea ki te Tonga',
    '🇰🇼' => 'haki: Kūweiti',
    '🇰🇾' => 'haki: Ngā Motu Keimana',
    '🇰🇿' => 'haki: Katatānga',
    '🇱🇦' => 'haki: Rāoho',
    '🇱🇧' => 'haki: Repanona',
    '🇱🇨' => 'haki: Hato Ruhia',
    '🇱🇮' => 'haki: Rīkenetaina',
    '🇱🇰' => 'haki: Hiri Rānaka',
    '🇱🇷' => 'haki: Raipiria',
    '🇱🇸' => 'haki: Teroto',
    '🇱🇹' => 'haki: Rituānia',
    '🇱🇺' => 'haki: Rakapuō',
    '🇱🇻' => 'haki: Rāwhia',
    '🇱🇾' => 'haki: Ripia',
    '🇲🇦' => 'haki: Moroko',
    '🇲🇨' => 'haki: Monāko',
    '🇲🇩' => 'haki: Morotawa',
    '🇲🇪' => 'haki: Maungakororiko',
    '🇲🇫' => 'haki: Hato Mātene',
    '🇲🇬' => 'haki: Matakāhika',
    '🇲🇭' => 'haki: Ngā Motu Māhara',
    '🇲🇰' => 'haki: Makerōnia ki te Raki',
    '🇲🇱' => 'haki: Māri',
    '🇲🇲' => 'haki: Pēma',
    '🇲🇳' => 'haki: Mongōria',
    '🇲🇴' => 'haki: Makau Haina',
    '🇲🇵' => 'haki: Ngā Motu Mariana ki te Raki',
    '🇲🇶' => 'haki: Mātiniki',
    '🇲🇷' => 'haki: Mauritānia',
    '🇲🇸' => 'haki: Monoterā',
    '🇲🇹' => 'haki: Mārata',
    '🇲🇺' => 'haki: Marihi',
    '🇲🇻' => 'haki: Māratiri',
    '🇲🇼' => 'haki: Marāwi',
    '🇲🇽' => 'haki: Mēhiko',
    '🇲🇾' => 'haki: Mareia',
    '🇲🇿' => 'haki: Mohapiki',
    '🇳🇦' => 'haki: Namipia',
    '🇳🇨' => 'haki: Whenua Kanaki',
    '🇳🇪' => 'haki: Ngāika',
    '🇳🇫' => 'haki: Te Moutere Nōpoke',
    '🇳🇬' => 'haki: Ngāitiria',
    '🇳🇮' => 'haki: Nikarāhua',
    '🇳🇱' => 'haki: Hōrana',
    '🇳🇴' => 'haki: Nōwei',
    '🇳🇵' => 'haki: Nepōra',
    '🇳🇷' => 'haki: Nauru',
    '🇳🇺' => 'haki: Niue',
    '🇳🇿' => 'haki: Aotearoa',
    '🇴🇲' => 'haki: Ōmana',
    '🇵🇦' => 'haki: Panama',
    '🇵🇪' => 'haki: Peru',
    '🇵🇫' => 'haki: Poronēhia Wīwī',
    '🇵🇬' => 'haki: Papua Nūkini',
    '🇵🇭' => 'haki: Piripīni',
    '🇵🇰' => 'haki: Pakitāne',
    '🇵🇱' => 'haki: Pōrana',
    '🇵🇲' => 'haki: Hato Piere & Mikerona',
    '🇵🇳' => 'haki: Pitikeina',
    '🇵🇷' => 'haki: Peta Riko',
    '🇵🇸' => 'haki: Ngā Rohe o Parihitini',
    '🇵🇹' => 'haki: Potukara',
    '🇵🇼' => 'haki: Pārau',
    '🇵🇾' => 'haki: Parakai',
    '🇶🇦' => 'haki: Katā',
    '🇷🇪' => 'haki: Reūnio',
    '🇷🇴' => 'haki: Romeinia',
    '🇷🇸' => 'haki: Hirupia',
    '🇷🇺' => 'haki: Rūhia',
    '🇷🇼' => 'haki: Rāwana',
    '🇸🇦' => 'haki: Hauri Arāpia',
    '🇸🇧' => 'haki: Ngā Motu Horomona',
    '🇸🇨' => 'haki: Heikere',
    '🇸🇩' => 'haki: Hūtāne',
    '🇸🇪' => 'haki: Huitene',
    '🇸🇬' => 'haki: Hingapoa',
    '🇸🇭' => 'haki: Hato Hērena',
    '🇸🇮' => 'haki: Horowinia',
    '🇸🇯' => 'haki: Heopara me Iana Maiana',
    '🇸🇰' => 'haki: Horowākia',
    '🇸🇱' => 'haki: Te Araone',
    '🇸🇲' => 'haki: Hana Marino',
    '🇸🇳' => 'haki: Henekara',
    '🇸🇴' => 'haki: Hūmārie',
    '🇸🇷' => 'haki: Huriname',
    '🇸🇸' => 'haki: Hūtāne ki te Tonga',
    '🇸🇹' => 'haki: Hato Tomei me Pirinipei',
    '🇸🇻' => 'haki: Whakaora',
    '🇸🇽' => 'haki: Hiti Mātene',
    '🇸🇾' => 'haki: Hiria',
    '🇸🇿' => 'haki: Ehiwatini',
    '🇹🇦' => 'haki: Tiritana da Kunia',
    '🇹🇨' => 'haki: Koru-Kākoa',
    '🇹🇩' => 'haki: Kāta',
    '🇹🇫' => 'haki: Ngā Rohe o Wīwī ki te Tonga',
    '🇹🇬' => 'haki: Toko',
    '🇹🇭' => 'haki: Tairanga',
    '🇹🇯' => 'haki: Takiritānga',
    '🇹🇰' => 'haki: Tokerau',
    '🇹🇱' => 'haki: Tīmoa ki te Rāwhiti',
    '🇹🇲' => 'haki: Tukumanatānga',
    '🇹🇳' => 'haki: Tūnihia',
    '🇹🇴' => 'haki: Tonga',
    '🇹🇷' => 'haki: Tākei',
    '🇹🇹' => 'haki: Tirinaki Tōpako',
    '🇹🇻' => 'haki: Tūwaru',
    '🇹🇼' => 'haki: Taiwana',
    '🇹🇿' => 'haki: Tānahia',
    '🇺🇦' => 'haki: Ukareinga',
    '🇺🇬' => 'haki: Ukānga',
    '🇺🇲' => 'haki: Ngā Moutere Amerika o Waho',
    '🇺🇳' => 'haki: Te Rūnanga Whakakotahi i ngā Iwi o te Ao',
    '🇺🇸' => 'haki: Hononga o Amerika',
    '🇺🇾' => 'haki: Urukoi',
    '🇺🇿' => 'haki: Uhipeketāne',
    '🇻🇦' => 'haki: Te Poho-o-Pita',
    '🇻🇨' => 'haki: Hato Wēneti me Keretīni',
    '🇻🇪' => 'haki: Penehūera',
    '🇻🇬' => 'haki: Ngā Moutere Puhi Piritene',
    '🇻🇮' => 'haki: Ngā Moutere Puhi Amerika',
    '🇻🇳' => 'haki: Whitināmu',
    '🇻🇺' => 'haki: Whenuatū',
    '🇼🇫' => 'haki: Warihi me Whutuna',
    '🇼🇸' => 'haki: Hāmoa',
    '🇽🇰' => 'haki: Kōhoro',
    '🇾🇪' => 'haki: Īmene',
    '🇾🇹' => 'haki: Māiota',
    '🇿🇦' => 'haki: Āwherika ki te Tonga',
    '🇿🇲' => 'haki: Tāmipia',
    '🇿🇼' => 'haki: Timuwawe',
    '🔟' => 'uhi pātuhi: 10',
    '🏻' => 'kiri āhua māmā',
    '🏼' => 'kiri āhua māmā-waenga',
    '🏽' => 'kiri āhua waenga',
    '🏾' => 'kiri āhua waenga-parauri',
    '🏿' => 'kiri āhua parauri',
    '😀' => 'kanohi pakiri',
    '😃' => 'kanohi menemene waha tuwhera',
    '😄' => 'kanohi menemene waha tuwhera me ngā karu menemene',
    '😁' => 'kanohi pakiri karu menemene',
    '😆' => 'kanohi menemene waha tuwhera me ngā karu kopi',
    '😅' => 'kanohi menemene waha tuwhera me te werawera mātao',
    '🤣' => 'takaoriori ana i te papa me te katakata',
    '😂' => 'kanohi roimata harikoa',
    '🙂' => 'kanohi menemene iti',
    '🙃' => 'kanohi huripoki',
    '😉' => 'kanohi kimokimo',
    '😊' => 'kanohi menemene karu menemene',
    '😇' => 'kanohi menemene whai āwheo',
    '😍' => 'kanohi menemene karu-manawa',
    '🤩' => 'tino mīharotia',
    '😘' => 'kanohi pupuhi kihi',
    '😗' => 'kanohi kihikihi',
    '☺' => 'kanohi menemene',
    '😚' => 'kanohi kihikihi karu kopi',
    '😙' => 'kanohi kihikihi karu menemene',
    '😋' => 'kanohi tāwara kai reka',
    '😛' => 'kanohi whātero',
    '😜' => 'kanohi whātero karu kimokimo',
    '🤪' => 'kanohi pōrangi',
    '😝' => 'kanohi whātero karu kopi',
    '🤑' => 'kanohi waha-moni',
    '🤗' => 'kanohi awhiawhi',
    '🤭' => 'kanohi ringa runga waha',
    '🤫' => 'kanohi whakahū',
    '🤔' => 'kanohi whakaaroaro',
    '🤐' => 'kanohi waha-kōtui',
    '🤨' => 'kanohi tukemata rewa',
    '😐' => 'kanohi kūpapa',
    '😑' => 'kanohi whakaririka',
    '😶' => 'kanohi kore waha',
    '😏' => 'kanohi tāpahi',
    '😒' => 'kanohi katakore',
    '🙄' => 'kanohi karu takahuri',
    '😬' => 'kanohi whāita',
    '🤥' => 'kanohi teka',
    '😌' => 'kanohi whakaoraora',
    '😔' => 'kanohi whakaaro',
    '😪' => 'kanohi hiamoe',
    '🤤' => 'kanohi hāware',
    '😴' => 'kanohi moe',
    '😷' => 'kanohi mau ārai rongoā',
    '🤒' => 'kanohi whai inemahana',
    '🤕' => 'kanohi mau takai-upoko',
    '🤢' => 'kanohi kanekane',
    '🤮' => 'kanohi ruaki',
    '🤧' => 'kanohi matihe',
    '😵' => 'kanohi takaanini',
    '🤯' => 'māhunga pahū',
    '🤠' => 'kanohi pōtae kaupoi',
    '😎' => 'kanohi menemene mau mōhitirā',
    '🤓' => 'kanohi nere',
    '🧐' => 'kanohi mau mōhititahi',
    '😕' => 'kanohi pōraru',
    '😟' => 'kanohi āwangawanga',
    '🙁' => 'kanohi āhua poururu',
    '☹' => 'kanohi poururu',
    '😮' => 'kanohi waha tuwhera',
    '😯' => 'kanohi hanea',
    '😲' => 'kanohi ohorere',
    '😳' => 'kanohi werawera',
    '😦' => 'kanohi poururu waha tuwhera',
    '😧' => 'kanohi aurere',
    '😨' => 'kanohi mataku',
    '😰' => 'kanohi waha tuwhera me te werawera mātao',
    '😥' => 'kanohi pāpouri engari whakaoraora',
    '😢' => 'kanohi tatangi',
    '😭' => 'kanohi tangi reonui',
    '😱' => 'kanohi ūmere i te wehi',
    '😖' => 'kanohi whakahēhē',
    '😣' => 'kanohi pāuaua',
    '😞' => 'kanohi pāpōuri',
    '😓' => 'kanohi werawera mātao',
    '😩' => 'kanohi ruha',
    '😫' => 'kanohi ngenge',
    '😤' => 'kanohi ihu korohū',
    '😡' => 'kanohi tupere',
    '😠' => 'kanohi riri',
    '🤬' => 'kanohi tohu runga waha',
    '😈' => 'kanohi menemene whai pihi',
    '👿' => 'kanohi riri whai pihi',
    '💀' => 'angaanga',
    '☠' => 'angaanga me ngā kōiwi-whiri',
    '💩' => 'putunga tiko',
    '🤡' => 'kanohi hangareka',
    '👹' => 'kaurehe',
    '👺' => 'taipō',
    '👻' => 'kēhua',
    '👽' => 'manene aokē',
    '👾' => 'ngārara aokē',
    '🤖' => 'kanohi karetao',
    '😺' => 'kanohi ngeru menemene waha tuwhera',
    '😸' => 'kanohi ngeru pakiri karu menemene',
    '😹' => 'kanohi ngeru me ngā roimata harikoa',
    '😻' => 'kanohi ngeru menemene karu-manawa',
    '😼' => 'kanohi ngeru menemene pūkawa',
    '😽' => 'kanohi ngeru kihikihi karu kopi',
    '🙀' => 'kanohi ngeru ruha',
    '😿' => 'kanohi ngeru tatangi',
    '😾' => 'kanohi ngeru tupere',
    '🙈' => 'makimaki kore-kite-kino',
    '🙉' => 'makimaki kore-rongo-kino',
    '🙊' => 'makimaki kore-kōrero-kino',
    '💌' => 'reta aroha',
    '💘' => 'manawa me te pere',
    '💝' => 'manawa mau rīpene',
    '💖' => 'manawa tīaho',
    '💗' => 'manawa tipu haere',
    '💓' => 'manawa patupatu',
    '💞' => 'ngā manawa takahurihuri',
    '💕' => 'rua manawa',
    '💟' => 'rākeitanga manawa',
    '❣' => 'tohuhā manawa pā',
    '💔' => 'manawa whati',
    '❤' => 'manawa whero',
    '🧡' => 'manawa karaka',
    '💛' => 'manawa kōwhai',
    '💚' => 'manawa kākāriki',
    '💙' => 'manawa kikorangi',
    '💜' => 'manawa poroporo',
    '🖤' => 'manawa pango',
    '💋' => 'tohu kihi',
    '💯' => 'rau piro',
    '💢' => 'tohu riri',
    '💥' => 'tutukitanga',
    '💫' => 'whakaamai',
    '💦' => 'ngā kōpata werawera',
    '💨' => 'rere atu ana',
    '🕳' => 'puare',
    '💬' => 'pūangi kōrero',
    '🗨' => 'mirumiru kōrero mauī',
    '🗯' => 'mirumiru riri matau',
    '💭' => 'pūangi whakaaro',
    '💤' => 'zzz',
    '👋' => 'ringa pōhirihiri',
    '🤚' => 'tāmuri tū',
    '🖐' => 'ringa tū matimati paraha',
    '✋' => 'ringa tū',
    '🖖' => 'whakakōtua vulcan',
    '👌' => 'ringa ĀE',
    '✌' => 'ringa wikitōria',
    '🤞' => 'matimati whiri',
    '🤟' => 'tohu aroha-ki-a-koe',
    '🤘' => 'tohu o ngā pihi',
    '🤙' => 'ringa waea mai',
    '👈' => 'kōroa tāmuri tohu mauī',
    '👉' => 'kōroa tāmuri tohu matau',
    '👆' => 'kōroa tāmuri tohu ake',
    '🖕' => 'māpere',
    '👇' => 'kōroa tāmuri tohu iho',
    '☝' => 'kōroa tohu ake',
    '👍' => 'kōnui ake',
    '👎' => 'kōnui iho',
    '✊' => 'meke tū',
    '👊' => 'meke anga mai',
    '🤛' => 'meke anga-mauī',
    '🤜' => 'meke anga-matau',
    '👏' => 'ringa pakipaki',
    '🙌' => 'ngā ringa tū',
    '👐' => 'ringa tuwhera',
    '🤲' => 'ringa rewa tahi',
    '🤝' => 'rūrū',
    '🙏' => 'ringa whiri',
    '✍' => 'ringa tuhituhi',
    '💅' => 'pani maikūkū',
    '🤳' => 'kiriāhua',
    '💪' => 'uarua whakapakari',
    '👂' => 'taringa',
    '👃' => 'ihu',
    '🧠' => 'roro',
    '👀' => 'ngā karu',
    '👁' => 'karu',
    '👅' => 'arero',
    '👄' => 'waha',
    '👶' => 'pēpi',
    '🧒' => 'tamaiti',
    '👦' => 'tamatāne',
    '👧' => 'kōtiro',
    '🧑' => 'pakeke',
    '👱' => 'tangata mākekehu',
    '👨' => 'tāne',
    '🧔' => 'tangata pāhau',
    '👩' => 'wahine',
    '🧓' => 'kaumātua',
    '👴' => 'koroua',
    '👵' => 'kuia',
    '🙍' => 'tangata poururu',
    '🙎' => 'tangata tupere',
    '🙅' => 'tangata tohu ana KĀO',
    '🙆' => 'tangata tohu ana ĀE',
    '💁' => 'tangata ringa tāringi',
    '🙋' => 'tangata ringa tū',
    '🙇' => 'tangata tuohu',
    '🤦' => 'tangata ringakanohi',
    '🤷' => 'tangata hiki-pakihiwi',
    '👮' => 'āpiha pirihimana',
    '🕵' => 'kaikimihara',
    '💂' => 'tautieki',
    '👷' => 'kaimahi hangatanga',
    '🤴' => 'piriniha',
    '👸' => 'pirinihi',
    '👳' => 'tangata mau pōtae kameta',
    '👲' => 'tāne mau kape hainīhi',
    '🧕' => 'wahine mau kāmeta',
    '🤵' => 'tāne mau hūtu ōkawa',
    '👰' => 'wahine mārena mau ārai',
    '🤰' => 'wahine hapū',
    '🤱' => 'whāngote-ū',
    '👼' => 'pīpī anahera',
    '🎅' => 'hana koko',
    '🤶' => 'kuia koko',
    '🧙' => 'tāngata matakite',
    '🧚' => 'patupaiarehe',
    '🧛' => 'kaitoto',
    '🧜' => 'tangata-ika',
    '🧝' => 'erepe',
    '🧞' => 'tūrehu',
    '🧟' => 'tūpāpaku',
    '💆' => 'tangata whiwhi mirimiri',
    '💇' => 'tangata whiwhi kutinga makawe',
    '🚶' => 'tangata hīkoi',
    '🏃' => 'tangata oma',
    '💃' => 'wahine kanikani',
    '🕺' => 'tāne kanikani',
    '🕴' => 'tāne mau hūtu e rewa ana',
    '👯' => 'tāngata taringa rāpeti whakangahau',
    '🧖' => 'tangata rō taiwhanga mamaoa',
    '🧗' => 'tangata piki',
    '🤺' => 'tangata matātuhi',
    '🏇' => 'tauomaoma hoiho',
    '⛷' => 'kairetihuka',
    '🏂' => 'kaipaparetihuka',
    '🏌' => 'tangata haupōro',
    '🏄' => 'tangata whakaheke ngaru',
    '🚣' => 'tangata hoe waka',
    '🏊' => 'tangata kauhoe',
    '⛹' => 'tangata tāwhana pōro',
    '🏋' => 'tangata hiki taumaha',
    '🚴' => 'tangata eke pahikara',
    '🚵' => 'tangata eke pahikara maunga',
    '🤸' => 'tangata kātawīra',
    '🤼' => 'tāngata mamau',
    '🤽' => 'tangata tākaro poro wai',
    '🤾' => 'tangata tākaro poiringa',
    '🤹' => 'tangata whiuwhiu',
    '🧘' => 'tangata tūranga rotu',
    '🛀' => 'tangata kaukau ana',
    '🛌' => 'tangata rō moenga',
    '👭' => 'tokorua wāhine mau ringa',
    '👫' => 'tāne me te wahine mau ringa',
    '👬' => 'tokorua tāne mau ringa',
    '💏' => 'kihi',
    '💑' => 'tokorua me te manawa',
    '🗣' => 'upoko kōrero',
    '👤' => 'poho rō ataata',
    '👥' => 'ngā poho rō ataata',
    '👪' => 'whānau',
    '👣' => 'ngā tapuwae',
    '🐵' => 'kanohi makimaki',
    '🐒' => 'makimaki',
    '🦍' => 'makimaki nui',
    '🐶' => 'kanohi kurī',
    '🐕' => 'kurī',
    '🐩' => 'kurī poipoi',
    '🐺' => 'kanohi wūruhi',
    '🦊' => 'kanohi pōkiha',
    '🐱' => 'kanohi ngeru',
    '🐈' => 'ngeru',
    '🦁' => 'kanohi raiona',
    '🐯' => 'kanohi taika',
    '🐅' => 'taika',
    '🐆' => 'reparo',
    '🐴' => 'kanohi hōiho',
    '🐎' => 'hōiho',
    '🦄' => 'kanohi hōiho pihi',
    '🦓' => 'hepapa',
    '🦌' => 'tia',
    '🐮' => 'kanohi kau',
    '🐂' => 'ōkiha',
    '🐃' => 'pūru wai',
    '🐄' => 'kau',
    '🐷' => 'kanohi poaka',
    '🐖' => 'poaka',
    '🐗' => 'poaka toa',
    '🐽' => 'ihu poaka',
    '🐏' => 'hipi toa',
    '🐑' => 'uha hipi',
    '🐐' => 'koati',
    '🐪' => 'kāmera',
    '🐫' => 'kāmera rua-tuapuku',
    '🦒' => 'kakīroa',
    '🐘' => 'erewhana',
    '🦏' => 'rinorino',
    '🐭' => 'kanohi kiore',
    '🐁' => 'kiore iti',
    '🐀' => 'kiore rahi',
    '🐹' => 'kanohi hamikiore',
    '🐰' => 'kanohi rāpeti',
    '🐇' => 'rāpeti',
    '🐿' => 'timahaki',
    '🦔' => 'tuatete',
    '🦇' => 'pekapeka',
    '🐻' => 'kanohi pea',
    '🐨' => 'koara',
    '🐼' => 'kanohi panara',
    '🐾' => 'ngā tā tapuwae',
    '🦃' => 'korukoru',
    '🐔' => 'heihei',
    '🐓' => 'tameheihei',
    '🐣' => 'pīpī timotimo',
    '🐤' => 'pīpī manu',
    '🐥' => 'pīpī manu anga mua',
    '🐦' => 'manu',
    '🐧' => 'kororā',
    '🕊' => 'kupupa',
    '🦅' => 'ekara',
    '🦆' => 'parera',
    '🦉' => 'ruru',
    '🐸' => 'kanohi poraka',
    '🐊' => 'nguturoa',
    '🐢' => 'honu',
    '🦎' => 'mokomoko',
    '🐍' => 'nākahi',
    '🐲' => 'kanohi tarakona',
    '🐉' => 'tarakona',
    '🦕' => 'sauropod',
    '🦖' => 'T-Rex',
    '🐳' => 'tohorā pupuhi',
    '🐋' => 'tohorā',
    '🐬' => 'aihe',
    '🐟' => 'ika',
    '🐠' => 'ika pārūrū',
    '🐡' => 'ikapupuhi',
    '🦈' => 'mangō',
    '🐙' => 'wheke',
    '🐚' => 'anga tōrino',
    '🦀' => 'pāpaka',
    '🦐' => 'kōuraura',
    '🦑' => 'ngū',
    '🐌' => 'hātaretare',
    '🦋' => 'pūrerehua',
    '🐛' => 'tātaka',
    '🐜' => 'pōpokorua',
    '🐝' => 'hanipī',
    '🐞' => 'pāpapa kōpure',
    '🦗' => 'kirikiti',
    '🕷' => 'ngārara',
    '🕸' => 'tukutuku ngārara',
    '🦂' => 'kopiona',
    '💐' => 'tākai putiputi',
    '🌸' => 'putiputi tieri',
    '💮' => 'putiputi mā',
    '🏵' => 'rōhiti',
    '🌹' => 'rōhi',
    '🥀' => 'putiputi kautaka',
    '🌺' => 'puarangi',
    '🌻' => 'putiputirā',
    '🌼' => 'puāwai',
    '🌷' => 'tūripi',
    '🌱' => 'tipu',
    '🌲' => 'rākau māota',
    '🌳' => 'rākau whakamakere rau',
    '🌴' => 'nīkau',
    '🌵' => 'tātā tiotio',
    '🌾' => 'kākati raihi',
    '🌿' => 'amiami',
    '☘' => 'hamitoka',
    '🍀' => 'koroa whā rau',
    '🍁' => 'rau mapera',
    '🍂' => 'rau makere',
    '🍃' => 'rau kapakapa hau',
    '🍄' => 'harore',
    '🍇' => 'ngā karepe',
    '🍈' => 'merengi',
    '🍉' => 'merengiwai',
    '🍊' => 'tāngarīni',
    '🍋' => 'rēmana',
    '🍌' => 'panana',
    '🍍' => 'paināporo',
    '🍎' => 'āporo whero',
    '🍏' => 'āporo kākāriki',
    '🍐' => 'pea',
    '🍑' => 'pītiti',
    '🍒' => 'ngā tieri',
    '🍓' => 'rōpere',
    '🥝' => 'hua kiwi',
    '🍅' => 'tomato',
    '🥥' => 'kokonati',
    '🥑' => 'awakāro',
    '🍆' => 'otahua',
    '🥔' => 'rīwai',
    '🥕' => 'kāroti',
    '🌽' => 'puku kānga',
    '🌶' => 'pepa wera',
    '🥒' => 'kūkama',
    '🥦' => 'porokori',
    '🥜' => 'pīnati',
    '🌰' => 'hetenati',
    '🍞' => 'parāoa',
    '🥐' => 'parāoarīpeka',
    '🥖' => 'parāoa pakete',
    '🥨' => 'pretzel',
    '🥞' => 'panekeke',
    '🧀' => 'matakahi tīhi',
    '🍖' => 'mīti runga kōiwi',
    '🍗' => 'waewae manu',
    '🥩' => 'tapahitanga mīti',
    '🥓' => 'pēkana',
    '🍔' => 'hāmipēka',
    '🍟' => 'ngā parai wīwī',
    '🍕' => 'parehe',
    '🌭' => 'kurī wera',
    '🥪' => 'hanewiti',
    '🌮' => 'tako',
    '🌯' => 'purito',
    '🥙' => 'parāoapapa whakakī',
    '🥚' => 'hēki',
    '🍳' => 'tao ana',
    '🥘' => 'pēne kai pāpaku',
    '🍲' => 'kōhua kai',
    '🥣' => 'paepae me te pūnu',
    '🥗' => 'huamata kākāriki',
    '🍿' => 'kāngapahū',
    '🥫' => 'kai kēne',
    '🍱' => 'pouaka peneto',
    '🍘' => 'pihikete raihi',
    '🍙' => 'pōro raihi',
    '🍚' => 'raihi maoa',
    '🍛' => 'raihi kari',
    '🍜' => 'paepae korohū',
    '🍝' => 'pakēti',
    '🍠' => 'kūmara tunutunu',
    '🍢' => 'otene',
    '🍣' => 'hūhi',
    '🍤' => 'kōuraura parai',
    '🍥' => 'keke ika whai koru',
    '🍡' => 'tāngoro',
    '🥟' => 'parāoa kinikini',
    '🥠' => 'pihikete matapae',
    '🥡' => 'pouaka kaweatu',
    '🍦' => 'aihikirīmi ngohengohe',
    '🍧' => 'huka heuheu',
    '🍨' => 'aihikirīmi',
    '🍩' => 'tōnati',
    '🍪' => 'pihikete',
    '🎂' => 'keke rāwhānau',
    '🍰' => 'kekepoto',
    '🥧' => 'pāi',
    '🍫' => 'pae tiokorete',
    '🍬' => 'rare',
    '🍭' => 'rarepapa',
    '🍮' => 'katete',
    '🍯' => 'paepae honi',
    '🍼' => 'pātara pēpi',
    '🥛' => 'karāhe miraka',
    '☕' => 'unu wera',
    '🍵' => 'tīkapu kore kakau',
    '🍶' => 'hake',
    '🍾' => 'pātara puru pahū',
    '🍷' => 'karāhe waina',
    '🍸' => 'karāhe unuranu',
    '🍹' => 'unu pārūrū',
    '🍺' => 'maka pia',
    '🍻' => 'ngā maka pia tutuki',
    '🥂' => 'karāhe tutuki',
    '🥃' => 'karāhe ipurau',
    '🥤' => 'kapu me te ngongo',
    '🥢' => 'rākaukai',
    '🍽' => 'paoka me naihi me pereti',
    '🍴' => 'paoka me te naihi',
    '🥄' => 'pūnu',
    '🔪' => 'naihi kīhini',
    '🏺' => 'amapora',
    '🌍' => 'ao whakakite Uropi-Āwherika',
    '🌎' => 'ao whakakite i ngā Amerika',
    '🌏' => 'ao whakakite Āhia-Ahitereiria',
    '🌐' => 'ao whai poutūmārō',
    '🗺' => 'mahere ao',
    '🗾' => 'mahere o Hapani',
    '🏔' => 'maunga tihi-hukarere',
    '⛰' => 'maunga',
    '🌋' => 'puia',
    '🗻' => 'maunga fuji',
    '🏕' => 'puninga',
    '🏖' => 'onepū me te hāmarara',
    '🏜' => 'kōraha',
    '🏝' => 'motu kōraha',
    '🏞' => 'papa rēhia ā-motu',
    '🏟' => 'taiwhanga hākinakina',
    '🏛' => 'hanganga tauhira',
    '🏗' => 'hangatanga whare',
    '🏘' => 'ngā whare',
    '🏚' => 'whare pāea',
    '🏠' => 'whare',
    '🏡' => 'whare me te māra',
    '🏢' => 'hanganga tari',
    '🏣' => 'poutāpeta Hapanīhi',
    '🏤' => 'poutāpeta',
    '🏥' => 'hōhipera',
    '🏦' => 'pēke',
    '🏨' => 'hōtēra',
    '🏩' => 'hōtēra aroha',
    '🏪' => 'pātaka haratau',
    '🏫' => 'kura',
    '🏬' => 'pātaka taiwhanga maha',
    '🏭' => 'wheketere',
    '🏯' => 'whare kīngi Hapanīhi',
    '🏰' => 'whare kīngi',
    '💒' => 'mārenatanga',
    '🗼' => 'pourewa Tōkio',
    '🗽' => 'te whakapakoko rangatiratanga',
    '⛪' => 'hāhi',
    '🕌' => 'mōhiku',
    '🕍' => 'whare karakia hūrae',
    '⛩' => 'wāhi tapu hinito',
    '🕋' => 'kaapa',
    '⛲' => 'puna torotī',
    '⛺' => 'tēneti',
    '🌁' => 'kohukohu',
    '🌃' => 'pō whai whetū',
    '🏙' => 'ataata tāonenui',
    '🌄' => 'whitinga rā runga maunga',
    '🌅' => 'whitinga o te rā',
    '🌆' => 'whakahuahua tāonenui porehu',
    '🌇' => 'tōnga o te rā',
    '🌉' => 'arawhata i te pō',
    '♨' => 'wai ariki',
    '🎠' => 'hōiho porowhawhe',
    '🎡' => 'wīra pērihi',
    '🎢' => 'tereina tō-ā-papa whakangahau',
    '💈' => 'pou kaikuti-makawe',
    '🎪' => 'tēneti manini rau',
    '🚂' => 'pūkaha tereina',
    '🚃' => 'waka rerewē',
    '🚄' => 'tereina tino tere',
    '🚅' => 'tereina tino tere ihu matā',
    '🚆' => 'tereina',
    '🚇' => 'rarowhenua',
    '🚈' => 'rerewē māmā',
    '🚉' => 'teihana',
    '🚊' => 'tarāme',
    '🚝' => 'rōautahi',
    '🚞' => 'rerewē maunga',
    '🚋' => 'waka tarāme',
    '🚌' => 'pahi',
    '🚍' => 'pahi anga mai',
    '🚎' => 'waka pāhiko',
    '🚐' => 'pahi iti',
    '🚑' => 'waka tūroro',
    '🚒' => 'waka tinei ahi',
    '🚓' => 'waka pirihimana',
    '🚔' => 'waka pirihimana anga mai',
    '🚕' => 'takihī',
    '🚖' => 'takihī anga mai',
    '🚗' => 'motokā',
    '🚘' => 'motokā anga mai',
    '🚙' => 'taraka hākinakina',
    '🚚' => 'taraka tiki',
    '🚛' => 'taraka tautō',
    '🚜' => 'tarakita',
    '🏎' => 'motokā tauwhainga',
    '🏍' => 'motopaika',
    '🛵' => 'hūpaika',
    '🚲' => 'pahikara',
    '🛴' => 'kuta whana',
    '🚏' => 'tūnga pahi',
    '🛣' => 'huanui',
    '🛤' => 'ara rerewē',
    '🛢' => 'taramu hinu',
    '⛽' => 'papu hinu',
    '🚨' => 'rama waka pirihimana',
    '🚥' => 'rama huarahi haupae',
    '🚦' => 'rama huarahi poutū',
    '🛑' => 'tohu tū',
    '🚧' => 'hangatanga',
    '⚓' => 'punga',
    '⛵' => 'waka pere',
    '🛶' => 'waka',
    '🚤' => 'wakatere',
    '🛳' => 'kaipuke pāhihi',
    '⛴' => 'waka kawekawe',
    '🛥' => 'waka pūkaha',
    '🚢' => 'kaipuke',
    '✈' => 'waka rererangi',
    '🛩' => 'rererangi iti',
    '🛫' => 'wehenga rererangi',
    '🛬' => 'taunga rererangi',
    '💺' => 'nohoanga',
    '🚁' => 'toparere',
    '🚟' => 'rerewē whakairi',
    '🚠' => 'arataura maunga',
    '🚡' => 'aratarāme rererangi',
    '🛰' => 'āmiorangi',
    '🚀' => 'tākirirangi',
    '🛸' => 'waka ātea nō ao kē',
    '🛎' => 'pere kaikawe',
    '⌛' => 'karāhe-hāora',
    '⏳' => 'karāhe-hāora kirikiri rere',
    '⌚' => 'matawā',
    '⏰' => 'karaka pūoho',
    '⏱' => 'matawā-tū',
    '⏲' => 'karaka pūtaki',
    '🕰' => 'karaka whatanga-ahi',
    '🕛' => 'te tekau-mā-rua o ngā hāora',
    '🕧' => 'te tekau-mā-rua me te toru tekau meneti',
    '🕐' => 'te tahi o ngā hāora',
    '🕜' => 'te tahi me te toru tekau meneti',
    '🕑' => 'te rua o ngā hāora',
    '🕝' => 'te rua me te toru tekau meneti',
    '🕒' => 'te toru o ngā hāora',
    '🕞' => 'te toru me te toru tekau meneti',
    '🕓' => 'te whā o ngā hāora',
    '🕟' => 'te whā me te toru tekau meneti',
    '🕔' => 'te rima o ngā hāora',
    '🕠' => 'te rima me te toru tekau meneti',
    '🕕' => 'te ono o ngā hāora',
    '🕡' => 'te ono me te toru tekau meneti',
    '🕖' => 'te whitu o ngā hāora',
    '🕢' => 'te whitu me te toru tekau meneti',
    '🕗' => 'te waru o ngā hāora',
    '🕣' => 'te waru me te toru tekau meneti',
    '🕘' => 'te iwa o ngā hāora',
    '🕤' => 'te iwa me te toru tekau meneti',
    '🕙' => 'te tekau o ngā hāora',
    '🕥' => 'te tekau me te toru tekau meneti',
    '🕚' => 'te tekau-mā-tahi o ngā hāora',
    '🕦' => 'te tekau-mā-tahi me te toru tekau meneti',
    '🌑' => 'marama kōhiti',
    '🌒' => 'marama hua tipihori',
    '🌓' => 'marama ahotū',
    '🌔' => 'marama hua',
    '🌕' => 'rākaunui',
    '🌖' => 'marama roroku',
    '🌗' => 'marama korekore',
    '🌘' => 'marama tohi',
    '🌙' => 'marama pewa',
    '🌚' => 'mata marama kōhiti',
    '🌛' => 'marama ahotū whai mata',
    '🌜' => 'marama korekore whai mata',
    '🌡' => 'inemahana',
    '☀' => 'rā',
    '🌝' => 'rākaunui whai mata',
    '🌞' => 'rā whai mata',
    '⭐' => 'whetū mā waenga',
    '🌟' => 'whetū mumura',
    '🌠' => 'unahi o takero',
    '🌌' => 'ikarangi',
    '☁' => 'kapua',
    '⛅' => 'rā muri kapua',
    '⛈' => 'kapua me te uira me te ua',
    '🌤' => 'rā muri kapua iti',
    '🌥' => 'rā muri kapua nui',
    '🌦' => 'rā muri kapua ua',
    '🌧' => 'kapua me te ua',
    '🌨' => 'kapua me te hukarere',
    '🌩' => 'kapua me te uira',
    '🌪' => 'āwhā',
    '🌫' => 'kohu',
    '🌬' => 'kanohi hau',
    '🌀' => 'kurahau awatea',
    '🌈' => 'kahukura',
    '🌂' => 'hāmarara kopi',
    '☂' => 'hāmarara',
    '☔' => 'hāmarara me ngā kōpata ua',
    '⛱' => 'hāmarara i te papa',
    '⚡' => 'ngaohiko teitei',
    '❄' => 'whā hukarere',
    '☃' => 'tāne-hukarere',
    '⛄' => 'tāne-hukarere kore hukarere',
    '☄' => 'unahiroa',
    '🔥' => 'ahi',
    '💧' => 'kōpata wai',
    '🌊' => 'ngaru wai',
    '🎃' => 'rama kanohi paukena',
    '🎄' => 'rākau Kirihimete',
    '🎆' => 'pahūahi',
    '🎇' => 'whakakorakora',
    '✨' => 'he korakora',
    '🎈' => 'pūangi',
    '🎉' => 'pahū whakangahau',
    '🎊' => 'pōro wāhi pepa',
    '🎋' => 'rākau tanapata',
    '🎍' => 'whakarei rākau paina',
    '🎎' => 'karetao Hapanīhi',
    '🎏' => 'haki ika',
    '🎐' => 'pere hau',
    '🎑' => 'taurima tiro marama',
    '🎀' => 'rīpene',
    '🎁' => 'perehana takai',
    '🎗' => 'rīpene whakamahara',
    '🎟' => 'tīkiti tomonga',
    '🎫' => 'tīkiti',
    '🎖' => 'metara ope tauā',
    '🏆' => 'tohu toa',
    '🏅' => 'mētara hākinakina',
    '🥇' => 'mētara wāhi 1',
    '🥈' => 'mētara wāhi 2',
    '🥉' => 'mētara wāhi 3',
    '⚽' => 'poi whana',
    '⚾' => 'pēhipōro',
    '🏀' => 'poitūkohu',
    '🏐' => 'poirewa',
    '🏈' => 'whutupōro amerikana',
    '🏉' => 'whutupōro rakapi',
    '🎾' => 'tēnehi',
    '🎳' => 'poipīrori',
    '🏏' => 'kēmu kirikiti',
    '🏑' => 'haupoi papa tākaro',
    '🏒' => 'haupoi huka',
    '🏓' => 'paopao',
    '🏸' => 'pūkura',
    '🥊' => 'karapu mekemeke',
    '🥋' => 'kākahu toi whawhai',
    '🥅' => 'neti ūhunga',
    '⛳' => 'kara rō kōhao',
    '⛸' => 'retireti keo',
    '🎣' => 'matira hī ika',
    '🎽' => 'hāte omaoma',
    '🎿' => 'papa retihuka',
    '🛷' => 'kōneke',
    '🥌' => 'pōhatu whakakōrino',
    '🎯' => 'pā hāngai',
    '🔫' => 'pū',
    '🎱' => 'piriota 8 pōro',
    '🔮' => 'pōro atamaha',
    '🎮' => 'kēmu ataata',
    '🕹' => 'rākau mana',
    '🎰' => 'mīhini kaimoni',
    '🎲' => 'tapaono kēmu',
    '♠' => 'hūtu pēti',
    '♥' => 'hūtu hāte',
    '♦' => 'hūtu taimana',
    '♣' => 'hūtu karapu',
    '🃏' => 'tioka',
    '🀄' => 'tarakona whero mahjong',
    '🎴' => 'kāri purei putiputi',
    '🎭' => 'ngā toi whakaaturanga',
    '🖼' => 'pikitia whai anga',
    '🎨' => 'papapeita tohunga toi',
    '👓' => 'mōhiti karu',
    '🕶' => 'mōhitirā',
    '👔' => 'neketai',
    '👕' => 'tī-hāte',
    '👖' => 'tarau tāngari',
    '🧣' => 'kāmeta',
    '🧤' => 'karapu',
    '🧥' => 'koti',
    '🧦' => 'tōkena',
    '👗' => 'kākahu',
    '👘' => 'kimono',
    '👙' => 'pikīni',
    '👚' => 'kākahu wahine',
    '👛' => 'pāhi',
    '👜' => 'pāhi ā-ringa',
    '👝' => 'pāhi hopu',
    '🛍' => 'pēke hokohoko',
    '🎒' => 'pēketuarā kura',
    '👞' => 'hū tāne',
    '👟' => 'hū omaama',
    '👠' => 'hū rekereke-teitei',
    '👡' => 'kopa wahine',
    '👢' => 'pūtu wahine',
    '👑' => 'karauna',
    '👒' => 'pōtae wahine',
    '🎩' => 'pōtae tihi',
    '🎓' => 'kape whiwhinga tohu',
    '🧢' => 'kape ngutu-parera',
    '⛑' => 'pōtae mārō kaimahi whakaora',
    '📿' => 'ngā poria inoi',
    '💄' => 'paningutu',
    '💍' => 'mōwhiti matimati',
    '💎' => 'kōhatu māpuna',
    '🔇' => 'tukuoro whakangū',
    '🔈' => 'tukuoro kahaoro pāpaku',
    '🔉' => 'tukuoro kahaoro waenga',
    '🔊' => 'tukuoro kahaoro teitei',
    '📢' => 'tukuoro',
    '📣' => 'pūwhakarahireo',
    '📯' => 'haona poutāpeta',
    '🔔' => 'pere',
    '🔕' => 'pere whai rītaha',
    '🎼' => 'tuhinga puoro',
    '🎵' => 'tohu waiata',
    '🎶' => 'ngā tohu waiata',
    '🎙' => 'hopuoro taiwhanga',
    '🎚' => 'rēreti puoro',
    '🎛' => 'ngā puku mana',
    '🎤' => 'hopuoro',
    '🎧' => 'maupane',
    '📻' => 'irirangi',
    '🎷' => 'pūtohe',
    '🎺' => 'pūawanui',
    '🎸' => 'kitā',
    '🎹' => 'papapurei puoro',
    '🎻' => 'tōiri',
    '🥁' => 'pahū',
    '📱' => 'waea pūkoro',
    '📲' => 'waea pūkoro me te pere',
    '☎' => 'waea',
    '📞' => 'pūwhiwhi waea',
    '📟' => 'pūoho',
    '📠' => 'mīhini waeatuhi',
    '🔋' => 'pūhiko',
    '🔌' => 'puru hiko',
    '💻' => 'paparorohiko',
    '🖥' => 'rorohiko papamahi',
    '🖨' => 'pūreretā',
    '⌨' => 'papapātuhi',
    '🖱' => 'kiore rorohiko',
    '🖲' => 'pōrotaki',
    '💽' => 'kōpae rorohiko',
    '💾' => 'kōpae pīngore',
    '💿' => 'kōpae whatu',
    '📀' => 'kam',
    '🎥' => 'pū hopuata',
    '🎞' => 'anga whitiāhua',
    '📽' => 'tukuata whitiāhua',
    '🎬' => 'papa papaki',
    '📺' => 'pouaka whakaata',
    '📷' => 'pūwhakaahua',
    '📸' => 'pūwhakaahua whai hikohiko',
    '📹' => 'pūwhakaahua ataata',
    '📼' => 'rīpene-ataata',
    '🔍' => 'kārāhe whārahi anga mauī',
    '🔎' => 'karāhe whārahi anga matau',
    '🕯' => 'kānara',
    '💡' => 'puku mārama',
    '🔦' => 'kōrama',
    '🏮' => 'rātana pepa whero',
    '📔' => 'pukatuhipoka whai uhi whakairoiro',
    '📕' => 'pukapuka kopi',
    '📖' => 'pukapuka tuwhera',
    '📗' => 'pukapuka kākāriki',
    '📘' => 'pukapuka kikorangi',
    '📙' => 'pukapuka karaka',
    '📚' => 'ngā pukapuka',
    '📓' => 'pukatuhipoka',
    '📒' => 'puka kaute',
    '📃' => 'whārangi whai piko',
    '📜' => 'tuhinga pōkai',
    '📄' => 'whārangi anga ake',
    '📰' => 'nūpepa',
    '🗞' => 'nūpepa pōkai',
    '📑' => 'ripa tohuwāhi',
    '🔖' => 'tohuwāhi',
    '🏷' => 'tapanga',
    '💰' => 'pēke moni',
    '💴' => 'monipepa Yen',
    '💵' => 'monipepa tāra',
    '💶' => 'monipepa uro',
    '💷' => 'monipepa pauna',
    '💸' => 'moni whai parirau',
    '💳' => 'kāri tāwere',
    '💹' => 'tūtohi aupiki me te yen',
    '✉' => 'kōpaki',
    '📧' => 'īmēra',
    '📨' => 'kōpaki taumai',
    '📩' => 'kōpaki whai kōpere',
    '📤' => 'heri pouakaputa',
    '📥' => 'heri pouakauru',
    '📦' => 'mōkihi',
    '📫' => 'pouakamēra kopi whai kara whakarewa',
    '📪' => 'pouakamēra kopi whai kara whakaheke',
    '📬' => 'pouakamēra tuwhera whai kara whakarewa',
    '📭' => 'pouakamēra tuwhera whai kara whakaheke',
    '📮' => 'pouaka poutāpeta',
    '🗳' => 'pouaka pōti me te pōti',
    '✏' => 'penerākau',
    '✒' => 'timopene pango',
    '🖋' => 'pene puna',
    '🖊' => 'pene',
    '🖌' => 'parahi peita',
    '🖍' => 'pene hinu',
    '📝' => 'manatu',
    '💼' => 'kopamārō',
    '📁' => 'kōpaki kōnae',
    '📂' => 'kōpaki kōnae tuwhera',
    '🗂' => 'ngā whakawehe kāri kuputohu',
    '📅' => 'maramataka',
    '📆' => 'maramataka tīhae',
    '🗒' => 'pukatuhi tōrino',
    '🗓' => 'maramataka tōrino',
    '📇' => 'kuputohu ā-kāri',
    '📈' => 'tūtohi aupiki',
    '📉' => 'tūtohi auheke',
    '📊' => 'tūtohi pae',
    '📋' => 'paparawhi',
    '📌' => 'pinepana',
    '📍' => 'pinepana porohita',
    '📎' => 'rawhipepa',
    '🖇' => 'ngā rawhipepa honohono',
    '📏' => 'rūri torotika',
    '📐' => 'rūri tapatoru',
    '✂' => 'kutikuti',
    '🗃' => 'pouaka kōnae kāri',
    '🗄' => 'kāpata kōnae',
    '🗑' => 'pāhikete para',
    '🔒' => 'kua maukati',
    '🔓' => 'wetemaukati',
    '🔏' => 'maukati mā te pene',
    '🔐' => 'maukati mā te kī',
    '🔑' => 'kī',
    '🗝' => 'kī tawhito',
    '🔨' => 'hama',
    '⛏' => 'keriwhenua',
    '⚒' => 'hama me te keriwhenua',
    '🛠' => 'hama me te wāwāhi',
    '🗡' => 'oka',
    '⚔' => 'hoari whakawhiri',
    '💣' => 'pōma',
    '🏹' => 'kōpere me ngā pere',
    '🛡' => 'pākai',
    '🔧' => 'wāwāhi',
    '🔩' => 'nati me te whaowiri',
    '⚙' => 'taputapu',
    '🗜' => 'kuku',
    '⚖' => 'ōrite whārite',
    '🔗' => 'hononga',
    '⛓' => 'ngā mekameka',
    '⚗' => 'taputapu iheunga',
    '🔬' => 'pūwhārahi',
    '🔭' => 'karu whakatata',
    '📡' => 'pūhihi amiorangi',
    '💉' => 'ngira',
    '💊' => 'pire',
    '🚪' => 'kūwaha',
    '🛏' => 'moenga',
    '🛋' => 'nohoanga roa me te rama',
    '🚽' => 'heketua',
    '🚿' => 'uwhiuwhi',
    '🛁' => 'tāpukaukau',
    '🛒' => 'tāiki panapana',
    '🚬' => 'hikareti',
    '⚰' => 'kāwhena',
    '⚱' => 'ipu tangihanga',
    '🗿' => 'moai',
    '🏧' => 'tohu ATM',
    '🚮' => 'tohu para roto ipu',
    '🚰' => 'wai pai hei unu',
    '♿' => 'tohu kōrea',
    '🚹' => 'taiwhanga tāne',
    '🚺' => 'taiwhanga wāhine',
    '🚻' => 'rūma whakatā',
    '🚼' => 'tohu pēpi',
    '🚾' => 'wharepaku',
    '🛂' => 'mana uruwhenua',
    '🛃' => 'tari taupare',
    '🛄' => 'kerēme pāhi',
    '🛅' => 'pāhi mahue',
    '⚠' => 'whakatūpato',
    '🚸' => 'tamariki e whakawhiti ana',
    '⛔' => 'kaua e tomo',
    '🚫' => 'kua whakakore',
    '🚳' => 'kaua he pahikara',
    '🚭' => 'kaua e kaipaipa',
    '🚯' => 'kaua e mahi para',
    '🚱' => 'wai kāore e pai hei unu',
    '🚷' => 'kaua he kaihīkoi',
    '📵' => 'kaua te waea pūkoro',
    '🔞' => 'kia tekau-mā-waru ake',
    '☢' => 'ira-rukeruke',
    '☣' => 'pūmate koiora',
    '⬆' => 'pere ake',
    '↗' => 'pere ake-matau',
    '➡' => 'pere matau',
    '↘' => 'pere iho-matau',
    '⬇' => 'pere iho',
    '↙' => 'pere iho-mauī',
    '⬅' => 'pere mauī',
    '↖' => 'pere ake-mauī',
    '↕' => 'pere ake-iho',
    '↔' => 'pere mauī-matau',
    '↩' => 'pere matau piko mauī',
    '↪' => 'pere mauī piko matau',
    '⤴' => 'pere matau piko ake',
    '⤵' => 'pere matau piko iho',
    '🔃' => 'pere poutū whakatekaraka',
    '🔄' => 'pātene pere kōaro',
    '🔙' => 'pere HOKI',
    '🔚' => 'pere MUTUNGA',
    '🔛' => 'pere KĀ!',
    '🔜' => 'pere ĀKUANEI',
    '🔝' => 'pere RUNGA',
    '🛐' => 'wāhi karakia',
    '⚛' => 'tohu ngota',
    '🕉' => 'om',
    '✡' => 'whetū o Rāwiri',
    '☸' => 'wīra o tārama',
    '☯' => 'yin yang',
    '✝' => 'rīpeka ratini',
    '☦' => 'rīpeka tukuiho',
    '☪' => 'whetū me pewa',
    '☮' => 'tohu rongomau',
    '🕎' => 'menoraha',
    '🔯' => 'whetū ono-pito iraira',
    '♈' => 'Aries',
    '♉' => 'Taurus',
    '♊' => 'Gemini',
    '♋' => 'Cancer',
    '♌' => 'Leo',
    '♍' => 'Virgo',
    '♎' => 'Libra',
    '♏' => 'Scorpius',
    '♐' => 'Sagittarius',
    '♑' => 'Capricorn',
    '♒' => 'Aquarius',
    '♓' => 'Pisces',
    '⛎' => 'Ophiuchus',
    '🔀' => 'pātene ranu riu',
    '🔁' => 'pātene tukurua',
    '🔂' => 'pātene tukurua kotahi',
    '▶' => 'pātene purei',
    '⏩' => 'pātene tere whakamua',
    '⏭' => 'pātene riu panuku',
    '⏯' => 'pātene purei, taihoa rānei',
    '◀' => 'pātene whakamuri',
    '⏪' => 'pātene tere whakamuri',
    '⏮' => 'pātene riu tōmuri',
    '🔼' => 'pātene ake',
    '⏫' => 'pātene tere ake',
    '🔽' => 'pātene iho',
    '⏬' => 'pātene tere iho',
    '⏸' => 'pātene taihoa',
    '⏹' => 'pātene tū',
    '⏺' => 'pātene tāhopu',
    '⏏' => 'pātene tuwha',
    '🎦' => 'whare whitiāhua',
    '🔅' => 'pātene whakakaurehu',
    '🔆' => 'pātene kanapa',
    '📶' => 'pae pūhīhī',
    '📳' => 'aratau wiriwiri',
    '📴' => 'waea pūkoro weto',
    '♀' => 'tohu wahine',
    '♂' => 'tohu tāne',
    '✖' => 'x whakarea taumaha',
    '➕' => 'tohu tāpiri taumaha',
    '➖' => 'tohu tango taumaha',
    '➗' => 'tohu whakawehe taumaha',
    '‼' => 'tohuhā taurua',
    '⁉' => 'tohu tohuhā-pātai',
    '❓' => 'tohu pātai',
    '❔' => 'tohu pātai mā',
    '❕' => 'tohuhā mā',
    '❗' => 'tohuhā',
    '〰' => 'pīhono karekare',
    '💱' => 'whakawhitinga momo moni',
    '💲' => 'tohu tāra taumaha',
    '⚕' => 'tohu rongoā',
    '♻' => 'tohu tukurua',
    '⚜' => 'putiputi rengarenga',
    '🔱' => 'tohu mārau',
    '📛' => 'tohu ingoa',
    '🔰' => 'tohu Hapanīhi mō te tauhou',
    '⭕' => 'porohita rahi taumaha',
    '✅' => 'tohu taki mā taumaha',
    '☑' => 'pouaka pōti whai taki',
    '✔' => 'tohu taki taumaha',
    '❌' => 'tohu whiri',
    '❎' => 'pātene tohu whiri',
    '➰' => 'koromeke hūmenge',
    '➿' => 'koromeke hūmenge taurua',
    '〽' => 'tohu wāhi whirihoa',
    '✳' => 'whetūriki waru-pito',
    '✴' => 'whetū waru-pito',
    '❇' => 'korakora',
    '™' => 'tohu hoko',
    '🔠' => 'tāuru pūmatua ratini',
    '🔡' => 'tāuru pūriki ratini',
    '🔢' => 'tāuru tau',
    '🔣' => 'tāuru tohu',
    '🔤' => 'tāuru pū ratini',
    '🅰' => 'pātene A (momo toto)',
    '🆎' => 'pātene AB (momo toto)',
    '🅱' => 'pātene B (momo toto)',
    '🆑' => 'pātene CL',
    '🆒' => 'pātene RAWE',
    '🆓' => 'pātene KOREUTU',
    'ℹ' => 'mōhiohio',
    '🆔' => 'pātene TT',
    'Ⓜ' => 'M porohitatia',
    '🆕' => 'pātene HŌU',
    '🆖' => 'pātene NG',
    '🅾' => 'pātene O (momo toto)',
    '🆗' => 'pātene ĀE',
    '🅿' => 'pātene P',
    '🆘' => 'pātene SOS',
    '🆚' => 'pātene VS',
    '🈁' => 'pātene Hapanīhi "i konei"',
    '🈂' => 'pātene Hapanīhi "utu ratonga"',
    '🈷' => 'pātene Hapanīhi "nuinga ā-marama"',
    '🈶' => 'pātene Hapanīhi "ehara i te koreutu"',
    '🈯' => 'pātene Hapanīhi "rāhuitia"',
    '🉐' => 'pātene Hapanīhi "utu ngāwari"',
    '🈹' => 'pātene Hapanīhi "kua whakaheke"',
    '🈚' => 'pātene Hapanīhi "kāore he utu"',
    '🈲' => 'pātene Hapanīhi "kua whakakore"',
    '🉑' => 'pātene Hapanīhi "ka whakaaetia"',
    '🈸' => 'pātene Hapanīhi "taupānga"',
    '🈴' => 'pātene Hapanīhi "whiwhinga pāhi"',
    '🈳' => 'pātene Hapanīhi "wāteatanga"',
    '㊗' => 'pātene Hapanīhi "tau kē"',
    '㊙' => 'pātene Hapanīhi "pirikoko"',
    '🈺' => 'pātene Hapanīhi "tuwhera mō te pakihi"',
    '🈵' => 'pātene Hapanīhi "kore wāteatanga"',
    '🔴' => 'porohita whero',
    '🔵' => 'porohita kikorangi',
    '⚫' => 'porohita pango',
    '⚪' => 'porohita mā',
    '⬛' => 'tapawhā rite pango rahi',
    '⬜' => 'tapawhā rite mā rahi',
    '◼' => 'tapawhā rite pango waenga',
    '◻' => 'tapawhā rite mā waenga',
    '◾' => 'tapawhā rite pango waenga-iti',
    '◽' => 'tapawhā rite mā waenga-iti',
    '▪' => 'tapawhā rite pango iti',
    '▫' => 'tapawhā rite mā iti',
    '🔶' => 'taimana karaka rahi',
    '🔷' => 'taimana kikorangi rahi',
    '🔸' => 'taimana karaka iti',
    '🔹' => 'taimana kikorangi iti',
    '🔺' => 'tapatoru whero tohu ake',
    '🔻' => 'tapatoru whero tohu iho',
    '💠' => 'taimana whai ira',
    '🔘' => 'pātene irirangi',
    '🔳' => 'pātene tapawhā mā',
    '🔲' => 'pātene tapawhā pango',
    '🏁' => 'kara pātikitiki',
    '🚩' => 'kara tapatoru',
    '🎌' => 'kara whakawhiri',
    '🏴' => 'kara pango',
    '🏳' => 'kara mā',
];
